@@ -20,15 +20,21 @@
 
 #pragma once
 
+#include <functional>
 #include <string>
+#include <vector>
 
+#include "common/status.h"
 #include "exec/exec_node.h"
-#include "gen_cpp/PaloInternalService_types.h"
 #include "util/runtime_profile.h"
 
 namespace doris {
 
-class TScanRange;
+class DescriptorTbl;
+class ObjectPool;
+class RuntimeState;
+class TPlanNode;
+class TScanRangeParams;
 
 // Abstract base class of all scan nodes; introduces set_scan_range().
 //
@@ -81,8 +87,6 @@ public:
 
     bool is_scan_node() const override { return true; }
 
-    void set_no_agg_finalize() { _need_agg_finalize = false; }
-
     RuntimeProfile::Counter* bytes_read_counter() const { return _bytes_read_counter; }
     RuntimeProfile::Counter* rows_read_counter() const { return _rows_read_counter; }
     RuntimeProfile::Counter* total_throughput_counter() const { return _total_throughput_counter; }
@@ -94,19 +98,11 @@ public:
     static const std::string _s_num_disks_accessed_counter;
 
 protected:
-    void _peel_pushed_vconjunct(
-            RuntimeState* state,
-            const std::function<bool(int)>& checker); // remove pushed expr from conjunct tree
-
     RuntimeProfile::Counter* _bytes_read_counter; // # bytes read from the scanner
-    // # rows/tuples read from the scanner (including those discarded by eval_conjuncts())
     RuntimeProfile::Counter* _rows_read_counter;
     // Wall based aggregate read throughput [bytes/sec]
     RuntimeProfile::Counter* _total_throughput_counter;
     RuntimeProfile::Counter* _num_disks_accessed_counter;
-
-protected:
-    bool _need_agg_finalize = true;
 };
 
 } // namespace doris
