@@ -17,45 +17,48 @@
 
 #include "http/action/download_action.h"
 
-#include <sys/types.h>
-#include <unistd.h>
-
+#include <algorithm>
+#include <memory>
 #include <sstream>
 #include <string>
+#include <utility>
 
-#include "agent/cgroups_mgr.h"
-#include "env/env.h"
+#include "common/config.h"
+#include "common/logging.h"
 #include "http/http_channel.h"
-#include "http/http_headers.h"
 #include "http/http_request.h"
-#include "http/http_response.h"
-#include "http/http_status.h"
 #include "http/utils.h"
+#include "io/fs/local_file_system.h"
 #include "runtime/exec_env.h"
-#include "util/file_utils.h"
-#include "util/filesystem_util.h"
-#include "util/path_util.h"
 
 namespace doris {
 
 const std::string FILE_PARAMETER = "file";
-const std::string DB_PARAMETER = "db";
-const std::string LABEL_PARAMETER = "label";
 const std::string TOKEN_PARAMETER = "token";
 
-DownloadAction::DownloadAction(ExecEnv* exec_env, const std::vector<std::string>& allow_dirs)
-        : _exec_env(exec_env), _download_type(NORMAL) {
+DownloadAction::DownloadAction(ExecEnv* exec_env, const std::vector<std::string>& allow_dirs,
+                               int32_t num_workers)
+        : _exec_env(exec_env), _download_type(NORMAL), _num_workers(num_workers) {
     for (auto& dir : allow_dirs) {
         std::string p;
-        WARN_IF_ERROR(FileUtils::canonicalize(dir, &p), "canonicalize path " + dir + " failed");
+        Status st = io::global_local_filesystem()->canonicalize(dir, &p);
+        if (!st.ok()) {
+            continue;
+        }
         _allow_paths.emplace_back(std::move(p));
     }
+    if (_num_workers > 0) {
+        // for single-replica-load
+        ThreadPoolBuilder("DownloadThreadPool")
+                .set_min_threads(num_workers)
+                .set_max_threads(num_workers)
+                .build(&_download_workers);
+    }
 }
 
 DownloadAction::DownloadAction(ExecEnv* exec_env, const std::string& error_log_root_dir)
-        : _exec_env(exec_env), _download_type(ERROR_LOG) {
-    WARN_IF_ERROR(FileUtils::canonicalize(error_log_root_dir, &_error_log_root_dir),
-                  "canonicalize path " + error_log_root_dir + " failed");
+        : _exec_env(exec_env), _download_type(ERROR_LOG), _num_workers(0) {
+    io::global_local_filesystem()->canonicalize(error_log_root_dir, &_error_log_root_dir);
 }
 
 void DownloadAction::handle_normal(HttpRequest* req, const std::string& file_param) {
@@ -64,18 +67,40 @@ void DownloadAction::handle_normal(HttpRequest* req, const std::string& file_par
     if (config::enable_token_check) {
         status = check_token(req);
         if (!status.ok()) {
-            HttpChannel::send_reply(req, status.to_string());
-            return;
+            std::string error_msg = status.to_string();
+            if (status.is_not_authorized()) {
+                HttpChannel::send_reply(req, HttpStatus::UNAUTHORIZED, error_msg);
+                return;
+            } else {
+                HttpChannel::send_reply(req, HttpStatus::INTERNAL_SERVER_ERROR, error_msg);
+                return;
+            }
         }
     }
 
     status = check_path_is_allowed(file_param);
+    if (!status.ok()) {
+        std::string error_msg = status.to_string();
+        if (status.is_not_found() || status.is_io_error()) {
+            HttpChannel::send_reply(req, HttpStatus::NOT_FOUND, error_msg);
+            return;
+        } else if (status.is_not_authorized()) {
+            HttpChannel::send_reply(req, HttpStatus::UNAUTHORIZED, error_msg);
+            return;
+        } else {
+            HttpChannel::send_reply(req, HttpStatus::INTERNAL_SERVER_ERROR, error_msg);
+            return;
+        }
+    }
+
+    bool is_dir = false;
+    status = io::global_local_filesystem()->is_directory(file_param, &is_dir);
     if (!status.ok()) {
         HttpChannel::send_reply(req, status.to_string());
         return;
     }
 
-    if (FileUtils::is_dir(file_param)) {
+    if (is_dir) {
         do_dir_response(file_param, req);
     } else {
         do_file_response(file_param, req);
@@ -88,11 +113,31 @@ void DownloadAction::handle_error_log(HttpRequest* req, const std::string& file_
     Status status = check_log_path_is_allowed(absolute_path);
     if (!status.ok()) {
         std::string error_msg = status.to_string();
-        HttpChannel::send_reply(req, error_msg);
-        return;
+        if (status.is_not_authorized()) {
+            HttpChannel::send_reply(req, HttpStatus::UNAUTHORIZED, error_msg);
+            return;
+        } else {
+            HttpChannel::send_reply(req, HttpStatus::INTERNAL_SERVER_ERROR, error_msg);
+            return;
+        }
     }
 
-    if (FileUtils::is_dir(absolute_path)) {
+    bool is_dir = false;
+    status = io::global_local_filesystem()->is_directory(absolute_path, &is_dir);
+    if (!status.ok()) {
+        std::string error_msg = status.to_string();
+        if (status.is_not_found() || status.is_io_error()) {
+            HttpChannel::send_reply(req, HttpStatus::NOT_FOUND, error_msg);
+            return;
+        } else if (status.is_not_authorized()) {
+            HttpChannel::send_reply(req, HttpStatus::UNAUTHORIZED, error_msg);
+            return;
+        } else {
+            HttpChannel::send_reply(req, HttpStatus::INTERNAL_SERVER_ERROR, error_msg);
+            return;
+        }
+    }
+    if (is_dir) {
         std::string error_msg = "error log can only be file.";
         HttpChannel::send_reply(req, error_msg);
         return;
@@ -102,10 +147,19 @@ void DownloadAction::handle_error_log(HttpRequest* req, const std::string& file_
 }
 
 void DownloadAction::handle(HttpRequest* req) {
-    VLOG_CRITICAL << "accept one download request " << req->debug_string();
+    if (_num_workers > 0) {
+        // async for heavy download job, currently mainly for single-replica-load
+        auto status = _download_workers->submit_func([this, req]() { _handle(req); });
+        if (!status.ok()) {
+            HttpChannel::send_reply(req, HttpStatus::INTERNAL_SERVER_ERROR, status.to_string());
+        }
+    } else {
+        _handle(req);
+    }
+}
 
-    // add tid to cgroup in order to limit read bandwidth
-    CgroupsMgr::apply_system_cgroup();
+void DownloadAction::_handle(HttpRequest* req) {
+    VLOG_CRITICAL << "accept one download request " << req->debug_string();
 
     // Get 'file' parameter, then assembly file absolute path
     const std::string& file_path = req->param(FILE_PARAMETER);
@@ -128,11 +182,11 @@ void DownloadAction::handle(HttpRequest* req) {
 Status DownloadAction::check_token(HttpRequest* req) {
     const std::string& token_str = req->param(TOKEN_PARAMETER);
     if (token_str.empty()) {
-        return Status::InternalError("token is not specified.");
+        return Status::NotAuthorized("token is not specified.");
     }
 
     if (token_str != _exec_env->token()) {
-        return Status::InternalError("invalid token.");
+        return Status::NotAuthorized("invalid token.");
     }
 
     return Status::OK();
@@ -142,32 +196,26 @@ Status DownloadAction::check_path_is_allowed(const std::string& file_path) {
     DCHECK_EQ(_download_type, NORMAL);
 
     std::string canonical_file_path;
-    RETURN_WITH_WARN_IF_ERROR(FileUtils::canonicalize(file_path, &canonical_file_path),
-                              Status::InternalError("file path is invalid: {}", file_path),
-                              "file path is invalid: " + file_path);
-
+    RETURN_IF_ERROR(io::global_local_filesystem()->canonicalize(file_path, &canonical_file_path));
     for (auto& allow_path : _allow_paths) {
-        if (FileSystemUtil::contain_path(allow_path, canonical_file_path)) {
+        if (io::LocalFileSystem::contain_path(allow_path, canonical_file_path)) {
             return Status::OK();
         }
     }
 
-    return Status::InternalError("file path is not allowed: {}", canonical_file_path);
+    return Status::NotAuthorized("file path is not allowed: {}", canonical_file_path);
 }
 
 Status DownloadAction::check_log_path_is_allowed(const std::string& file_path) {
     DCHECK_EQ(_download_type, ERROR_LOG);
 
     std::string canonical_file_path;
-    RETURN_WITH_WARN_IF_ERROR(FileUtils::canonicalize(file_path, &canonical_file_path),
-                              Status::InternalError("file path is invalid: {}", file_path),
-                              "file path is invalid: " + file_path);
-
-    if (FileSystemUtil::contain_path(_error_log_root_dir, canonical_file_path)) {
+    RETURN_IF_ERROR(io::global_local_filesystem()->canonicalize(file_path, &canonical_file_path));
+    if (io::LocalFileSystem::contain_path(_error_log_root_dir, canonical_file_path)) {
         return Status::OK();
     }
 
-    return Status::InternalError("file path is not allowed: {}", file_path);
+    return Status::NotAuthorized("file path is not allowed: {}", file_path);
 }
 
 } // end namespace doris
