@@ -26,6 +26,7 @@
 #include <vector>
 
 #include "agent/utils.h"
+#include "common/config.h"
 #include "common/logging.h"
 #include "io/fs/hdfs.h"
 #include "util/string_util.h"
@@ -134,6 +135,7 @@ Status createHDFSBuilder(const THdfsParams& hdfsParams, HDFSCommonBuilder* build
     if (hdfsParams.__isset.hdfs_conf) {
         for (const THdfsConf& conf : hdfsParams.hdfs_conf) {
             hdfsBuilderConfSetStr(builder->get(), conf.key.c_str(), conf.value.c_str());
+            LOG(INFO) << "set hdfs config: " << conf.key << ", value: " << conf.value;
 #ifdef USE_HADOOP_HDFS
             // Set krb5.conf, we should define java.security.krb5.conf in catalog properties
             if (strcmp(conf.key.c_str(), "java.security.krb5.conf") == 0) {
@@ -143,6 +145,17 @@ Status createHDFSBuilder(const THdfsParams& hdfsParams, HDFSCommonBuilder* build
         }
     }
 
+#ifdef USE_HADOOP_HDFS
+    if (config::enable_hdfs_hedged_read) {
+        hdfsBuilderConfSetStr(builder->get(), "dfs.client.hedged.read.threadpool.size",
+                              std::to_string(config::hdfs_hedged_read_thread_num).c_str());
+        hdfsBuilderConfSetStr(builder->get(), "dfs.client.hedged.read.threshold.millis",
+                              std::to_string(config::hdfs_hedged_read_threshold_time).c_str());
+        LOG(INFO) << "set hdfs hedged read config: " << config::hdfs_hedged_read_thread_num << ", "
+                  << config::hdfs_hedged_read_threshold_time;
+    }
+#endif
+
     hdfsBuilderConfSetStr(builder->get(), "ipc.client.fallback-to-simple-auth-allowed", "true");
 
     if (builder->is_need_kinit()) {
