@@ -17,25 +17,46 @@
 
 #pragma once
 
-#include "gen_cpp/internal_service.pb.h"
-#include "olap/rowset/rowset_writer.h"
+#include <gen_cpp/Types_types.h>
+#include <gen_cpp/internal_service.pb.h>
+#include <gen_cpp/types.pb.h>
+#include <stdint.h>
+
+#include <atomic>
+#include <memory>
+#include <mutex>
+#include <shared_mutex>
+#include <unordered_set>
+#include <vector>
+
+#include "common/status.h"
+#include "olap/memtable.h"
+#include "olap/olap_common.h"
+#include "olap/rowset/rowset.h"
 #include "olap/tablet.h"
+#include "olap/tablet_meta.h"
+#include "olap/tablet_schema.h"
 #include "util/spinlock.h"
+#include "util/uid_util.h"
 
 namespace doris {
 
 class FlushToken;
 class MemTable;
 class MemTracker;
-class RowBatch;
 class Schema;
 class StorageEngine;
-class Tuple;
 class TupleDescriptor;
-class TupleRow;
 class SlotDescriptor;
+class OlapTableSchemaParam;
+class RowsetWriter;
+
+namespace vectorized {
+class Block;
+} // namespace vectorized
 
 enum WriteType { LOAD = 1, LOAD_DELETE = 2, DELETE = 3 };
+enum MemType { WRITE = 1, FLUSH = 2, ALL = 3 };
 
 struct WriteRequest {
     int64_t tablet_id;
@@ -56,22 +77,26 @@ struct WriteRequest {
 // This class is NOT thread-safe, external synchronization is required.
 class DeltaWriter {
 public:
-    static Status open(WriteRequest* req, DeltaWriter** writer,
-                       const UniqueId& load_id = TUniqueId(), bool is_vec = false);
+    static Status open(WriteRequest* req, DeltaWriter** writer, RuntimeProfile* profile,
+                       const UniqueId& load_id = TUniqueId());
 
     ~DeltaWriter();
 
     Status init();
 
-    Status write(Tuple* tuple);
-    Status write(const RowBatch* row_batch, const std::vector<int>& row_idxs);
-    Status write(const vectorized::Block* block, const std::vector<int>& row_idxs);
+    Status write(const vectorized::Block* block, const std::vector<int>& row_idxs,
+                 bool is_append = false);
 
-    // flush the last memtable to flush queue, must call it before close_wait()
+    Status append(const vectorized::Block* block);
+
+    // flush the last memtable to flush queue, must call it before build_rowset()
     Status close();
     // wait for all memtables to be flushed.
     // mem_consumption() should be 0 after this function returns.
-    Status close_wait(const PSlaveTabletNodes& slave_tablet_nodes, const bool write_single_replica);
+    Status build_rowset();
+    Status submit_calc_delete_bitmap_task();
+    Status wait_calc_delete_bitmap();
+    Status commit_txn(const PSlaveTabletNodes& slave_tablet_nodes, const bool write_single_replica);
 
     bool check_slave_replicas_done(google::protobuf::Map<int64_t, PSuccessSlaveTabletNodeIds>*
                                            success_slave_tablet_node_ids);
@@ -93,7 +118,8 @@ public:
 
     int64_t partition_id() const;
 
-    int64_t mem_consumption();
+    int64_t mem_consumption(MemType mem);
+    int64_t active_memtable_mem_consumption();
 
     // Wait all memtable in flush queue to be flushed
     Status wait_flush();
@@ -102,19 +128,18 @@ public:
 
     int32_t schema_hash() { return _tablet->schema_hash(); }
 
-    void save_mem_consumption_snapshot();
-
-    int64_t get_memtable_consumption_inflush() const;
-
-    int64_t get_memtable_consumption_snapshot() const;
-
     void finish_slave_tablet_pull_rowset(int64_t node_id, bool is_succeed);
 
     int64_t total_received_rows() const { return _total_received_rows; }
 
+    int64_t num_rows_filtered() const;
+
+    // For UT
+    DeleteBitmapPtr get_delete_bitmap() { return _delete_bitmap; }
+
 private:
-    DeltaWriter(WriteRequest* req, StorageEngine* storage_engine, const UniqueId& load_id,
-                bool is_vec);
+    DeltaWriter(WriteRequest* req, StorageEngine* storage_engine, RuntimeProfile* profile,
+                const UniqueId& load_id);
 
     // push a full memtable to flush executor
     Status _flush_memtable_async();
@@ -129,6 +154,8 @@ private:
 
     void _request_slave_tablet_pull_rowset(PNodeInfo node_info);
 
+    void _init_profile(RuntimeProfile* profile);
+
     bool _is_init = false;
     bool _is_cancelled = false;
     bool _is_closed = false;
@@ -150,27 +177,19 @@ private:
     StorageEngine* _storage_engine;
     UniqueId _load_id;
     std::unique_ptr<FlushToken> _flush_token;
-    std::vector<std::shared_ptr<MemTracker>> _mem_table_tracker;
+    std::vector<std::shared_ptr<MemTracker>> _mem_table_insert_trackers;
+    std::vector<std::shared_ptr<MemTracker>> _mem_table_flush_trackers;
     SpinLock _mem_table_tracker_lock;
     std::atomic<uint32_t> _mem_table_num = 1;
 
     std::mutex _lock;
 
-    // use in vectorized load
-    bool _is_vec;
-
-    // memory consumption snapshot for current delta_writer, only
-    // used for std::sort
-    int64_t _mem_consumption_snapshot = 0;
-    // memory consumption snapshot for current memtable, only
-    // used for std::sort
-    int64_t _memtable_consumption_snapshot = 0;
-
     std::unordered_set<int64_t> _unfinished_slave_node;
     PSuccessSlaveTabletNodeIds _success_slave_node_ids;
     std::shared_mutex _slave_node_lock;
 
     DeleteBitmapPtr _delete_bitmap = nullptr;
+    std::unique_ptr<CalcDeleteBitmapToken> _calc_delete_bitmap_token;
     // current rowset_ids, used to do diff in publish_version
     RowsetIdUnorderedSet _rowset_ids;
     // current max version, used to calculate delete bitmap
@@ -178,8 +197,26 @@ private:
 
     // total rows num written by DeltaWriter
     int64_t _total_received_rows = 0;
-    // rows num merged by memtable
-    int64_t _merged_rows = 0;
+
+    RuntimeProfile* _profile = nullptr;
+    RuntimeProfile::Counter* _lock_timer = nullptr;
+    RuntimeProfile::Counter* _sort_timer = nullptr;
+    RuntimeProfile::Counter* _agg_timer = nullptr;
+    RuntimeProfile::Counter* _wait_flush_timer = nullptr;
+    RuntimeProfile::Counter* _delete_bitmap_timer = nullptr;
+    RuntimeProfile::Counter* _segment_writer_timer = nullptr;
+    RuntimeProfile::Counter* _memtable_duration_timer = nullptr;
+    RuntimeProfile::Counter* _put_into_output_timer = nullptr;
+    RuntimeProfile::Counter* _sort_times = nullptr;
+    RuntimeProfile::Counter* _agg_times = nullptr;
+    RuntimeProfile::Counter* _close_wait_timer = nullptr;
+    RuntimeProfile::Counter* _segment_num = nullptr;
+    RuntimeProfile::Counter* _raw_rows_num = nullptr;
+    RuntimeProfile::Counter* _merged_rows_num = nullptr;
+
+    MonotonicStopWatch _lock_watch;
+
+    MemTableStat _memtable_stat;
 };
 
 } // namespace doris
