@@ -17,8 +17,6 @@
 
 #pragma once
 
-#include <parallel_hashmap/phmap.h>
-
 #include <cstdint>
 #include <roaring/roaring.hh>
 
@@ -27,24 +25,20 @@
 #include "olap/column_predicate.h"
 #include "olap/olap_common.h"
 #include "olap/rowset/segment_v2/bloom_filter.h"
+#include "olap/rowset/segment_v2/inverted_index_cache.h" // IWYU pragma: keep
+#include "olap/rowset/segment_v2/inverted_index_reader.h"
 #include "olap/wrapper_field.h"
 #include "runtime/define_primitive_type.h"
 #include "runtime/primitive_type.h"
-#include "runtime/string_value.h"
 #include "runtime/type_limit.h"
 #include "uint24.h"
 #include "vec/columns/column_dictionary.h"
+#include "vec/common/string_ref.h"
 #include "vec/core/types.h"
 
-// for string value
 template <>
-struct std::hash<doris::StringValue> {
-    uint64_t operator()(const doris::StringValue& rhs) const { return hash_value(rhs); }
-};
-
-template <>
-struct std::equal_to<doris::StringValue> {
-    bool operator()(const doris::StringValue& lhs, const doris::StringValue& rhs) const {
+struct std::equal_to<doris::StringRef> {
+    bool operator()(const doris::StringRef& lhs, const doris::StringRef& rhs) const {
         return lhs == rhs;
     }
 };
@@ -80,29 +74,35 @@ struct std::equal_to<doris::uint24_t> {
 
 namespace doris {
 
-template <PrimitiveType Type, PredicateType PT>
+/**
+ * Use HybridSetType can avoid virtual function call in the loop.
+ * @tparam Type
+ * @tparam PT
+ * @tparam HybridSetType
+ */
+template <PrimitiveType Type, PredicateType PT, typename HybridSetType>
 class InListPredicateBase : public ColumnPredicate {
 public:
     using T = typename PredicatePrimitiveTypeTraits<Type>::PredicateFieldType;
     template <typename ConditionType, typename ConvertFunc>
     InListPredicateBase(uint32_t column_id, const ConditionType& conditions,
                         const ConvertFunc& convert, bool is_opposite = false,
-                        const TabletColumn* col = nullptr, MemPool* pool = nullptr)
+                        const TabletColumn* col = nullptr, vectorized::Arena* arena = nullptr)
             : ColumnPredicate(column_id, is_opposite),
-              _values(new phmap::flat_hash_set<T>()),
               _min_value(type_limit<T>::max()),
               _max_value(type_limit<T>::min()) {
+        _values = std::make_shared<HybridSetType>();
         for (const auto& condition : conditions) {
             T tmp;
             if constexpr (Type == TYPE_STRING || Type == TYPE_CHAR) {
-                tmp = convert(*col, condition, pool);
+                tmp = convert(*col, condition, arena);
             } else if constexpr (Type == TYPE_DECIMAL32 || Type == TYPE_DECIMAL64 ||
                                  Type == TYPE_DECIMAL128I) {
                 tmp = convert(*col, condition);
             } else {
                 tmp = convert(condition);
             }
-            _values->insert(tmp);
+            _values->insert(&tmp);
             _update_min_max(tmp);
         }
     }
@@ -112,98 +112,76 @@ public:
             : ColumnPredicate(column_id, false),
               _min_value(type_limit<T>::max()),
               _max_value(type_limit<T>::min()) {
-        using HybridSetType =
-                std::conditional_t<is_string_type(Type), StringSet, HybridSet<Type, true>>;
-
         CHECK(hybrid_set != nullptr);
 
         if constexpr (is_string_type(Type) || Type == TYPE_DECIMALV2 || is_date_type(Type)) {
-            _values = new phmap::flat_hash_set<T>();
-            auto values = ((HybridSetType*)hybrid_set.get())->get_inner_set();
-
+            _values = std::make_shared<HybridSetType>();
             if constexpr (is_string_type(Type)) {
-                for (auto& value : *values) {
-                    StringValue sv = {value.data(), int(value.size())};
+                HybridSetBase::IteratorBase* iter = hybrid_set->begin();
+                while (iter->has_next()) {
+                    const StringRef* value = (const StringRef*)(iter->get_value());
                     if constexpr (Type == TYPE_CHAR) {
                         _temp_datas.push_back("");
-                        _temp_datas.back().resize(std::max(char_length, value.size()));
-                        memcpy(_temp_datas.back().data(), value.data(), value.size());
-                        sv = {_temp_datas.back().data(), int(_temp_datas.back().size())};
+                        _temp_datas.back().resize(std::max(char_length, value->size));
+                        memcpy(_temp_datas.back().data(), value->data, value->size);
+                        const string& str = _temp_datas.back();
+                        _values->insert((void*)str.data(), str.length());
+                    } else {
+                        _values->insert((void*)value->data, value->size);
                     }
-                    _values->insert(sv);
+                    iter->next();
                 }
             } else if constexpr (Type == TYPE_DECIMALV2) {
-                for (auto& value : *values) {
-                    _values->insert({value.int_value(), value.frac_value()});
+                HybridSetBase::IteratorBase* iter = hybrid_set->begin();
+                while (iter->has_next()) {
+                    const DecimalV2Value* value = (const DecimalV2Value*)(iter->get_value());
+                    decimal12_t decimal12 = {value->int_value(), value->frac_value()};
+                    _values->insert(&decimal12);
+                    iter->next();
                 }
             } else if constexpr (Type == TYPE_DATE) {
-                for (auto& value : *values) {
-                    _values->insert(value.to_olap_date());
+                HybridSetBase::IteratorBase* iter = hybrid_set->begin();
+                while (iter->has_next()) {
+                    const vectorized::VecDateTimeValue* value =
+                            (const vectorized::VecDateTimeValue*)(iter->get_value());
+                    uint64_t date = value->to_olap_date();
+                    _values->insert(&date);
+                    iter->next();
                 }
             } else if constexpr (Type == TYPE_DATETIME) {
-                for (auto& value : *values) {
-                    _values->insert(value.to_olap_datetime());
+                HybridSetBase::IteratorBase* iter = hybrid_set->begin();
+                while (iter->has_next()) {
+                    const vectorized::VecDateTimeValue* value =
+                            (const vectorized::VecDateTimeValue*)(iter->get_value());
+                    uint64_t date_time = value->to_olap_datetime();
+                    _values->insert(&date_time);
+                    iter->next();
                 }
             } else {
-                CHECK(Type == TYPE_DATETIMEV2 || Type == TYPE_DATEV2);
-                for (auto& value : *values) {
-                    _values->insert(T(value));
+                HybridSetBase::IteratorBase* iter = hybrid_set->begin();
+                while (iter->has_next()) {
+                    const void* value = iter->get_value();
+                    _values->insert(value);
+                    iter->next();
                 }
+                CHECK(Type == TYPE_DATETIMEV2 || Type == TYPE_DATEV2);
             }
         } else {
-            should_delete = false;
-            _values = ((HybridSetType*)hybrid_set.get())->get_inner_set();
+            // shared from the caller, so it needs to be shared ptr
+            _values = hybrid_set;
         }
-
-        for (auto& value : *_values) {
-            _update_min_max(value);
+        HybridSetBase::IteratorBase* iter = _values->begin();
+        while (iter->has_next()) {
+            const T* value = (const T*)(iter->get_value());
+            _update_min_max(*value);
+            iter->next();
         }
     }
 
-    ~InListPredicateBase() override {
-        if (should_delete) {
-            delete _values;
-        }
-    }
-
-    // Only for test
-    InListPredicateBase(uint32_t column_id, phmap::flat_hash_set<T>& values,
-                        T min_value = type_limit<T>::min(), T max_value = type_limit<T>::max(),
-                        bool is_opposite = false)
-            : ColumnPredicate(column_id, is_opposite),
-              _values(&values),
-              _min_value(min_value),
-              _max_value(max_value) {
-        should_delete = false;
-    }
+    ~InListPredicateBase() override = default;
 
     PredicateType type() const override { return PT; }
 
-    void evaluate(ColumnBlock* block, uint16_t* sel, uint16_t* size) const override {
-        if (block->is_nullable()) {
-            _base_evaluate<true>(block, sel, size);
-        } else {
-            _base_evaluate<false>(block, sel, size);
-        }
-    }
-
-    void evaluate_or(ColumnBlock* block, uint16_t* sel, uint16_t size, bool* flags) const override {
-        if (block->is_nullable()) {
-            _base_evaluate<true, false>(block, sel, size, flags);
-        } else {
-            _base_evaluate<false, false>(block, sel, size, flags);
-        }
-    }
-
-    void evaluate_and(ColumnBlock* block, uint16_t* sel, uint16_t size,
-                      bool* flags) const override {
-        if (block->is_nullable()) {
-            _base_evaluate<true, true>(block, sel, size, flags);
-        } else {
-            _base_evaluate<false, true>(block, sel, size, flags);
-        }
-    }
-
     Status evaluate(BitmapIndexIterator* iterator, uint32_t num_rows,
                     roaring::Roaring* result) const override {
         if (iterator == nullptr) {
@@ -215,9 +193,11 @@ public:
             *result -= null_bitmap;
         }
         roaring::Roaring indices;
-        for (auto value : *_values) {
+        HybridSetBase::IteratorBase* iter = _values->begin();
+        while (iter->has_next()) {
+            const void* value = iter->get_value();
             bool exact_match;
-            Status s = iterator->seek_dictionary(&value, &exact_match);
+            Status s = iterator->seek_dictionary(value, &exact_match);
             rowid_t seeked_ordinal = iterator->current_ordinal();
             if (!s.is<ErrorCode::NOT_FOUND>()) {
                 if (!s.ok()) {
@@ -229,6 +209,7 @@ public:
                     indices |= index;
                 }
             }
+            iter->next();
         }
 
         if constexpr (PT == PredicateType::IN_LIST) {
@@ -240,30 +221,72 @@ public:
         return Status::OK();
     }
 
+    Status evaluate(const Schema& schema, InvertedIndexIterator* iterator, uint32_t num_rows,
+                    roaring::Roaring* result) const override {
+        if (iterator == nullptr) {
+            return Status::OK();
+        }
+        auto column_desc = schema.column(_column_id);
+        std::string column_name = column_desc->name();
+        roaring::Roaring indices;
+        HybridSetBase::IteratorBase* iter = _values->begin();
+        while (iter->has_next()) {
+            const void* value = iter->get_value();
+            InvertedIndexQueryType query_type = InvertedIndexQueryType::EQUAL_QUERY;
+            roaring::Roaring index;
+            RETURN_IF_ERROR(iterator->read_from_inverted_index(column_name, value, query_type,
+                                                               num_rows, &index));
+            indices |= index;
+            iter->next();
+        }
+
+        // mask out null_bitmap, since NULL cmp VALUE will produce NULL
+        //  and be treated as false in WHERE
+        // keep it after query, since query will try to read null_bitmap and put it to cache
+        InvertedIndexQueryCacheHandle null_bitmap_cache_handle;
+        RETURN_IF_ERROR(iterator->read_null_bitmap(&null_bitmap_cache_handle));
+        std::shared_ptr<roaring::Roaring> null_bitmap = null_bitmap_cache_handle.get_bitmap();
+        if (null_bitmap) {
+            *result -= *null_bitmap;
+        }
+
+        if constexpr (PT == PredicateType::IN_LIST) {
+            *result &= indices;
+        } else {
+            *result -= indices;
+        }
+        return Status::OK();
+    }
+
     uint16_t evaluate(const vectorized::IColumn& column, uint16_t* sel,
                       uint16_t size) const override {
+        int64_t new_size = 0;
+
         if (column.is_nullable()) {
             auto* nullable_col =
                     vectorized::check_and_get_column<vectorized::ColumnNullable>(column);
-            auto& null_bitmap = reinterpret_cast<const vectorized::ColumnUInt8&>(
-                                        nullable_col->get_null_map_column())
-                                        .get_data();
+            auto& null_map = reinterpret_cast<const vectorized::ColumnUInt8&>(
+                                     nullable_col->get_null_map_column())
+                                     .get_data();
             auto& nested_col = nullable_col->get_nested_column();
 
             if (_opposite) {
-                return _base_evaluate<true, true>(&nested_col, &null_bitmap, sel, size);
+                new_size = _base_evaluate<true, true>(&nested_col, &null_map, sel, size);
             } else {
-                return _base_evaluate<true, false>(&nested_col, &null_bitmap, sel, size);
+                new_size = _base_evaluate<true, false>(&nested_col, &null_map, sel, size);
             }
         } else {
             if (_opposite) {
-                return _base_evaluate<false, true>(&column, nullptr, sel, size);
+                new_size = _base_evaluate<false, true>(&column, nullptr, sel, size);
             } else {
-                return _base_evaluate<false, false>(&column, nullptr, sel, size);
+                new_size = _base_evaluate<false, false>(&column, nullptr, sel, size);
             }
         }
+        _evaluated_rows += size;
+        _passed_rows += new_size;
+        return new_size;
     }
-
+    int get_filter_id() const override { return _values->get_filter_id(); }
     template <bool is_and>
     void _evaluate_bit(const vectorized::IColumn& column, const uint16_t* sel, uint16_t size,
                        bool* flags) const {
@@ -323,6 +346,17 @@ public:
         }
     }
 
+    bool evaluate_and(const StringRef* dict_words, const size_t count) const override {
+        for (size_t i = 0; i != count; ++i) {
+            const auto found = _values->find(dict_words[i].data, dict_words[i].size) ^ _opposite;
+            if (found == (PT == PredicateType::IN_LIST)) {
+                return true;
+            }
+        }
+
+        return false;
+    }
+
     bool evaluate_del(const std::pair<WrapperField*, WrapperField*>& statistic) const override {
         if (statistic.first->is_null() || statistic.second->is_null()) {
             return false;
@@ -347,20 +381,27 @@ public:
 
     bool evaluate_and(const segment_v2::BloomFilter* bf) const override {
         if constexpr (PT == PredicateType::IN_LIST) {
-            for (auto value : *_values) {
-                if constexpr (std::is_same_v<T, StringValue>) {
-                    if (bf->test_bytes(value.ptr, value.len)) {
+            // IN predicate can not use ngram bf, just return true to accept
+            if (bf->is_ngram_bf()) return true;
+            HybridSetBase::IteratorBase* iter = _values->begin();
+            while (iter->has_next()) {
+                if constexpr (std::is_same_v<T, StringRef>) {
+                    const StringRef* value = (const StringRef*)iter->get_value();
+                    if (bf->test_bytes(value->data, value->size)) {
                         return true;
                     }
                 } else if constexpr (Type == TYPE_DATE) {
-                    if (bf->test_bytes(reinterpret_cast<char*>(&value), sizeof(uint24_t))) {
+                    const void* value = iter->get_value();
+                    if (bf->test_bytes(reinterpret_cast<const char*>(value), sizeof(uint24_t))) {
                         return true;
                     }
                 } else {
-                    if (bf->test_bytes(reinterpret_cast<char*>(&value), sizeof(value))) {
+                    const T* value = (const T*)(iter->get_value());
+                    if (bf->test_bytes(reinterpret_cast<const char*>(value), sizeof(*value))) {
                         return true;
                     }
                 }
+                iter->next();
             }
             return false;
         } else {
@@ -369,80 +410,17 @@ public:
         }
     }
 
-    bool can_do_bloom_filter() const override { return PT == PredicateType::IN_LIST; }
+    bool can_do_bloom_filter(bool ngram) const override {
+        return PT == PredicateType::IN_LIST && !ngram;
+    }
 
 private:
     template <typename LeftT, typename RightT>
     bool _operator(const LeftT& lhs, const RightT& rhs) const {
-        if constexpr (Type == TYPE_BOOLEAN) {
-            DCHECK(_values->size() == 2);
-            return PT == PredicateType::IN_LIST;
-        } else if constexpr (PT == PredicateType::IN_LIST) {
+        if constexpr (PT == PredicateType::IN_LIST) {
             return lhs != rhs;
-        }
-        return lhs == rhs;
-    }
-
-    template <bool is_nullable>
-    void _base_evaluate(const ColumnBlock* block, uint16_t* sel, uint16_t* size) const {
-        uint16_t new_size = 0;
-        for (uint16_t i = 0; i < *size; ++i) {
-            uint16_t idx = sel[i];
-            sel[new_size] = idx;
-            if constexpr (Type == TYPE_DATE) {
-                T tmp_uint32_value = 0;
-                memcpy((char*)(&tmp_uint32_value), block->cell(idx).cell_ptr(), sizeof(uint24_t));
-                if constexpr (is_nullable) {
-                    new_size += _opposite ^
-                                (!block->cell(idx).is_null() &&
-                                 _operator(_values->find(tmp_uint32_value), _values->end()));
-                } else {
-                    new_size +=
-                            _opposite ^ _operator(_values->find(tmp_uint32_value), _values->end());
-                }
-            } else {
-                const T* cell_value = reinterpret_cast<const T*>(block->cell(idx).cell_ptr());
-                if constexpr (is_nullable) {
-                    new_size += _opposite ^ (!block->cell(idx).is_null() &&
-                                             _operator(_values->find(*cell_value), _values->end()));
-                } else {
-                    new_size += _opposite ^ _operator(_values->find(*cell_value), _values->end());
-                }
-            }
-        }
-        *size = new_size;
-    }
-
-    template <bool is_nullable, bool is_and>
-    void _base_evaluate(const ColumnBlock* block, const uint16_t* sel, uint16_t size,
-                        bool* flags) const {
-        for (uint16_t i = 0; i < size; ++i) {
-            if (!flags[i]) {
-                continue;
-            }
-
-            uint16_t idx = sel[i];
-            auto result = true;
-            if constexpr (Type == TYPE_DATE) {
-                T tmp_uint32_value = 0;
-                memcpy((char*)(&tmp_uint32_value), block->cell(idx).cell_ptr(), sizeof(uint24_t));
-                if constexpr (is_nullable) {
-                    result &= !block->cell(idx).is_null();
-                }
-                result &= _operator(_values->find(tmp_uint32_value), _values->end());
-            } else {
-                const T* cell_value = reinterpret_cast<const T*>(block->cell(idx).cell_ptr());
-                if constexpr (is_nullable) {
-                    result &= !block->cell(idx).is_null();
-                }
-                result &= _operator(_values->find(*cell_value), _values->end());
-            }
-
-            if constexpr (is_and) {
-                flags[i] &= _opposite ^ result;
-            } else {
-                flags[i] |= _opposite ^ result;
-            }
+        } else {
+            return lhs == rhs;
         }
     }
 
@@ -453,7 +431,7 @@ private:
         uint16_t new_size = 0;
 
         if (column->is_column_dictionary()) {
-            if constexpr (std::is_same_v<T, StringValue>) {
+            if constexpr (std::is_same_v<T, StringRef>) {
                 auto* nested_col_ptr = vectorized::check_and_get_column<
                         vectorized::ColumnDictionary<vectorized::Int32>>(column);
                 auto& data_array = nested_col_ptr->get_data();
@@ -461,7 +439,7 @@ private:
                 DCHECK((segid.first.hi | segid.first.mi | segid.first.lo) != 0);
                 auto& value_in_dict_flags = _segment_id_to_value_in_dict_flags[segid];
                 if (value_in_dict_flags.empty()) {
-                    nested_col_ptr->find_codes(*_values, value_in_dict_flags);
+                    nested_col_ptr->find_codes(_values.get(), value_in_dict_flags);
                 }
 
                 CHECK(value_in_dict_flags.size() == nested_col_ptr->dict_size())
@@ -492,38 +470,25 @@ private:
                     }
                 }
             } else {
-                LOG(FATAL) << "column_dictionary must use StringValue predicate.";
+                LOG(FATAL) << "column_dictionary must use StringRef predicate.";
             }
         } else {
-            auto* nested_col_ptr = vectorized::check_and_get_column<
-                    vectorized::PredicateColumnType<PredicateEvaluateType<Type>>>(column);
-            auto& data_array = nested_col_ptr->get_data();
+            auto& pred_col =
+                    vectorized::check_and_get_column<
+                            vectorized::PredicateColumnType<PredicateEvaluateType<Type>>>(column)
+                            ->get_data();
+            auto pred_col_data = pred_col.data();
 
-            for (uint16_t i = 0; i < size; i++) {
-                uint16_t idx = sel[i];
-                if constexpr (is_nullable) {
-                    if ((*null_map)[idx]) {
-                        if constexpr (is_opposite) {
-                            sel[new_size++] = idx;
-                        }
-                        continue;
-                    }
-                }
-
-                if constexpr (!is_opposite) {
-                    if (_operator(_values->find(reinterpret_cast<const T&>(data_array[idx])),
-                                  _values->end())) {
-                        sel[new_size++] = idx;
-                    }
-                } else {
-                    if (!_operator(_values->find(reinterpret_cast<const T&>(data_array[idx])),
-                                   _values->end())) {
-                        sel[new_size++] = idx;
-                    }
-                }
-            }
+#define EVALUATE_WITH_NULL_IMPL(IDX) \
+    is_opposite ^                    \
+            (!(*null_map)[IDX] &&    \
+             _operator(_values->find(reinterpret_cast<const T*>(&pred_col_data[IDX])), false))
+#define EVALUATE_WITHOUT_NULL_IMPL(IDX) \
+    is_opposite ^ _operator(_values->find(reinterpret_cast<const T*>(&pred_col_data[IDX])), false)
+            EVALUATE_BY_SELECTOR(EVALUATE_WITH_NULL_IMPL, EVALUATE_WITHOUT_NULL_IMPL)
+#undef EVALUATE_WITH_NULL_IMPL
+#undef EVALUATE_WITHOUT_NULL_IMPL
         }
-
         return new_size;
     }
 
@@ -532,14 +497,14 @@ private:
                             const vectorized::PaddedPODArray<vectorized::UInt8>* null_map,
                             const uint16_t* sel, uint16_t size, bool* flags) const {
         if (column->is_column_dictionary()) {
-            if constexpr (std::is_same_v<T, StringValue>) {
+            if constexpr (std::is_same_v<T, StringRef>) {
                 auto* nested_col_ptr = vectorized::check_and_get_column<
                         vectorized::ColumnDictionary<vectorized::Int32>>(column);
                 auto& data_array = nested_col_ptr->get_data();
                 auto& value_in_dict_flags =
                         _segment_id_to_value_in_dict_flags[column->get_rowset_segment_id()];
                 if (value_in_dict_flags.empty()) {
-                    nested_col_ptr->find_codes(*_values, value_in_dict_flags);
+                    nested_col_ptr->find_codes(_values.get(), value_in_dict_flags);
                 }
 
                 for (uint16_t i = 0; i < size; i++) {
@@ -568,7 +533,7 @@ private:
                     }
                 }
             } else {
-                LOG(FATAL) << "column_dictionary must use StringValue predicate.";
+                LOG(FATAL) << "column_dictionary must use StringRef predicate.";
             }
         } else {
             auto* nested_col_ptr = vectorized::check_and_get_column<
@@ -591,14 +556,14 @@ private:
 
                 if constexpr (!is_opposite) {
                     if (is_and ^
-                        _operator(_values->find(reinterpret_cast<const T&>(data_array[idx])),
-                                  _values->end())) {
+                        _operator(_values->find(reinterpret_cast<const T*>(&data_array[idx])),
+                                  false)) {
                         flags[i] = !is_and;
                     }
                 } else {
                     if (is_and ^
-                        !_operator(_values->find(reinterpret_cast<const T&>(data_array[idx])),
-                                   _values->end())) {
+                        !_operator(_values->find(reinterpret_cast<const T*>(&data_array[idx])),
+                                   false)) {
                         flags[i] = !is_and;
                     }
                 }
@@ -621,8 +586,7 @@ private:
         }
     }
 
-    phmap::flat_hash_set<T>* _values;
-    bool should_delete = true;
+    std::shared_ptr<HybridSetBase> _values;
     mutable std::map<std::pair<RowsetId, uint32_t>, std::vector<vectorized::UInt8>>
             _segment_id_to_value_in_dict_flags;
     T _min_value;
@@ -632,4 +596,110 @@ private:
     std::list<std::string> _temp_datas;
 };
 
+template <PrimitiveType Type, PredicateType PT, typename ConditionType, typename ConvertFunc,
+          size_t N = 0>
+ColumnPredicate* _create_in_list_predicate(uint32_t column_id, const ConditionType& conditions,
+                                           const ConvertFunc& convert, bool is_opposite = false,
+                                           const TabletColumn* col = nullptr,
+                                           vectorized::Arena* arena = nullptr) {
+    using T = typename PredicatePrimitiveTypeTraits<Type>::PredicateFieldType;
+    if constexpr (N >= 1 && N <= FIXED_CONTAINER_MAX_SIZE) {
+        using Set = std::conditional_t<
+                std::is_same_v<T, StringRef>, StringSet<FixedContainer<std::string, N>>,
+                HybridSet<Type, FixedContainer<T, N>,
+                          vectorized::PredicateColumnType<PredicateEvaluateType<Type>>>>;
+        return new InListPredicateBase<Type, PT, Set>(column_id, conditions, convert, is_opposite,
+                                                      col, arena);
+    } else {
+        using Set = std::conditional_t<
+                std::is_same_v<T, StringRef>, StringSet<DynamicContainer<std::string>>,
+                HybridSet<Type, DynamicContainer<T>,
+                          vectorized::PredicateColumnType<PredicateEvaluateType<Type>>>>;
+        return new InListPredicateBase<Type, PT, Set>(column_id, conditions, convert, is_opposite,
+                                                      col, arena);
+    }
+}
+
+template <PrimitiveType Type, PredicateType PT, typename ConditionType, typename ConvertFunc>
+ColumnPredicate* create_in_list_predicate(uint32_t column_id, const ConditionType& conditions,
+                                          const ConvertFunc& convert, bool is_opposite = false,
+                                          const TabletColumn* col = nullptr,
+                                          vectorized::Arena* arena = nullptr) {
+    if (conditions.size() == 1) {
+        return _create_in_list_predicate<Type, PT, ConditionType, ConvertFunc, 1>(
+                column_id, conditions, convert, is_opposite, col, arena);
+    } else if (conditions.size() == 2) {
+        return _create_in_list_predicate<Type, PT, ConditionType, ConvertFunc, 2>(
+                column_id, conditions, convert, is_opposite, col, arena);
+    } else if (conditions.size() == 3) {
+        return _create_in_list_predicate<Type, PT, ConditionType, ConvertFunc, 3>(
+                column_id, conditions, convert, is_opposite, col, arena);
+    } else if (conditions.size() == 4) {
+        return _create_in_list_predicate<Type, PT, ConditionType, ConvertFunc, 4>(
+                column_id, conditions, convert, is_opposite, col, arena);
+    } else if (conditions.size() == 5) {
+        return _create_in_list_predicate<Type, PT, ConditionType, ConvertFunc, 5>(
+                column_id, conditions, convert, is_opposite, col, arena);
+    } else if (conditions.size() == 6) {
+        return _create_in_list_predicate<Type, PT, ConditionType, ConvertFunc, 6>(
+                column_id, conditions, convert, is_opposite, col, arena);
+    } else if (conditions.size() == 7) {
+        return _create_in_list_predicate<Type, PT, ConditionType, ConvertFunc, 7>(
+                column_id, conditions, convert, is_opposite, col, arena);
+    } else if (conditions.size() == FIXED_CONTAINER_MAX_SIZE) {
+        return _create_in_list_predicate<Type, PT, ConditionType, ConvertFunc,
+                                         FIXED_CONTAINER_MAX_SIZE>(column_id, conditions, convert,
+                                                                   is_opposite, col, arena);
+    } else {
+        return _create_in_list_predicate<Type, PT, ConditionType, ConvertFunc>(
+                column_id, conditions, convert, is_opposite, col, arena);
+    }
+}
+
+template <PrimitiveType Type, PredicateType PT, size_t N = 0>
+ColumnPredicate* _create_in_list_predicate(uint32_t column_id,
+                                           const std::shared_ptr<HybridSetBase>& hybrid_set,
+                                           size_t char_length = 0) {
+    using T = typename PredicatePrimitiveTypeTraits<Type>::PredicateFieldType;
+    if constexpr (N >= 1 && N <= FIXED_CONTAINER_MAX_SIZE) {
+        using Set = std::conditional_t<
+                std::is_same_v<T, StringRef>, StringSet<FixedContainer<std::string, N>>,
+                HybridSet<Type, FixedContainer<T, N>,
+                          vectorized::PredicateColumnType<PredicateEvaluateType<Type>>>>;
+        return new InListPredicateBase<Type, PT, Set>(column_id, hybrid_set, char_length);
+    } else {
+        using Set = std::conditional_t<
+                std::is_same_v<T, StringRef>, StringSet<DynamicContainer<std::string>>,
+                HybridSet<Type, DynamicContainer<T>,
+                          vectorized::PredicateColumnType<PredicateEvaluateType<Type>>>>;
+        return new InListPredicateBase<Type, PT, Set>(column_id, hybrid_set, char_length);
+    }
+}
+
+template <PrimitiveType Type, PredicateType PT>
+ColumnPredicate* create_in_list_predicate(uint32_t column_id,
+                                          const std::shared_ptr<HybridSetBase>& hybrid_set,
+                                          size_t char_length = 0) {
+    if (hybrid_set->size() == 1) {
+        return _create_in_list_predicate<Type, PT, 1>(column_id, hybrid_set, char_length);
+    } else if (hybrid_set->size() == 2) {
+        return _create_in_list_predicate<Type, PT, 2>(column_id, hybrid_set, char_length);
+    } else if (hybrid_set->size() == 3) {
+        return _create_in_list_predicate<Type, PT, 3>(column_id, hybrid_set, char_length);
+    } else if (hybrid_set->size() == 4) {
+        return _create_in_list_predicate<Type, PT, 4>(column_id, hybrid_set, char_length);
+    } else if (hybrid_set->size() == 5) {
+        return _create_in_list_predicate<Type, PT, 5>(column_id, hybrid_set, char_length);
+    } else if (hybrid_set->size() == 6) {
+        return _create_in_list_predicate<Type, PT, 6>(column_id, hybrid_set, char_length);
+    } else if (hybrid_set->size() == 7) {
+        return _create_in_list_predicate<Type, PT, 7>(column_id, hybrid_set, char_length);
+    } else if (hybrid_set->size() == FIXED_CONTAINER_MAX_SIZE) {
+        return _create_in_list_predicate<Type, PT, FIXED_CONTAINER_MAX_SIZE>(column_id, hybrid_set,
+                                                                             char_length);
+    } else {
+        return _create_in_list_predicate<Type, PT>(column_id, hybrid_set, char_length);
+    }
+}
+
 } //namespace doris
