@@ -60,9 +60,15 @@ static const uint32_t OLAP_STRING_MAX_LENGTH = 2147483647;
 // the max length supported for jsonb type 2G
 static const uint32_t OLAP_JSONB_MAX_LENGTH = 2147483647;
 
+// the max length supported for struct, but excluding the length of its subtypes.
+static const uint16_t OLAP_STRUCT_MAX_LENGTH = 65535;
+
 // the max length supported for array
 static const uint16_t OLAP_ARRAY_MAX_LENGTH = 65535;
 
+// the max length supported for map
+static const uint16_t OLAP_MAP_MAX_LENGTH = 65535;
+
 // the max bytes for stored string length
 using StringOffsetType = uint32_t;
 using StringLengthType = uint32_t;
@@ -92,6 +98,17 @@ static const std::string PENDING_DELTA_PREFIX = "pending_delta";
 static const std::string INCREMENTAL_DELTA_PREFIX = "incremental_delta";
 static const std::string CLONE_PREFIX = "clone";
 
+// define paths
+static inline std::string remote_tablet_path(int64_t tablet_id) {
+    // data/{tablet_id}
+    return fmt::format("{}/{}", DATA_PREFIX, tablet_id);
+}
+static inline std::string remote_tablet_meta_path(int64_t tablet_id, int64_t replica_id,
+                                                  int64_t cooldown_term) {
+    // data/{tablet_id}/{replica_id}.{cooldown_term}.meta
+    return fmt::format("{}/{}.{}.meta", remote_tablet_path(tablet_id), replica_id, cooldown_term);
+}
+
 static const std::string TABLET_UID = "tablet_uid";
 static const std::string STORAGE_NAME = "storage_name";
 
@@ -108,14 +125,19 @@ static const uint64_t GB_EXCHANGE_BYTE = 1024 * 1024 * 1024;
 // bloom filter fpp
 static const double BLOOM_FILTER_DEFAULT_FPP = 0.05;
 
-#define OLAP_GOTO(label) goto label
-
 enum ColumnFamilyIndex {
     DEFAULT_COLUMN_FAMILY_INDEX = 0,
     DORIS_COLUMN_FAMILY_INDEX,
     META_COLUMN_FAMILY_INDEX,
 };
 
+enum class DataWriteType {
+    TYPE_DEFAULT = 0,
+    TYPE_DIRECT,
+    TYPE_SCHEMA_CHANGE,
+    TYPE_COMPACTION,
+};
+
 static const char* const HINIS_KEY_SEPARATOR = ";";
 static const char* const HINIS_KEY_PAIR_SEPARATOR = "|";
 static const char* const HINIS_KEY_GROUP_SEPARATOR = "&";
@@ -133,35 +155,6 @@ const std::string ROWSET_ID_PREFIX = "s_";
 const std::string REMOTE_ROWSET_GC_PREFIX = "gc_";
 const std::string REMOTE_TABLET_GC_PREFIX = "tgc_";
 
-#if defined(__GNUC__)
-#define OLAP_LIKELY(x) __builtin_expect((x), 1)
-#define OLAP_UNLIKELY(x) __builtin_expect((x), 0)
-#else
-#define OLAP_LIKELY(x)
-#define OLAP_UNLIKELY(x)
-#endif
-
-#ifndef RETURN_NOT_OK
-#define RETURN_NOT_OK(s)               \
-    do {                               \
-        Status _s = (s);               \
-        if (OLAP_UNLIKELY(!_s.ok())) { \
-            return _s;                 \
-        }                              \
-    } while (0);
-#endif
-
-#ifndef RETURN_NOT_OK_LOG
-#define RETURN_NOT_OK_LOG(s, msg)                          \
-    do {                                                   \
-        Status _s = (s);                                   \
-        if (OLAP_UNLIKELY(!_s)) {                          \
-            LOG(WARNING) << (msg) << "[res=" << _s << "]"; \
-            return _s;                                     \
-        }                                                  \
-    } while (0);
-#endif
-
 // Declare copy constructor and equal operator as private
 #ifndef DISALLOW_COPY_AND_ASSIGN
 #define DISALLOW_COPY_AND_ASSIGN(type_t) \
@@ -169,29 +162,6 @@ const std::string REMOTE_TABLET_GC_PREFIX = "tgc_";
     type_t(const type_t&);
 #endif
 
-// 没有使用的变量不报warning
-#define OLAP_UNUSED_ARG(a) (void)(a)
-
-// thread-safe(gcc only) method for obtaining singleton
-#define DECLARE_SINGLETON(classname)     \
-public:                                  \
-    static classname* instance() {       \
-        classname* p_instance = nullptr; \
-        try {                            \
-            static classname s_instance; \
-            p_instance = &s_instance;    \
-        } catch (...) {                  \
-            p_instance = nullptr;        \
-        }                                \
-        return p_instance;               \
-    }                                    \
-                                         \
-protected:                               \
-    classname();                         \
-                                         \
-private:                                 \
-    ~classname();
-
 #define SAFE_DELETE(ptr)      \
     do {                      \
         if (nullptr != ptr) { \
