@@ -18,25 +18,32 @@
 #ifndef DORIS_SRC_OLAP_ROWSET_BETA_ROWSET_H_
 #define DORIS_SRC_OLAP_ROWSET_BETA_ROWSET_H_
 
-#include <cstdint>
-#include <string>
+#include <stddef.h>
 
-#include "olap/olap_common.h"
-#include "olap/olap_define.h"
+#include <cstdint>
+#include <memory>
+#include <string>
+#include <vector>
+
+#include "common/status.h"
 #include "olap/rowset/rowset.h"
 #include "olap/rowset/rowset_meta.h"
 #include "olap/rowset/rowset_reader.h"
 #include "olap/rowset/segment_v2/segment.h"
+#include "olap/tablet_schema.h"
 
 namespace doris {
 
-class BetaRowsetReader;
-class RowsetFactory;
-
 class BetaRowset;
+
+namespace io {
+class RemoteFileSystem;
+} // namespace io
+struct RowsetId;
+
 using BetaRowsetSharedPtr = std::shared_ptr<BetaRowset>;
 
-class BetaRowset : public Rowset {
+class BetaRowset final : public Rowset {
 public:
     virtual ~BetaRowset();
 
@@ -46,8 +53,7 @@ public:
 
     std::string segment_cache_path(int segment_id);
 
-    static std::string segment_cache_path(const std::string& rowset_dir, const RowsetId& rowset_id,
-                                          int segment_id);
+    static bool is_segment_cache_dir(const std::string& cache_dir);
 
     static std::string segment_file_path(const std::string& rowset_dir, const RowsetId& rowset_id,
                                          int segment_id);
@@ -62,16 +68,11 @@ public:
     static std::string remote_segment_path(int64_t tablet_id, const std::string& rowset_id,
                                            int segment_id);
 
-    static std::string remote_tablet_path(int64_t tablet_id);
-
-    Status split_range(const RowCursor& start_key, const RowCursor& end_key,
-                       uint64_t request_block_row_count, size_t key_num,
-                       std::vector<OlapTuple>* ranges) override;
-
     Status remove() override;
 
     Status link_files_to(const std::string& dir, RowsetId new_rowset_id,
-                         size_t new_rowset_start_seg_id = 0) override;
+                         size_t new_rowset_start_seg_id = 0,
+                         std::set<int32_t>* without_index_uids = nullptr) override;
 
     Status copy_files_to(const std::string& dir, const RowsetId& new_rowset_id) override;
 
@@ -80,7 +81,7 @@ public:
     // only applicable to alpha rowset, no op here
     Status remove_old_files(std::vector<std::string>* files_to_remove) override {
         return Status::OK();
-    };
+    }
 
     bool check_path(const std::string& path) override;
 
@@ -93,9 +94,11 @@ public:
 
     Status get_segments_size(std::vector<size_t>* segments_size);
 
+    [[nodiscard]] virtual Status add_to_binlog() override;
+
 protected:
-    BetaRowset(TabletSchemaSPtr schema, const std::string& tablet_path,
-               RowsetMetaSharedPtr rowset_meta);
+    BetaRowset(const TabletSchemaSPtr& schema, const std::string& tablet_path,
+               const RowsetMetaSharedPtr& rowset_meta);
 
     // init segment groups
     Status init() override;
