@@ -17,15 +17,17 @@
 
 #include "olap/rowset/rowset.h"
 
+#include <gen_cpp/olap_file.pb.h>
+
+#include "olap/olap_define.h"
 #include "olap/tablet_schema.h"
-#include "olap/tablet_schema_cache.h"
 #include "util/time.h"
 
 namespace doris {
 
-Rowset::Rowset(TabletSchemaSPtr schema, const std::string& tablet_path,
-               RowsetMetaSharedPtr rowset_meta)
-        : _tablet_path(tablet_path), _rowset_meta(std::move(rowset_meta)), _refs_by_reader(0) {
+Rowset::Rowset(const TabletSchemaSPtr& schema, const std::string& tablet_path,
+               const RowsetMetaSharedPtr& rowset_meta)
+        : _tablet_path(tablet_path), _rowset_meta(rowset_meta), _refs_by_reader(0) {
     _is_pending = !_rowset_meta->has_version();
     if (_is_pending) {
         _is_cumulative = false;
@@ -45,12 +47,12 @@ Status Rowset::load(bool use_cache) {
     }
     {
         // before lock, if rowset state is ROWSET_UNLOADING, maybe it is doing do_close in release
-        std::lock_guard<std::mutex> load_lock(_lock);
+        std::lock_guard load_lock(_lock);
         // after lock, if rowset state is ROWSET_UNLOADING, it is ok to return
         if (_rowset_state_machine.rowset_state() == ROWSET_UNLOADED) {
             // first do load, then change the state
-            RETURN_NOT_OK(do_load(use_cache));
-            RETURN_NOT_OK(_rowset_state_machine.on_load());
+            RETURN_IF_ERROR(do_load(use_cache));
+            RETURN_IF_ERROR(_rowset_state_machine.on_load());
         }
     }
     // load is done
@@ -71,14 +73,24 @@ void Rowset::make_visible(Version version) {
 
     if (_rowset_meta->has_delete_predicate()) {
         _rowset_meta->mutable_delete_predicate()->set_version(version.first);
-        return;
     }
-    make_visible_extra(version);
 }
 
 bool Rowset::check_rowset_segment() {
-    std::lock_guard<std::mutex> load_lock(_lock);
+    std::lock_guard load_lock(_lock);
     return check_current_rowset_segment();
 }
 
+void Rowset::merge_rowset_meta(const RowsetMetaSharedPtr& other) {
+    _rowset_meta->set_num_segments(num_segments() + other->num_segments());
+    _rowset_meta->set_num_rows(num_rows() + other->num_rows());
+    _rowset_meta->set_data_disk_size(data_disk_size() + other->data_disk_size());
+    _rowset_meta->set_index_disk_size(index_disk_size() + other->index_disk_size());
+    std::vector<KeyBoundsPB> key_bounds;
+    other->get_segments_key_bounds(&key_bounds);
+    for (auto key_bound : key_bounds) {
+        _rowset_meta->add_segment_key_bounds(key_bound);
+    }
+}
+
 } // namespace doris
