@@ -53,26 +53,39 @@ public:
                        const RowsetMetaPB& rowset_meta_pb, bool enable_binlog);
     static Status save(OlapMeta* meta, TabletUid tablet_uid, const RowsetId& rowset_id,
                        const RowsetMetaPB& rowset_meta_pb);
+
     static std::vector<std::string> get_binlog_filenames(OlapMeta* meta, TabletUid tablet_uid,
                                                          std::string_view binlog_version,
                                                          int64_t segment_idx);
     static std::pair<std::string, int64_t> get_binlog_info(OlapMeta* meta, TabletUid tablet_uid,
                                                            std::string_view binlog_version);
-    static std::string get_binlog_rowset_meta(OlapMeta* meta, TabletUid tablet_uid,
+    static std::string get_rowset_binlog_meta(OlapMeta* meta, TabletUid tablet_uid,
                                               std::string_view binlog_version,
                                               std::string_view rowset_id);
+    static Status get_rowset_binlog_metas(OlapMeta* meta, const TabletUid tablet_uid,
+                                          const std::vector<int64_t>& binlog_versions,
+                                          RowsetBinlogMetasPB* metas_pb);
+    static Status remove_binlog(OlapMeta* meta, const std::string& suffix);
+    static Status ingest_binlog_metas(OlapMeta* meta, TabletUid tablet_uid,
+                                      RowsetBinlogMetasPB* metas_pb);
+    static Status traverse_rowset_metas(OlapMeta* meta,
+                                        std::function<bool(const TabletUid&, const RowsetId&,
+                                                           const std::string&)> const& collector);
+    static Status traverse_binlog_metas(
+            OlapMeta* meta, std::function<bool(const string&, const string&, bool)> const& func);
 
     static Status remove(OlapMeta* meta, TabletUid tablet_uid, const RowsetId& rowset_id);
 
-    static Status traverse_rowset_metas(
-            OlapMeta* meta,
-            std::function<bool(const TabletUid&, const RowsetId&, const std::string&)> const& func);
-
     static Status load_json_rowset_meta(OlapMeta* meta, const std::string& rowset_meta_path);
 
 private:
     static Status _save_with_binlog(OlapMeta* meta, TabletUid tablet_uid, const RowsetId& rowset_id,
                                     const RowsetMetaPB& rowset_meta_pb);
+    static Status _get_rowset_binlog_metas(OlapMeta* meta, const TabletUid tablet_uid,
+                                           const std::vector<int64_t>& binlog_versions,
+                                           RowsetBinlogMetasPB* metas_pb);
+    static Status _get_all_rowset_binlog_metas(OlapMeta* meta, const TabletUid tablet_uid,
+                                               RowsetBinlogMetasPB* metas_pb);
 };
 
 } // namespace doris
