@@ -17,8 +17,7 @@
 
 #pragma once
 
-#include "common/status.h"     // for Status
-#include "olap/column_block.h" // for ColumnBlockView
+#include "common/status.h" // for Status
 #include "vec/columns/column.h"
 
 namespace doris {
@@ -72,16 +71,6 @@ public:
         return step;
     }
 
-    // Fetch the next vector of values from the page into 'column_vector_view'.
-    // The output vector must have space for up to n cells.
-    //
-    // Return the size of read entries .
-    //
-    // In the case that the values are themselves references
-    // to other memory (eg Slices), the referred-to memory is
-    // allocated in the column_vector_view's mem_pool.
-    virtual Status next_batch(size_t* n, ColumnBlockView* dst) = 0;
-
     virtual Status next_batch(size_t* n, vectorized::MutableColumnPtr& dst) = 0;
 
     virtual Status read_by_rowids(const rowid_t* rowids, ordinal_t page_first_ordinal, size_t* n,
@@ -92,8 +81,8 @@ public:
     // Same as `next_batch` except for not moving forward the cursor.
     // When read array's ordinals in `ArrayFileColumnIterator`, we want to read one extra ordinal
     // but do not want to move forward the cursor.
-    virtual Status peek_next_batch(size_t* n, ColumnBlockView* dst) {
-        return Status::NotSupported("peek_next_batch");
+    virtual Status peek_next_batch(size_t* n, vectorized::MutableColumnPtr& dst) {
+        return Status::NotSupported("not implement vec op now");
     }
 
     // Return the number of elements in this page.
