@@ -77,6 +77,7 @@
 #include "util/parse_util.h"
 #include "util/pretty_printer.h"
 #include "util/threadpool.h"
+#include "util/timezone_utils.h"
 #include "vec/exec/scan/scanner_scheduler.h"
 #include "vec/runtime/vdata_stream_mgr.h"
 
@@ -105,10 +106,6 @@ Status ExecEnv::_init(const std::vector<StorePath>& store_paths) {
         return Status::OK();
     }
     _store_paths = store_paths;
-    // path_name => path_index
-    for (int i = 0; i < store_paths.size(); i++) {
-        _store_path_map[store_paths[i].path] = i;
-    }
 
     _external_scan_context_mgr = new ExternalScanContextMgr(this);
     _vstream_mgr = new doris::vectorized::VDataStreamMgr();
@@ -120,6 +117,9 @@ Status ExecEnv::_init(const std::vector<StorePath>& store_paths) {
 
     TimezoneUtils::load_timezone_names();
 
+    _global_zone_cache = std::make_unique<vectorized::ZoneList>();
+    TimezoneUtils::load_timezones_to_cache(*_global_zone_cache);
+
     ThreadPoolBuilder("SendBatchThreadPool")
             .set_min_threads(config::send_batch_thread_pool_thread_num)
             .set_max_threads(config::send_batch_thread_pool_thread_num)
