@@ -17,18 +17,28 @@
 
 #include "runtime/routine_load/data_consumer.h"
 
+#include <gen_cpp/Types_types.h>
+#include <gen_cpp/internal_service.pb.h>
+#include <librdkafka/rdkafkacpp.h>
+
 #include <algorithm>
-#include <functional>
+// IWYU pragma: no_include <bits/chrono.h>
+#include <chrono> // IWYU pragma: keep
 #include <string>
+#include <thread>
+#include <utility>
 #include <vector>
 
+#include "common/config.h"
 #include "common/status.h"
-#include "gen_cpp/internal_service.pb.h"
 #include "gutil/strings/split.h"
+#include "runtime/exec_env.h"
 #include "runtime/small_file_mgr.h"
 #include "service/backend_options.h"
+#include "util/blocking_queue.hpp"
 #include "util/defer_op.h"
 #include "util/stopwatch.hpp"
+#include "util/string_util.h"
 #include "util/uid_util.h"
 
 namespace doris {
@@ -36,7 +46,7 @@ namespace doris {
 static const std::string PROP_GROUP_ID = "group.id";
 // init kafka consumer will only set common configs such as
 // brokers, groupid
-Status KafkaDataConsumer::init(StreamLoadContext* ctx) {
+Status KafkaDataConsumer::init(std::shared_ptr<StreamLoadContext> ctx) {
     std::unique_lock<std::mutex> l(_lock);
     if (_init) {
         // this consumer has already been initialized.
@@ -139,7 +149,7 @@ Status KafkaDataConsumer::init(StreamLoadContext* ctx) {
 
 Status KafkaDataConsumer::assign_topic_partitions(
         const std::map<int32_t, int64_t>& begin_partition_offset, const std::string& topic,
-        StreamLoadContext* ctx) {
+        std::shared_ptr<StreamLoadContext> ctx) {
     DCHECK(_k_consumer);
     // create TopicPartitions
     std::stringstream ss;
@@ -230,6 +240,7 @@ Status KafkaDataConsumer::group_consume(BlockingQueue<RdKafka::Message*>* queue,
                 std::this_thread::sleep_for(std::chrono::milliseconds(200));
                 break;
             }
+            [[fallthrough]];
         default:
             LOG(WARNING) << "kafka consume failed: " << _id << ", msg: " << msg->errstr();
             done = true;
@@ -379,7 +390,7 @@ Status KafkaDataConsumer::get_latest_offsets_for_partitions(
     return Status::OK();
 }
 
-Status KafkaDataConsumer::cancel(StreamLoadContext* ctx) {
+Status KafkaDataConsumer::cancel(std::shared_ptr<StreamLoadContext> ctx) {
     std::unique_lock<std::mutex> l(_lock);
     if (!_init) {
         return Status::InternalError("consumer is not initialized");
@@ -412,7 +423,7 @@ Status KafkaDataConsumer::commit(std::vector<RdKafka::TopicPartition*>& offset)
 
 // if the kafka brokers and topic are same,
 // we considered this consumer as matched, thus can be reused.
-bool KafkaDataConsumer::match(StreamLoadContext* ctx) {
+bool KafkaDataConsumer::match(std::shared_ptr<StreamLoadContext> ctx) {
     if (ctx->load_src_type != TLoadSourceType::KAFKA) {
         return false;
     }
