@@ -17,11 +17,13 @@
 
 #pragma once
 
-#include <gutil/macros.h>
+#include <butil/macros.h>
 
 #include <string>
 #include <vector>
 
+#include "gen_cpp/Types_types.h"
+
 namespace doris {
 
 class CIDR;
@@ -29,14 +31,21 @@ class CIDR;
 class BackendOptions {
 public:
     static bool init();
-    static std::string get_localhost();
+    static const std::string& get_localhost();
+    static TBackend get_local_backend();
+    static void set_localhost(const std::string& host);
+    static bool is_bind_ipv6();
+    static const char* get_service_bind_address();
+    static const char* get_service_bind_address_without_bracket();
 
 private:
     static bool analyze_priority_cidrs();
     static bool is_in_prior_network(const std::string& ip);
 
     static std::string _s_localhost;
+    static TBackend _backend;
     static std::vector<CIDR> _s_priority_cidrs;
+    static bool _bind_ipv6;
 
     DISALLOW_COPY_AND_ASSIGN(BackendOptions);
 };
