@@ -55,6 +55,7 @@
 #include "common/status.h"
 #include "gutil/integral_types.h"
 #include "http/http_client.h"
+#include "io/fs/local_file_system.h"
 #include "io/fs/stream_load_pipe.h"
 #include "io/io_common.h"
 #include "olap/data_dir.h"
@@ -110,12 +111,12 @@
 #include "vec/core/block.h"
 #include "vec/core/column_with_type_and_name.h"
 #include "vec/data_types/data_type.h"
+#include "vec/exec/format/avro//avro_jni_reader.h"
 #include "vec/exec/format/csv/csv_reader.h"
 #include "vec/exec/format/generic_reader.h"
 #include "vec/exec/format/json/new_json_reader.h"
 #include "vec/exec/format/orc/vorc_reader.h"
 #include "vec/exec/format/parquet/vparquet_reader.h"
-#include "vec/exec/scan/avro_jni_reader.h"
 #include "vec/jsonb/serialize.h"
 #include "vec/runtime/vdata_stream_mgr.h"
 
@@ -273,6 +274,7 @@ void PInternalServiceImpl::tablet_writer_open(google::protobuf::RpcController* c
     });
     if (!ret) {
         offer_failed(response, done, _light_work_pool);
+        return;
     }
 }
 
@@ -285,6 +287,7 @@ void PInternalServiceImpl::exec_plan_fragment(google::protobuf::RpcController* c
     });
     if (!ret) {
         offer_failed(response, done, _light_work_pool);
+        return;
     }
 }
 
@@ -321,6 +324,7 @@ void PInternalServiceImpl::exec_plan_fragment_prepare(google::protobuf::RpcContr
     });
     if (!ret) {
         offer_failed(response, done, _light_work_pool);
+        return;
     }
 }
 
@@ -337,6 +341,7 @@ void PInternalServiceImpl::exec_plan_fragment_start(google::protobuf::RpcControl
     });
     if (!ret) {
         offer_failed(result, done, _light_work_pool);
+        return;
     }
 }
 
@@ -349,6 +354,7 @@ void PInternalServiceImpl::tablet_writer_add_block(google::protobuf::RpcControll
     });
     if (!ret) {
         offer_failed(response, done, _heavy_work_pool);
+        return;
     }
 }
 
@@ -370,6 +376,7 @@ void PInternalServiceImpl::tablet_writer_add_block_by_http(
     });
     if (!ret) {
         offer_failed(response, done, _heavy_work_pool);
+        return;
     }
 }
 
@@ -399,6 +406,7 @@ void PInternalServiceImpl::_tablet_writer_add_block(google::protobuf::RpcControl
     });
     if (!ret) {
         offer_failed(response, done, _heavy_work_pool);
+        return;
     }
 }
 
@@ -420,6 +428,7 @@ void PInternalServiceImpl::tablet_writer_cancel(google::protobuf::RpcController*
     });
     if (!ret) {
         offer_failed(response, done, _light_work_pool);
+        return;
     }
 }
 
@@ -497,6 +506,7 @@ void PInternalServiceImpl::cancel_plan_fragment(google::protobuf::RpcController*
     });
     if (!ret) {
         offer_failed(result, done, _light_work_pool);
+        return;
     }
 }
 
@@ -510,6 +520,7 @@ void PInternalServiceImpl::fetch_data(google::protobuf::RpcController* controlle
     });
     if (!ret) {
         offer_failed(result, done, _heavy_work_pool);
+        return;
     }
 }
 
@@ -558,6 +569,8 @@ void PInternalServiceImpl::fetch_table_schema(google::protobuf::RpcController* c
         case TFileFormatType::FORMAT_CSV_GZ:
         case TFileFormatType::FORMAT_CSV_BZ2:
         case TFileFormatType::FORMAT_CSV_LZ4FRAME:
+        case TFileFormatType::FORMAT_CSV_LZ4BLOCK:
+        case TFileFormatType::FORMAT_CSV_SNAPPYBLOCK:
         case TFileFormatType::FORMAT_CSV_LZOP:
         case TFileFormatType::FORMAT_CSV_DEFLATE: {
             // file_slots is no use
@@ -614,6 +627,7 @@ void PInternalServiceImpl::fetch_table_schema(google::protobuf::RpcController* c
     });
     if (!ret) {
         offer_failed(result, done, _heavy_work_pool);
+        return;
     }
 }
 
@@ -641,6 +655,7 @@ void PInternalServiceImpl::tablet_fetch_data(google::protobuf::RpcController* co
     });
     if (!ret) {
         offer_failed(response, done, _light_work_pool);
+        return;
     }
 }
 
@@ -653,6 +668,7 @@ void PInternalServiceImpl::get_column_ids_by_tablet_ids(google::protobuf::RpcCon
     });
     if (!ret) {
         offer_failed(response, done, _light_work_pool);
+        return;
     }
 }
 
@@ -666,7 +682,7 @@ void PInternalServiceImpl::_get_column_ids_by_tablet_ids(
     for (const auto& param : params) {
         int64_t index_id = param.indexid();
         auto tablet_ids = param.tablet_ids();
-        std::set<std::vector<int32_t>> filter_set;
+        std::set<std::set<int32_t>> filter_set;
         for (const int64_t tablet_id : tablet_ids) {
             TabletSharedPtr tablet = tablet_mgr->get_tablet(tablet_id);
             if (tablet == nullptr) {
@@ -679,9 +695,10 @@ void PInternalServiceImpl::_get_column_ids_by_tablet_ids(
             }
             // check schema consistency, column ids should be the same
             const auto& columns = tablet->tablet_schema()->columns();
-            std::vector<int32_t> column_ids(columns.size());
-            std::transform(columns.begin(), columns.end(), column_ids.begin(),
-                           [](const TabletColumn& c) { return c.unique_id(); });
+            std::set<int32_t> column_ids;
+            for (const auto& col : columns) {
+                column_ids.insert(col.unique_id());
+            }
             filter_set.insert(column_ids);
         }
         if (filter_set.size() > 1) {
@@ -769,6 +786,7 @@ void PInternalServiceImpl::get_info(google::protobuf::RpcController* controller,
     });
     if (!ret) {
         offer_failed(response, done, _heavy_work_pool);
+        return;
     }
 }
 
@@ -781,6 +799,7 @@ void PInternalServiceImpl::update_cache(google::protobuf::RpcController* control
     });
     if (!ret) {
         offer_failed(response, done, _light_work_pool);
+        return;
     }
 }
 
@@ -793,6 +812,7 @@ void PInternalServiceImpl::fetch_cache(google::protobuf::RpcController* controll
     });
     if (!ret) {
         offer_failed(result, done, _heavy_work_pool);
+        return;
     }
 }
 
@@ -805,6 +825,7 @@ void PInternalServiceImpl::clear_cache(google::protobuf::RpcController* controll
     });
     if (!ret) {
         offer_failed(response, done, _light_work_pool);
+        return;
     }
 }
 
@@ -824,6 +845,7 @@ void PInternalServiceImpl::merge_filter(::google::protobuf::RpcController* contr
     });
     if (!ret) {
         offer_failed(response, done, _light_work_pool);
+        return;
     }
 }
 
@@ -845,6 +867,7 @@ void PInternalServiceImpl::apply_filter(::google::protobuf::RpcController* contr
     });
     if (!ret) {
         offer_failed(response, done, _light_work_pool);
+        return;
     }
 }
 
@@ -866,6 +889,7 @@ void PInternalServiceImpl::apply_filterv2(::google::protobuf::RpcController* con
     });
     if (!ret) {
         offer_failed(response, done, _light_work_pool);
+        return;
     }
 }
 
@@ -899,6 +923,7 @@ void PInternalServiceImpl::send_data(google::protobuf::RpcController* controller
     });
     if (!ret) {
         offer_failed(response, done, _heavy_work_pool);
+        return;
     }
 }
 
@@ -922,6 +947,7 @@ void PInternalServiceImpl::commit(google::protobuf::RpcController* controller,
     });
     if (!ret) {
         offer_failed(response, done, _light_work_pool);
+        return;
     }
 }
 
@@ -944,6 +970,7 @@ void PInternalServiceImpl::rollback(google::protobuf::RpcController* controller,
     });
     if (!ret) {
         offer_failed(response, done, _light_work_pool);
+        return;
     }
 }
 
@@ -962,6 +989,7 @@ void PInternalServiceImpl::fold_constant_expr(google::protobuf::RpcController* c
     });
     if (!ret) {
         offer_failed(response, done, _light_work_pool);
+        return;
     }
 }
 
@@ -996,6 +1024,7 @@ void PInternalServiceImpl::transmit_block(google::protobuf::RpcController* contr
     });
     if (!ret) {
         offer_failed(response, done, pool);
+        return;
     }
 }
 
@@ -1014,6 +1043,7 @@ void PInternalServiceImpl::transmit_block_by_http(google::protobuf::RpcControlle
     });
     if (!ret) {
         offer_failed(response, done, _heavy_work_pool);
+        return;
     }
 }
 
@@ -1080,6 +1110,7 @@ void PInternalServiceImpl::check_rpc_channel(google::protobuf::RpcController* co
     });
     if (!ret) {
         offer_failed(response, done, _light_work_pool);
+        return;
     }
 }
 
@@ -1118,6 +1149,7 @@ void PInternalServiceImpl::reset_rpc_channel(google::protobuf::RpcController* co
     });
     if (!ret) {
         offer_failed(response, done, _light_work_pool);
+        return;
     }
 }
 
@@ -1134,6 +1166,7 @@ void PInternalServiceImpl::hand_shake(google::protobuf::RpcController* controlle
     });
     if (!ret) {
         offer_failed(response, done, _light_work_pool);
+        return;
     }
 }
 
@@ -1352,6 +1385,7 @@ void PInternalServiceImpl::request_slave_tablet_pull_rowset(
     });
     if (!ret) {
         offer_failed(response, done, _heavy_work_pool);
+        return;
     }
     Status::OK().to_protobuf(response->mutable_status());
 }
@@ -1423,6 +1457,7 @@ void PInternalServiceImpl::response_slave_tablet_pull_rowset(
     });
     if (!ret) {
         offer_failed(response, done, _heavy_work_pool);
+        return;
     }
 }
 
@@ -1596,6 +1631,7 @@ void PInternalServiceImpl::multiget_data(google::protobuf::RpcController* contro
     });
     if (!ret) {
         offer_failed(response, done, _heavy_work_pool);
+        return;
     }
 }
 
@@ -1608,4 +1644,26 @@ void PInternalServiceImpl::get_tablet_rowset_versions(google::protobuf::RpcContr
     ExecEnv::GetInstance()->storage_engine()->get_tablet_rowset_versions(request, response);
 }
 
+void PInternalServiceImpl::glob(google::protobuf::RpcController* controller,
+                                const PGlobRequest* request, PGlobResponse* response,
+                                google::protobuf::Closure* done) {
+    bool ret = _heavy_work_pool.try_offer([request, response, done]() {
+        brpc::ClosureGuard closure_guard(done);
+        std::vector<io::FileInfo> files;
+        Status st = io::global_local_filesystem()->safe_glob(request->pattern(), &files);
+        if (st.ok()) {
+            for (auto& file : files) {
+                PGlobResponse_PFileInfo* pfile = response->add_files();
+                pfile->set_file(file.file_name);
+                pfile->set_size(file.file_size);
+            }
+        }
+        st.to_protobuf(response->mutable_status());
+    });
+    if (!ret) {
+        offer_failed(response, done, _heavy_work_pool);
+        return;
+    }
+}
+
 } // namespace doris
