@@ -17,13 +17,14 @@
 
 #include "util/hdfs_util.h"
 
-#include <util/string_util.h>
+#include <ostream>
 
-#include "common/config.h"
 #include "common/logging.h"
 #include "io/fs/err_utils.h"
+#include "io/hdfs_builder.h"
 
 namespace doris {
+namespace io {
 
 HDFSHandle& HDFSHandle::instance() {
     static HDFSHandle hdfs_handle;
@@ -34,10 +35,20 @@ hdfsFS HDFSHandle::create_hdfs_fs(HDFSCommonBuilder& hdfs_builder) {
     hdfsFS hdfs_fs = hdfsBuilderConnect(hdfs_builder.get());
     if (hdfs_fs == nullptr) {
         LOG(WARNING) << "connect to hdfs failed."
-                     << ", error: " << io::hdfs_error();
+                     << ", error: " << hdfs_error();
         return nullptr;
     }
     return hdfs_fs;
 }
 
+Path convert_path(const Path& path, const std::string& namenode) {
+    Path real_path(path);
+    if (path.string().find(namenode) != std::string::npos) {
+        std::string real_path_str = path.string().substr(namenode.size());
+        real_path = real_path_str;
+    }
+    return real_path;
+}
+
+} // namespace io
 } // namespace doris
