@@ -158,7 +158,7 @@ public:
         return string_to_bool_internal(s + i, len - i, result);
     }
 
-    template <typename T>
+    template <PrimitiveType P, typename T>
     static inline T string_to_decimal(const char* s, int len, int type_precision, int type_scale,
                                       ParseResult* result);
 
@@ -568,7 +568,7 @@ inline int StringParser::StringParseTraits<__int128>::max_ascii_len() {
     return 39;
 }
 
-template <typename T>
+template <PrimitiveType P, typename T>
 T StringParser::string_to_decimal(const char* s, int len, int type_precision, int type_scale,
                                   ParseResult* result) {
     // Special cases:
@@ -624,55 +624,112 @@ T StringParser::string_to_decimal(const char* s, int len, int type_precision, in
     }
 
     int precision = 0;
+    int max_digit = type_precision - type_scale;
     bool found_exponent = false;
     int8_t exponent = 0;
     T value = 0;
-    for (int i = 0; i < len; ++i) {
-        const char& c = s[i];
-        if (LIKELY('0' <= c && c <= '9')) {
-            found_value = true;
-            // Ignore digits once the type's precision limit is reached. This avoids
-            // overflowing the underlying storage while handling a string like
-            // 10000000000e-10 into a DECIMAL(1, 0). Adjustments for ignored digits and
-            // an exponent will be made later.
-            if (LIKELY(type_precision > precision)) {
-                value = (value * 10) + (c - '0'); // Benchmarks are faster with parenthesis...
-            } else {
-                *result = StringParser::PARSE_OVERFLOW;
-                value = is_negative ? vectorized::min_decimal_value<vectorized::Decimal<T>>(
-                                              type_precision)
-                                    : vectorized::max_decimal_value<vectorized::Decimal<T>>(
-                                              type_precision);
-                return value;
-            }
-            DCHECK(value >= 0); // For some reason //DCHECK_GE doesn't work with __int128.
-            ++precision;
-            scale += found_dot;
-        } else if (c == '.' && LIKELY(!found_dot)) {
-            found_dot = 1;
-        } else if ((c == 'e' || c == 'E') && LIKELY(!found_exponent)) {
-            found_exponent = true;
-            exponent = string_to_int_internal<int8_t>(s + i + 1, len - i - 1, result);
-            if (UNLIKELY(*result != StringParser::PARSE_SUCCESS)) {
-                if (*result == StringParser::PARSE_OVERFLOW && exponent < 0) {
-                    *result = StringParser::PARSE_UNDERFLOW;
+    if constexpr (TYPE_DECIMALV2 == P) {
+        // decimalv2 do not care type_scale and type_precision,just keep the origin logic
+        for (int i = 0; i < len; ++i) {
+            const char& c = s[i];
+            if (LIKELY('0' <= c && c <= '9')) {
+                found_value = true;
+                // Ignore digits once the type's precision limit is reached. This avoids
+                // overflowing the underlying storage while handling a string like
+                // 10000000000e-10 into a DECIMAL(1, 0). Adjustments for ignored digits and
+                // an exponent will be made later.
+                if (LIKELY(type_precision > precision)) {
+                    value = (value * 10) + (c - '0'); // Benchmarks are faster with parenthesis...
+                } else {
+                    *result = StringParser::PARSE_OVERFLOW;
+                    value = is_negative ? vectorized::min_decimal_value<vectorized::Decimal<T>>(
+                                                  type_precision)
+                                        : vectorized::max_decimal_value<vectorized::Decimal<T>>(
+                                                  type_precision);
+                    return value;
                 }
-                return 0;
-            }
-            break;
-        } else {
-            if (value == 0) {
-                *result = StringParser::PARSE_FAILURE;
-                return 0;
-            }
-            *result = StringParser::PARSE_SUCCESS;
-            if constexpr (std::is_same_v<T, vectorized::Int128I>) {
-                value *= get_scale_multiplier<__int128>(type_scale - scale);
+                DCHECK(value >= 0); // For some reason //DCHECK_GE doesn't work with __int128.
+                ++precision;
+                scale += found_dot;
+            } else if (c == '.' && LIKELY(!found_dot)) {
+                found_dot = 1;
+            } else if ((c == 'e' || c == 'E') && LIKELY(!found_exponent)) {
+                found_exponent = true;
+                exponent = string_to_int_internal<int8_t>(s + i + 1, len - i - 1, result);
+                if (UNLIKELY(*result != StringParser::PARSE_SUCCESS)) {
+                    if (*result == StringParser::PARSE_OVERFLOW && exponent < 0) {
+                        *result = StringParser::PARSE_UNDERFLOW;
+                    }
+                    return 0;
+                }
+                break;
             } else {
-                value *= get_scale_multiplier<T>(type_scale - scale);
-            }
+                if (value == 0) {
+                    *result = StringParser::PARSE_FAILURE;
+                    return 0;
+                }
+                *result = StringParser::PARSE_SUCCESS;
+                if constexpr (std::is_same_v<T, vectorized::Int128I>) {
+                    value *= get_scale_multiplier<__int128>(type_scale - scale);
+                } else {
+                    value *= get_scale_multiplier<T>(type_scale - scale);
+                }
 
-            return is_negative ? T(-value) : T(value);
+                return is_negative ? T(-value) : T(value);
+            }
+        }
+    } else {
+        // decimalv3
+        for (int i = 0; i < len; ++i) {
+            const char& c = s[i];
+            // keep a rounding precision to round the decimal value
+            if (LIKELY('0' <= c && c <= '9') && LIKELY(type_precision >= precision)) {
+                found_value = true;
+                // Ignore digits once the type's precision limit is reached. This avoids
+                // overflowing the underlying storage while handling a string like
+                // 10000000000e-10 into a DECIMAL(1, 0). Adjustments for ignored digits and
+                // an exponent will be made later.
+                ++precision;
+                scale += found_dot;
+                // decimalv3 should make sure the type_scale and type_precision
+                if (!found_dot && max_digit < (precision - scale)) {
+                    // parse_overflow should only happen when the digit part reached the max
+                    *result = StringParser::PARSE_OVERFLOW;
+                    value = is_negative ? vectorized::min_decimal_value<vectorized::Decimal<T>>(
+                                                  type_precision)
+                                        : vectorized::max_decimal_value<vectorized::Decimal<T>>(
+                                                  type_precision);
+                    return value;
+                }
+                // keep a rounding precision to round the decimal value
+                value = (value * 10) + (c - '0'); // Benchmarks are faster with parenthesis...
+                DCHECK(value >= 0); // For some reason //DCHECK_GE doesn't work with __int128.
+            } else if (c == '.' && LIKELY(!found_dot)) {
+                found_dot = 1;
+            } else if ((c == 'e' || c == 'E') && LIKELY(!found_exponent)) {
+                found_exponent = true;
+                exponent = string_to_int_internal<int8_t>(s + i + 1, len - i - 1, result);
+                if (UNLIKELY(*result != StringParser::PARSE_SUCCESS)) {
+                    if (*result == StringParser::PARSE_OVERFLOW && exponent < 0) {
+                        *result = StringParser::PARSE_UNDERFLOW;
+                    }
+                    return 0;
+                }
+                break;
+            } else {
+                if (value == 0) {
+                    *result = StringParser::PARSE_FAILURE;
+                    return 0;
+                }
+                *result = StringParser::PARSE_SUCCESS;
+                if constexpr (std::is_same_v<T, vectorized::Int128I>) {
+                    value *= get_scale_multiplier<__int128>(type_scale - scale);
+                } else {
+                    value *= get_scale_multiplier<T>(type_scale - scale);
+                }
+
+                return is_negative ? T(-value) : T(value);
+            }
         }
     }
 
