@@ -20,11 +20,11 @@
 
 #pragma once
 
-#include <vec/aggregate_functions/aggregate_function.h>
-#include <vec/data_types/data_type.h>
-
 #include <memory>
 
+#include "vec/aggregate_functions/aggregate_function.h"
+#include "vec/data_types/data_type.h"
+
 namespace doris::vectorized {
 
 /** Aggregate function combinator allows to take one aggregate function
@@ -58,12 +58,6 @@ public:
       */
     virtual DataTypes transform_arguments(const DataTypes& arguments) const { return arguments; }
 
-    /** From the parameters for combined function,
-      *  get the parameters for nested function.
-      * If arguments are not suitable for combined function, throw an exception.
-      */
-    virtual Array transform_parameters(const Array& parameters) const { return parameters; }
-
     /** Create combined aggregate function (ex: sumIf)
       *  from nested function (ex: sum)
       *  and arguments for combined aggregate function (ex: UInt64, UInt8 for sumIf).
@@ -71,7 +65,7 @@ public:
       */
     virtual AggregateFunctionPtr transform_aggregate_function(
             const AggregateFunctionPtr& nested_function, const DataTypes& arguments,
-            const Array& params, const bool result_is_nullable) const = 0;
+            const bool result_is_nullable) const = 0;
 
     virtual ~IAggregateFunctionCombinator() = default;
 };
