@@ -20,46 +20,39 @@
 
 #include "vec/data_types/data_type_string.h"
 
-#include <string_view>
+#include <string.h>
 
+#include <typeinfo>
+#include <utility>
+
+#include "vec/columns/column.h"
+#include "vec/columns/column_const.h"
 #include "vec/columns/column_string.h"
 #include "vec/common/assert_cast.h"
+#include "vec/common/string_buffer.hpp"
+#include "vec/common/string_ref.h"
 #include "vec/core/field.h"
-
-#ifdef __SSE2__
-#include <emmintrin.h>
-#endif
+#include "vec/io/reader_buffer.h"
 
 namespace doris::vectorized {
 
-template <typename Reader>
-static inline void read(IColumn& column, Reader&& reader) {
-    ColumnString& column_string = assert_cast<ColumnString&>(column);
-    ColumnString::Chars& data = column_string.get_chars();
-    ColumnString::Offsets& offsets = column_string.get_offsets();
-    size_t old_chars_size = data.size();
-    size_t old_offsets_size = offsets.size();
-    try {
-        reader(data);
-        offsets.push_back(data.size());
-    } catch (...) {
-        offsets.resize_assume_reserved(old_offsets_size);
-        data.resize_assume_reserved(old_chars_size);
-        throw;
-    }
-}
-
 std::string DataTypeString::to_string(const IColumn& column, size_t row_num) const {
-    auto ptr = column.convert_to_full_column_if_const();
-    const StringRef& s = assert_cast<const ColumnString&>(*ptr.get()).get_data_at(row_num);
-    return s.to_string();
+    auto result = check_column_const_set_readability(column, row_num);
+    ColumnPtr ptr = result.first;
+    row_num = result.second;
+
+    const auto& value = assert_cast<const ColumnString&>(*ptr).get_data_at(row_num);
+    return value.to_string();
 }
 
 void DataTypeString::to_string(const class doris::vectorized::IColumn& column, size_t row_num,
                                class doris::vectorized::BufferWritable& ostr) const {
-    auto ptr = column.convert_to_full_column_if_const();
-    const StringRef& s = assert_cast<const ColumnString&>(*ptr.get()).get_data_at(row_num);
-    ostr.write(s.data, s.size);
+    auto result = check_column_const_set_readability(column, row_num);
+    ColumnPtr ptr = result.first;
+    row_num = result.second;
+
+    const auto& value = assert_cast<const ColumnString&>(*ptr).get_data_at(row_num);
+    ostr.write(value.data, value.size);
 }
 
 Status DataTypeString::from_string(ReadBuffer& rb, IColumn* column) const {
