@@ -44,12 +44,26 @@ class Arena;
 class DataTypeDateTimeV2SerDe : public DataTypeNumberSerDe<UInt64> {
 public:
     DataTypeDateTimeV2SerDe(int scale) : scale(scale) {};
+    void serialize_one_cell_to_text(const IColumn& column, int row_num, BufferWritable& bw,
+                                    FormatOptions& options) const override;
+
+    void serialize_column_to_text(const IColumn& column, int start_idx, int end_idx,
+                                  BufferWritable& bw, FormatOptions& options) const override;
+
+    Status deserialize_one_cell_from_text(IColumn& column, Slice& slice,
+                                          const FormatOptions& options) const override;
+
+    Status deserialize_column_from_text_vector(IColumn& column, std::vector<Slice>& slices,
+                                               int* num_deserialized,
+                                               const FormatOptions& options) const override;
+
     void write_column_to_arrow(const IColumn& column, const NullMap* null_map,
                                arrow::ArrayBuilder* array_builder, int start,
                                int end) const override;
     void read_column_from_arrow(IColumn& column, const arrow::Array* arrow_array, int start,
                                 int end, const cctz::time_zone& ctz) const override {
-        LOG(FATAL) << "not support read arrow array to uint64 column";
+        throw doris::Exception(ErrorCode::NOT_IMPLEMENTED_ERROR,
+                               "write_column_to_pb with type " + column.get_name());
     }
 
     Status write_column_to_mysql(const IColumn& column, MysqlRowBuffer<true>& row_buffer,
@@ -64,4 +78,4 @@ private:
     int scale;
 };
 } // namespace vectorized
-} // namespace doris
\ No newline at end of file
+} // namespace doris
