@@ -201,7 +201,13 @@ Status JniConnector::close() {
 }
 
 Status JniConnector::_init_jni_scanner(JNIEnv* env, int batch_size) {
-    RETURN_IF_ERROR(JniUtil::GetGlobalClassRef(env, _connector_class.c_str(), &_jni_scanner_cls));
+    RETURN_IF_ERROR(
+            JniUtil::get_jni_scanner_class(env, _connector_class.c_str(), &_jni_scanner_cls));
+    if (_jni_scanner_cls == NULL) {
+        if (env->ExceptionOccurred()) env->ExceptionDescribe();
+        return Status::InternalError("Fail to get JniScanner class.");
+    }
+    RETURN_ERROR_IF_EXC(env);
     jmethodID scanner_constructor =
             env->GetMethodID(_jni_scanner_cls, "<init>", "(ILjava/util/Map;)V");
     RETURN_ERROR_IF_EXC(env);
