@@ -53,7 +53,6 @@ Status NewFileScanNode::prepare(RuntimeState* state) {
     if (state->get_query_ctx() != nullptr &&
         state->get_query_ctx()->file_scan_range_params_map.count(id()) > 0) {
         TFileScanRangeParams& params = state->get_query_ctx()->file_scan_range_params_map[id()];
-        _input_tuple_id = params.src_tuple_id;
         _output_tuple_id = params.dest_tuple_id;
     }
     return Status::OK();
@@ -85,8 +84,6 @@ void NewFileScanNode::set_scan_ranges(const std::vector<TScanRangeParams>& scan_
         scan_ranges[0].scan_range.ext_scan_range.file_scan_range.__isset.params) {
         // for compatibility.
         // in new implement, the tuple id is set in prepare phase
-        _input_tuple_id =
-                scan_ranges[0].scan_range.ext_scan_range.file_scan_range.params.src_tuple_id;
         _output_tuple_id =
                 scan_ranges[0].scan_range.ext_scan_range.file_scan_range.params.dest_tuple_id;
     }
