@@ -17,34 +17,53 @@
 
 #pragma once
 
-#include <memory>
+#include <stddef.h>
+#include <stdint.h>
 
+#include <memory>
+#include <vector>
+
+#include "common/status.h"
 #include "exec/exec_node.h"
+#include "runtime/descriptors.h"
 #include "vec/common/sort/vsort_exec_exprs.h"
 
 namespace doris {
+class DorisNodesInfo;
+class ObjectPool;
+class QueryStatistics;
+class QueryStatisticsRecvr;
+class RuntimeState;
+class TPlanNode;
+
+namespace pipeline {
+class ExchangeSourceOperator;
+}
 namespace vectorized {
 class VDataStreamRecvr;
+class Block;
 
 class VExchangeNode : public ExecNode {
 public:
+    friend class doris::pipeline::ExchangeSourceOperator;
     VExchangeNode(ObjectPool* pool, const TPlanNode& tnode, const DescriptorTbl& descs);
-    virtual ~VExchangeNode() {}
+    ~VExchangeNode() override = default;
 
-    virtual Status init(const TPlanNode& tnode, RuntimeState* state = nullptr) override;
-    virtual Status prepare(RuntimeState* state) override;
-    virtual Status open(RuntimeState* state) override;
-    virtual Status get_next(RuntimeState* state, RowBatch* row_batch, bool* eos) override;
-    virtual Status get_next(RuntimeState* state, Block* row_batch, bool* eos) override;
+    Status init(const TPlanNode& tnode, RuntimeState* state = nullptr) override;
+    Status prepare(RuntimeState* state) override;
+    Status alloc_resource(RuntimeState* state) override;
+    Status open(RuntimeState* state) override;
+    Status get_next(RuntimeState* state, Block* row_batch, bool* eos) override;
+    void release_resource(RuntimeState* state) override;
     Status collect_query_statistics(QueryStatistics* statistics) override;
-    virtual Status close(RuntimeState* state) override;
+    Status close(RuntimeState* state) override;
 
-    // Status collect_query_statistics(QueryStatistics* statistics) override;
     void set_num_senders(int num_senders) { _num_senders = num_senders; }
 
 private:
     int _num_senders;
     bool _is_merging;
+    bool _is_ready;
     std::shared_ptr<VDataStreamRecvr> _stream_recvr;
     RowDescriptor _input_row_desc;
     std::shared_ptr<QueryStatisticsRecvr> _sub_plan_query_statistics_recvr;
