@@ -17,24 +17,38 @@
 
 #pragma once
 
-#include "exprs/table_function/explode_split.h"
-#include "gutil/strings/stringpiece.h"
-#include "runtime/string_value.h"
-#include "vec/columns/column.h"
+#include <stddef.h>
+#include <stdint.h>
+
+#include <string_view>
+#include <vector>
+
+#include "common/status.h"
+#include "vec/common/string_ref.h"
+#include "vec/data_types/data_type.h"
+#include "vec/exprs/table_function/table_function.h"
+
+namespace doris {
+namespace vectorized {
+class Block;
+class ColumnString;
+} // namespace vectorized
+} // namespace doris
 
 namespace doris::vectorized {
 
-class VExplodeSplitTableFunction : public ExplodeSplitTableFunction {
+class VExplodeSplitTableFunction final : public TableFunction {
+    ENABLE_FACTORY_CREATOR(VExplodeSplitTableFunction);
+
 public:
     VExplodeSplitTableFunction();
-    virtual ~VExplodeSplitTableFunction() = default;
+    ~VExplodeSplitTableFunction() override = default;
 
-    virtual Status open() override;
-    virtual Status process_init(vectorized::Block* block) override;
-    virtual Status process_row(size_t row_idx) override;
-    virtual Status process_close() override;
-    virtual Status get_value(void** output) override;
-    virtual Status get_value_length(int64_t* length) override;
+    Status open() override;
+    Status process_init(Block* block) override;
+    Status process_row(size_t row_idx) override;
+    Status process_close() override;
+    void get_value(MutableColumnPtr& column) override;
 
 private:
     std::vector<std::string_view> _backup;
