@@ -17,15 +17,17 @@
 
 #include "vec/functions/function_string.h"
 
-#include <re2/re2.h>
+#include <ctype.h>
+#include <math.h>
+#include <re2/stringpiece.h>
 
-#include <cstddef>
-#include <cstdlib>
 #include <string_view>
 
 #include "runtime/string_search.hpp"
 #include "util/url_coding.h"
+#include "vec/columns/column_string.h"
 #include "vec/common/pod_array_fwd.h"
+#include "vec/common/string_ref.h"
 #include "vec/functions/function_reverse.h"
 #include "vec/functions/function_string_to_string.h"
 #include "vec/functions/function_totype.h"
@@ -93,7 +95,7 @@ struct StringUtf8LengthImpl {
         for (int i = 0; i < size; ++i) {
             const char* raw_str = reinterpret_cast<const char*>(&data[offsets[i - 1]]);
             int str_size = offsets[i] - offsets[i - 1];
-            res[i] = get_char_len(StringValue(raw_str, str_size), str_size);
+            res[i] = simd::VStringFunctions::get_char_len(raw_str, str_size);
         }
         return Status::OK();
     }
@@ -172,37 +174,152 @@ struct NameInstr {
     static constexpr auto name = "instr";
 };
 
+// LeftDataType and RightDataType are DataTypeString
+template <typename LeftDataType, typename RightDataType>
+struct StringInStrImpl {
+    using ResultDataType = DataTypeInt32;
+    using ResultPaddedPODArray = PaddedPODArray<Int32>;
+
+    static Status scalar_vector(const StringRef& ldata, const ColumnString::Chars& rdata,
+                                const ColumnString::Offsets& roffsets, ResultPaddedPODArray& res) {
+        StringRef lstr_ref(ldata.data, ldata.size);
+
+        auto size = roffsets.size();
+        res.resize(size);
+        for (int i = 0; i < size; ++i) {
+            const char* r_raw_str = reinterpret_cast<const char*>(&rdata[roffsets[i - 1]]);
+            int r_str_size = roffsets[i] - roffsets[i - 1];
+
+            StringRef rstr_ref(r_raw_str, r_str_size);
+
+            res[i] = execute(lstr_ref, rstr_ref);
+        }
+
+        return Status::OK();
+    }
+
+    static Status vector_scalar(const ColumnString::Chars& ldata,
+                                const ColumnString::Offsets& loffsets, const StringRef& rdata,
+                                ResultPaddedPODArray& res) {
+        auto size = loffsets.size();
+        res.resize(size);
+
+        if (rdata.size == 0) {
+            std::fill(res.begin(), res.end(), 1);
+            return Status::OK();
+        }
+
+        const UInt8* begin = ldata.data();
+        const UInt8* end = begin + ldata.size();
+        const UInt8* pos = begin;
+
+        /// Current index in the array of strings.
+        size_t i = 0;
+        std::fill(res.begin(), res.end(), 0);
+
+        StringRef rstr_ref(rdata.data, rdata.size);
+        StringSearch search(&rstr_ref);
+
+        while (pos < end) {
+            // search return matched substring start offset
+            pos = (UInt8*)search.search((char*)pos, end - pos);
+            if (pos >= end) {
+                break;
+            }
+
+            /// Determine which index it refers to.
+            /// begin + value_offsets[i] is the start offset of string at i+1
+            while (begin + loffsets[i] < pos) {
+                ++i;
+            }
+
+            /// We check that the entry does not pass through the boundaries of strings.
+            if (pos + rdata.size <= begin + loffsets[i]) {
+                int loc = pos - begin - loffsets[i - 1];
+                int l_str_size = loffsets[i] - loffsets[i - 1];
+                size_t len = std::min(l_str_size, loc);
+                loc = simd::VStringFunctions::get_char_len((char*)(begin + loffsets[i - 1]), len);
+                res[i] = loc + 1;
+            }
+
+            // move to next string offset
+            pos = begin + loffsets[i];
+            ++i;
+        }
+
+        return Status::OK();
+    }
+
+    static Status vector_vector(const ColumnString::Chars& ldata,
+                                const ColumnString::Offsets& loffsets,
+                                const ColumnString::Chars& rdata,
+                                const ColumnString::Offsets& roffsets, ResultPaddedPODArray& res) {
+        DCHECK_EQ(loffsets.size(), roffsets.size());
+
+        auto size = loffsets.size();
+        res.resize(size);
+        for (int i = 0; i < size; ++i) {
+            const char* l_raw_str = reinterpret_cast<const char*>(&ldata[loffsets[i - 1]]);
+            int l_str_size = loffsets[i] - loffsets[i - 1];
+            StringRef lstr_ref(l_raw_str, l_str_size);
+
+            const char* r_raw_str = reinterpret_cast<const char*>(&rdata[roffsets[i - 1]]);
+            int r_str_size = roffsets[i] - roffsets[i - 1];
+            StringRef rstr_ref(r_raw_str, r_str_size);
+
+            res[i] = execute(lstr_ref, rstr_ref);
+        }
+
+        return Status::OK();
+    }
+
+    static int execute(const StringRef& strl, const StringRef& strr) {
+        if (strr.size == 0) {
+            return 1;
+        }
+
+        StringSearch search(&strr);
+        // Hive returns positions starting from 1.
+        int loc = search.search(&strl);
+        if (loc > 0) {
+            size_t len = std::min((size_t)loc, strl.size);
+            loc = simd::VStringFunctions::get_char_len(strl.data, len);
+        }
+
+        return loc + 1;
+    }
+};
+
 // the same impl as instr
 struct NameLocate {
     static constexpr auto name = "locate";
 };
 
-struct InStrOP {
+// LeftDataType and RightDataType are DataTypeString
+template <typename LeftDataType, typename RightDataType>
+struct StringLocateImpl {
     using ResultDataType = DataTypeInt32;
     using ResultPaddedPODArray = PaddedPODArray<Int32>;
-    static void execute(const std::string_view& strl, const std::string_view& strr, int32_t& res) {
-        if (strr.length() == 0) {
-            res = 1;
-            return;
-        }
 
-        StringValue str_sv(strl.data(), strl.length());
-        StringValue substr_sv(strr.data(), strr.length());
-        StringSearch search(&substr_sv);
-        // Hive returns positions starting from 1.
-        int loc = search.search(&str_sv);
-        if (loc > 0) {
-            loc = get_char_len(str_sv, loc);
-        }
-
-        res = loc + 1;
+    static Status scalar_vector(const StringRef& ldata, const ColumnString::Chars& rdata,
+                                const ColumnString::Offsets& roffsets, ResultPaddedPODArray& res) {
+        return StringInStrImpl<LeftDataType, RightDataType>::vector_scalar(rdata, roffsets, ldata,
+                                                                           res);
     }
-};
-struct LocateOP {
-    using ResultDataType = DataTypeInt32;
-    using ResultPaddedPODArray = PaddedPODArray<Int32>;
-    static void execute(const std::string_view& strl, const std::string_view& strr, int32_t& res) {
-        InStrOP::execute(strr, strl, res);
+
+    static Status vector_scalar(const ColumnString::Chars& ldata,
+                                const ColumnString::Offsets& loffsets, const StringRef& rdata,
+                                ResultPaddedPODArray& res) {
+        return StringInStrImpl<LeftDataType, RightDataType>::scalar_vector(rdata, ldata, loffsets,
+                                                                           res);
+    }
+
+    static Status vector_vector(const ColumnString::Chars& ldata,
+                                const ColumnString::Offsets& loffsets,
+                                const ColumnString::Chars& rdata,
+                                const ColumnString::Offsets& roffsets, ResultPaddedPODArray& res) {
+        return StringInStrImpl<LeftDataType, RightDataType>::vector_vector(rdata, roffsets, ldata,
+                                                                           loffsets, res);
     }
 };
 
@@ -212,10 +329,10 @@ struct StringFunctionImpl {
     using ResultDataType = typename OP::ResultDataType;
     using ResultPaddedPODArray = typename OP::ResultPaddedPODArray;
 
-    static Status vector_vector(const ColumnString::Chars& ldata,
-                                const ColumnString::Offsets& loffsets,
-                                const ColumnString::Chars& rdata,
-                                const ColumnString::Offsets& roffsets, ResultPaddedPODArray& res) {
+    static void vector_vector(const ColumnString::Chars& ldata,
+                              const ColumnString::Offsets& loffsets,
+                              const ColumnString::Chars& rdata,
+                              const ColumnString::Offsets& roffsets, ResultPaddedPODArray& res) {
         DCHECK_EQ(loffsets.size(), roffsets.size());
 
         auto size = loffsets.size();
@@ -232,8 +349,33 @@ struct StringFunctionImpl {
 
             OP::execute(lview, rview, res[i]);
         }
+    }
+    static void vector_scalar(const ColumnString::Chars& ldata,
+                              const ColumnString::Offsets& loffsets, const StringRef& rdata,
+                              ResultPaddedPODArray& res) {
+        auto size = loffsets.size();
+        res.resize(size);
+        std::string_view rview(rdata.data, rdata.size);
+        for (int i = 0; i < size; ++i) {
+            const char* l_raw_str = reinterpret_cast<const char*>(&ldata[loffsets[i - 1]]);
+            int l_str_size = loffsets[i] - loffsets[i - 1];
+            std::string_view lview(l_raw_str, l_str_size);
 
-        return Status::OK();
+            OP::execute(lview, rview, res[i]);
+        }
+    }
+    static void scalar_vector(const StringRef& ldata, const ColumnString::Chars& rdata,
+                              const ColumnString::Offsets& roffsets, ResultPaddedPODArray& res) {
+        auto size = roffsets.size();
+        res.resize(size);
+        std::string_view lview(ldata.data, ldata.size);
+        for (int i = 0; i < size; ++i) {
+            const char* r_raw_str = reinterpret_cast<const char*>(&rdata[roffsets[i - 1]]);
+            int r_str_size = roffsets[i] - roffsets[i - 1];
+            std::string_view rview(r_raw_str, r_str_size);
+
+            OP::execute(lview, rview, res[i]);
+        }
     }
 };
 
@@ -255,8 +397,9 @@ struct TransferImpl {
         }
 
         res_offsets.resize(offset_size);
-        memcpy(res_offsets.data(), offsets.data(),
-               offset_size * sizeof(ColumnString::Offsets::value_type));
+        memcpy_small_allow_read_write_overflow15(
+                res_offsets.data(), offsets.data(),
+                offset_size * sizeof(ColumnString::Offsets::value_type));
 
         size_t data_length = data.size();
         res_data.resize(data_length);
@@ -279,8 +422,9 @@ struct InitcapImpl {
                          ColumnString::Chars& res_data, ColumnString::Offsets& res_offsets) {
         size_t offset_size = offsets.size();
         res_offsets.resize(offsets.size());
-        memcpy(res_offsets.data(), offsets.data(),
-               offset_size * sizeof(ColumnString::Offsets::value_type));
+        memcpy_small_allow_read_write_overflow15(
+                res_offsets.data(), offsets.data(),
+                offset_size * sizeof(ColumnString::Offsets::value_type));
 
         size_t data_length = data.size();
         res_data.resize(data_length);
@@ -426,8 +570,6 @@ public:
     // The second parameter of "trim" is a constant.
     ColumnNumbers get_arguments_that_are_always_constant() const override { return {1}; }
 
-    bool use_default_implementation_for_constants() const override { return true; }
-
     DataTypes get_variadic_argument_types_impl() const override {
         return impl::get_variadic_argument_types();
     }
@@ -438,7 +580,6 @@ public:
     }
 };
 
-static constexpr int MAX_STACK_CIPHER_LEN = 1024 * 64;
 struct UnHexImpl {
     static constexpr auto name = "unhex";
     using ReturnType = DataTypeString;
@@ -510,16 +651,9 @@ struct UnHexImpl {
                 StringOP::push_empty_string(i, dst_data, dst_offsets);
                 continue;
             }
-            char dst_array[MAX_STACK_CIPHER_LEN];
-            char* dst = dst_array;
 
             int cipher_len = srclen / 2;
-            std::unique_ptr<char[]> dst_uptr;
-            if (cipher_len > MAX_STACK_CIPHER_LEN) {
-                dst_uptr.reset(new char[cipher_len]);
-                dst = dst_uptr.get();
-            }
-
+            char dst[cipher_len];
             int outlen = hex_decode(source, srclen, dst);
 
             if (outlen < 0) {
@@ -589,15 +723,8 @@ struct ToBase64Impl {
                 continue;
             }
 
-            char dst_array[MAX_STACK_CIPHER_LEN];
-            char* dst = dst_array;
-
             int cipher_len = (int)(4.0 * ceil((double)srclen / 3.0));
-            std::unique_ptr<char[]> dst_uptr;
-            if (cipher_len > MAX_STACK_CIPHER_LEN) {
-                dst_uptr.reset(new char[cipher_len]);
-                dst = dst_uptr.get();
-            }
+            char dst[cipher_len];
             int outlen = base64_encode((const unsigned char*)source, srclen, (unsigned char*)dst);
 
             if (outlen < 0) {
@@ -636,15 +763,8 @@ struct FromBase64Impl {
                 continue;
             }
 
-            char dst_array[MAX_STACK_CIPHER_LEN];
-            char* dst = dst_array;
-
             int cipher_len = srclen;
-            std::unique_ptr<char[]> dst_uptr;
-            if (cipher_len > MAX_STACK_CIPHER_LEN) {
-                dst_uptr.reset(new char[cipher_len]);
-                dst = dst_uptr.get();
-            }
+            char dst[cipher_len];
             int outlen = base64_decode(source, srclen, dst);
 
             if (outlen < 0) {
@@ -698,6 +818,66 @@ struct StringAppendTrailingCharIfAbsent {
                                         res_offsets);
         }
     }
+    static void vector_scalar(FunctionContext* context, const Chars& ldata, const Offsets& loffsets,
+                              const StringRef& rdata, Chars& res_data, Offsets& res_offsets,
+                              NullMap& null_map_data) {
+        size_t input_rows_count = loffsets.size();
+        res_offsets.resize(input_rows_count);
+        fmt::memory_buffer buffer;
+
+        if (rdata.size != 1) {
+            for (size_t i = 0; i < input_rows_count; ++i) {
+                StringOP::push_null_string(i, res_data, res_offsets, null_map_data);
+            }
+            return;
+        }
+
+        for (size_t i = 0; i < input_rows_count; ++i) {
+            buffer.clear();
+
+            int l_size = loffsets[i] - loffsets[i - 1];
+            const auto l_raw = reinterpret_cast<const char*>(&ldata[loffsets[i - 1]]);
+
+            if (l_raw[l_size - 1] == rdata.data[0]) {
+                StringOP::push_value_string(std::string_view(l_raw, l_size), i, res_data,
+                                            res_offsets);
+                continue;
+            }
+
+            buffer.append(l_raw, l_raw + l_size);
+            buffer.append(rdata.begin(), rdata.end());
+            StringOP::push_value_string(std::string_view(buffer.data(), buffer.size()), i, res_data,
+                                        res_offsets);
+        }
+    }
+    static void scalar_vector(FunctionContext* context, const StringRef& ldata, const Chars& rdata,
+                              const Offsets& roffsets, Chars& res_data, Offsets& res_offsets,
+                              NullMap& null_map_data) {
+        size_t input_rows_count = roffsets.size();
+        res_offsets.resize(input_rows_count);
+        fmt::memory_buffer buffer;
+
+        for (size_t i = 0; i < input_rows_count; ++i) {
+            buffer.clear();
+
+            int r_size = roffsets[i] - roffsets[i - 1];
+            const auto r_raw = reinterpret_cast<const char*>(&rdata[roffsets[i - 1]]);
+
+            if (r_size != 1) {
+                StringOP::push_null_string(i, res_data, res_offsets, null_map_data);
+                continue;
+            }
+            if (ldata.size == 0 || ldata.back() == r_raw[0]) {
+                StringOP::push_value_string(ldata.to_string_view(), i, res_data, res_offsets);
+                continue;
+            }
+
+            buffer.append(ldata.begin(), ldata.end());
+            buffer.append(r_raw, r_raw + 1);
+            StringOP::push_value_string(std::string_view(buffer.data(), buffer.size()), i, res_data,
+                                        res_offsets);
+        }
+    }
 };
 
 struct StringLPad {
@@ -716,12 +896,6 @@ using StringStartsWithImpl = StringFunctionImpl<LeftDataType, RightDataType, Sta
 template <typename LeftDataType, typename RightDataType>
 using StringEndsWithImpl = StringFunctionImpl<LeftDataType, RightDataType, EndsWithOp>;
 
-template <typename LeftDataType, typename RightDataType>
-using StringInstrImpl = StringFunctionImpl<LeftDataType, RightDataType, InStrOP>;
-
-template <typename LeftDataType, typename RightDataType>
-using StringLocateImpl = StringFunctionImpl<LeftDataType, RightDataType, LocateOP>;
-
 template <typename LeftDataType, typename RightDataType>
 using StringFindInSetImpl = StringFunctionImpl<LeftDataType, RightDataType, FindInSetOp>;
 
@@ -735,14 +909,12 @@ using FunctionStringStartsWith =
 using FunctionStringEndsWith =
         FunctionBinaryToType<DataTypeString, DataTypeString, StringEndsWithImpl, NameEndsWith>;
 using FunctionStringInstr =
-        FunctionBinaryToType<DataTypeString, DataTypeString, StringInstrImpl, NameInstr>;
+        FunctionBinaryToType<DataTypeString, DataTypeString, StringInStrImpl, NameInstr>;
 using FunctionStringLocate =
         FunctionBinaryToType<DataTypeString, DataTypeString, StringLocateImpl, NameLocate>;
 using FunctionStringFindInSet =
         FunctionBinaryToType<DataTypeString, DataTypeString, StringFindInSetImpl, NameFindInSet>;
 
-using FunctionUnHex = FunctionStringOperateToNullType<UnHexImpl>;
-
 using FunctionToLower = FunctionStringToString<TransferImpl<NameToLower>, NameToLower>;
 
 using FunctionToUpper = FunctionStringToString<TransferImpl<NameToUpper>, NameToUpper>;
@@ -751,7 +923,6 @@ using FunctionToInitcap = FunctionStringToString<InitcapImpl, NameToInitcap>;
 
 using FunctionUnHex = FunctionStringOperateToNullType<UnHexImpl>;
 using FunctionToBase64 = FunctionStringOperateToNullType<ToBase64Impl>;
-
 using FunctionFromBase64 = FunctionStringOperateToNullType<FromBase64Impl>;
 
 using FunctionStringAppendTrailingCharIfAbsent =
@@ -790,10 +961,11 @@ void register_function_string(SimpleFunctionFactory& factory) {
     factory.register_function<FunctionNullOrEmpty>();
     factory.register_function<FunctionNotNullOrEmpty>();
     factory.register_function<FunctionStringConcat>();
+    factory.register_function<FunctionIntToChar>();
     factory.register_function<FunctionStringElt>();
     factory.register_function<FunctionStringConcatWs>();
     factory.register_function<FunctionStringAppendTrailingCharIfAbsent>();
-    factory.register_function<FunctionStringRepeat>();
+    factory.register_function<FunctionStringRepeat<false>>();
     factory.register_function<FunctionStringLPad>();
     factory.register_function<FunctionStringRPad>();
     factory.register_function<FunctionToBase64>();
@@ -824,6 +996,10 @@ void register_function_string(SimpleFunctionFactory& factory) {
     factory.register_alias(FunctionStringMd5AndSM3<MD5Sum>::name, "md5");
     factory.register_alias(FunctionStringUTF8Length::name, "character_length");
     factory.register_alias(FunctionStringMd5AndSM3<SM3Sum>::name, "sm3");
+
+    /// @TEMPORARY: for be_exec_version=2
+    factory.register_alternative_function<FunctionStringEltOld>();
+    factory.register_alternative_function<FunctionStringRepeat<true>>();
 }
 
 } // namespace doris::vectorized
