@@ -19,6 +19,8 @@
 #include <fmt/format.h>
 
 #include "vec/columns/column_complex.h"
+#include "vec/columns/column_const.h"
+#include "vec/columns/column_nullable.h"
 #include "vec/columns/column_string.h"
 #include "vec/columns/column_vector.h"
 #include "vec/data_types/data_type.h"
@@ -49,21 +51,22 @@ public:
         return std::make_shared<typename Impl::ReturnType>();
     }
 
-    bool use_default_implementation_for_constants() const override { return true; }
-
     Status execute_impl(FunctionContext* context, Block& block, const ColumnNumbers& arguments,
                         size_t result, size_t input_rows_count) override {
         return execute_impl<typename Impl::ReturnType>(block, arguments, result, input_rows_count);
     }
 
     DataTypes get_variadic_argument_types_impl() const override {
-        if constexpr (has_variadic_argument) return Impl::get_variadic_argument_types();
+        if constexpr (has_variadic_argument) {
+            return Impl::get_variadic_argument_types();
+        }
         return {};
     }
 
 private:
     // handle result == DataTypeString
-    template <typename T, std::enable_if_t<std::is_same_v<T, DataTypeString>, T>* = nullptr>
+    template <typename T>
+        requires std::is_same_v<T, DataTypeString>
     Status execute_impl(Block& block, const ColumnNumbers& arguments, size_t result,
                         size_t input_rows_count) {
         const ColumnPtr column = block.get_by_position(arguments[0]).column;
@@ -90,7 +93,8 @@ private:
                                     block.get_by_position(arguments[0]).column->get_name(),
                                     get_name());
     }
-    template <typename T, std::enable_if_t<!std::is_same_v<T, DataTypeString>, T>* = nullptr>
+    template <typename T>
+        requires(!std::is_same_v<T, DataTypeString>)
     Status execute_impl(Block& block, const ColumnNumbers& arguments, size_t result,
                         size_t input_rows_count) {
         const ColumnPtr column = block.get_by_position(arguments[0]).column;
@@ -138,15 +142,13 @@ public:
         return std::make_shared<ResultDataType>();
     }
 
-    bool use_default_implementation_for_constants() const override { return true; }
-
     Status execute_impl(FunctionContext* context, Block& block, const ColumnNumbers& arguments,
                         size_t result, size_t /*input_rows_count*/) override {
         DCHECK_EQ(arguments.size(), 2);
-        const auto& left = block.get_by_position(arguments[0]);
-        auto lcol = left.column->convert_to_full_column_if_const();
-        const auto& right = block.get_by_position(arguments[1]);
-        auto rcol = right.column->convert_to_full_column_if_const();
+        const auto& [lcol, left_const] =
+                unpack_if_const(block.get_by_position(arguments[0]).column);
+        const auto& [rcol, right_const] =
+                unpack_if_const(block.get_by_position(arguments[1]).column);
 
         using ResultDataType = typename Impl<LeftDataType, RightDataType>::ResultDataType;
 
@@ -171,8 +173,17 @@ public:
 
         if (auto col_left = check_and_get_column<ColVecLeft>(lcol.get())) {
             if (auto col_right = check_and_get_column<ColVecRight>(rcol.get())) {
-                Impl<LeftDataType, RightDataType>::vector_vector(col_left->get_data(),
-                                                                 col_right->get_data(), vec_res);
+                if (left_const) {
+                    Impl<LeftDataType, RightDataType>::scalar_vector(
+                            col_left->get_data()[0], col_right->get_data(), vec_res);
+                } else if (right_const) {
+                    Impl<LeftDataType, RightDataType>::vector_scalar(
+                            col_left->get_data(), col_right->get_data()[0], vec_res);
+                } else {
+                    Impl<LeftDataType, RightDataType>::vector_vector(
+                            col_left->get_data(), col_right->get_data(), vec_res);
+                }
+
                 block.replace_by_position(result, std::move(col_res));
                 return Status::OK();
             }
@@ -206,8 +217,6 @@ public:
 
     bool is_variadic() const override { return true; }
 
-    bool use_default_implementation_for_constants() const override { return true; }
-
     Status execute_impl(FunctionContext* context, Block& block, const ColumnNumbers& arguments,
                         size_t result, size_t /*input_rows_count*/) override {
         const auto& left = block.get_by_position(arguments[0]);
@@ -216,13 +225,12 @@ public:
     }
 
 private:
-    template <typename ReturnDataType,
-              std::enable_if_t<!std::is_same_v<ResultDataType, DataTypeString>, ReturnDataType>* =
-                      nullptr>
+    template <typename ReturnDataType>
+        requires(!std::is_same_v<ResultDataType, DataTypeString>)
     Status execute_inner_impl(const ColumnWithTypeAndName& left, const ColumnWithTypeAndName& right,
                               Block& block, const ColumnNumbers& arguments, size_t result) {
-        auto lcol = left.column->convert_to_full_column_if_const();
-        auto rcol = right.column->convert_to_full_column_if_const();
+        const auto& [lcol, left_const] = unpack_if_const(left.column);
+        const auto& [rcol, right_const] = unpack_if_const(right.column);
 
         using ResultType = typename ResultDataType::FieldType;
         using ColVecResult = ColumnVector<ResultType>;
@@ -233,9 +241,20 @@ private:
 
         if (auto col_left = check_and_get_column<ColVecLeft>(lcol.get())) {
             if (auto col_right = check_and_get_column<ColVecRight>(rcol.get())) {
-                Impl<LeftDataType, RightDataType>::vector_vector(
-                        col_left->get_chars(), col_left->get_offsets(), col_right->get_chars(),
-                        col_right->get_offsets(), vec_res);
+                if (left_const) {
+                    Impl<LeftDataType, RightDataType>::scalar_vector(
+                            col_left->get_data_at(0), col_right->get_chars(),
+                            col_right->get_offsets(), vec_res);
+                } else if (right_const) {
+                    Impl<LeftDataType, RightDataType>::vector_scalar(
+                            col_left->get_chars(), col_left->get_offsets(),
+                            col_right->get_data_at(0), vec_res);
+                } else {
+                    Impl<LeftDataType, RightDataType>::vector_vector(
+                            col_left->get_chars(), col_left->get_offsets(), col_right->get_chars(),
+                            col_right->get_offsets(), vec_res);
+                }
+
                 block.replace_by_position(result, std::move(col_res));
                 return Status::OK();
             }
@@ -243,21 +262,32 @@ private:
         return Status::RuntimeError("unimplements function {}", get_name());
     }
 
-    template <typename ReturnDataType,
-              std::enable_if_t<std::is_same_v<ResultDataType, DataTypeString>, ReturnDataType>* =
-                      nullptr>
+    template <typename ReturnDataType>
+        requires std::is_same_v<ResultDataType, DataTypeString>
     Status execute_inner_impl(const ColumnWithTypeAndName& left, const ColumnWithTypeAndName& right,
                               Block& block, const ColumnNumbers& arguments, size_t result) {
-        auto lcol = left.column->convert_to_full_column_if_const();
-        auto rcol = right.column->convert_to_full_column_if_const();
+        const auto& [lcol, left_const] = unpack_if_const(left.column);
+        const auto& [rcol, right_const] = unpack_if_const(right.column);
 
         using ColVecResult = ColumnString;
         typename ColVecResult::MutablePtr col_res = ColVecResult::create();
         if (auto col_left = check_and_get_column<ColVecLeft>(lcol.get())) {
             if (auto col_right = check_and_get_column<ColVecRight>(rcol.get())) {
-                Impl<LeftDataType, RightDataType>::vector_vector(
-                        col_left->get_chars(), col_left->get_offsets(), col_right->get_chars(),
-                        col_right->get_offsets(), col_res->get_chars(), col_res->get_offsets());
+                if (left_const) {
+                    Impl<LeftDataType, RightDataType>::scalar_vector(
+                            col_left->get_data_at(0), col_right->get_chars(),
+                            col_right->get_offsets(), col_res->get_chars(), col_res->get_offsets());
+                } else if (right_const) {
+                    Impl<LeftDataType, RightDataType>::vector_scalar(
+                            col_left->get_chars(), col_left->get_offsets(),
+                            col_right->get_data_at(0), col_res->get_chars(),
+                            col_res->get_offsets());
+                } else {
+                    Impl<LeftDataType, RightDataType>::vector_vector(
+                            col_left->get_chars(), col_left->get_offsets(), col_right->get_chars(),
+                            col_right->get_offsets(), col_res->get_chars(), col_res->get_offsets());
+                }
+
                 block.replace_by_position(result, std::move(col_res));
                 return Status::OK();
             }
@@ -282,24 +312,17 @@ public:
         return make_nullable(std::make_shared<ResultDataType>());
     }
 
-    bool use_default_implementation_for_constants() const override { return true; }
-
     Status execute_impl(FunctionContext* context, Block& block, const ColumnNumbers& arguments,
                         size_t result, size_t input_rows_count) override {
         auto null_map = ColumnUInt8::create(input_rows_count, 0);
         DCHECK_EQ(arguments.size(), 2);
+
         ColumnPtr argument_columns[2];
+        bool col_const[2];
         for (int i = 0; i < 2; ++i) {
-            argument_columns[i] =
-                    block.get_by_position(arguments[i]).column->convert_to_full_column_if_const();
-            if (auto* nullable = check_and_get_column<ColumnNullable>(*argument_columns[i])) {
-                // Danger: Here must dispose the null map data first! Because
-                // argument_columns[i]=nullable->get_nested_column_ptr(); will release the mem
-                // of column nullable mem of null map
-                VectorizedUtils::update_null_map(null_map->get_data(),
-                                                 nullable->get_null_map_data());
-                argument_columns[i] = nullable->get_nested_column_ptr();
-            }
+            std::tie(argument_columns[i], col_const[i]) =
+                    unpack_if_const(block.get_by_position(arguments[i]).column);
+            check_set_nullable(argument_columns[i], null_map, col_const[i]);
         }
 
         using ResultDataType = typename Impl<LeftDataType, RightDataType, ResultDateType,
@@ -326,8 +349,20 @@ public:
 
         if (auto col_left = check_and_get_column<ColVecLeft>(argument_columns[0].get())) {
             if (auto col_right = check_and_get_column<ColVecRight>(argument_columns[1].get())) {
-                Impl<LeftDataType, RightDataType, ResultDateType, ReturnType>::vector_vector(
-                        col_left->get_data(), col_right->get_data(), vec_res, null_map->get_data());
+                if (col_const[0]) {
+                    Impl<LeftDataType, RightDataType, ResultDateType, ReturnType>::scalar_vector(
+                            col_left->get_data()[0], col_right->get_data(), vec_res,
+                            null_map->get_data());
+                } else if (col_const[1]) {
+                    Impl<LeftDataType, RightDataType, ResultDateType, ReturnType>::vector_scalar(
+                            col_left->get_data(), col_right->get_data()[0], vec_res,
+                            null_map->get_data());
+                } else {
+                    Impl<LeftDataType, RightDataType, ResultDateType, ReturnType>::vector_vector(
+                            col_left->get_data(), col_right->get_data(), vec_res,
+                            null_map->get_data());
+                }
+
                 block.get_by_position(result).column =
                         ColumnNullable::create(std::move(col_res), std::move(null_map));
                 return Status::OK();
@@ -350,25 +385,15 @@ public:
     DataTypePtr get_return_type_impl(const DataTypes& arguments) const override {
         return make_nullable(std::make_shared<typename Impl::ReturnType>());
     }
-    bool use_default_implementation_for_constants() const override { return true; }
     Status execute_impl(FunctionContext* context, Block& block, const ColumnNumbers& arguments,
                         size_t result, size_t input_rows_count) override {
         auto null_map = ColumnUInt8::create(input_rows_count, 0);
         ColumnPtr argument_columns[2];
-
-        // focus convert const to full column to simply execute logic
-        // handle
+        bool col_const[2];
         for (int i = 0; i < 2; ++i) {
-            argument_columns[i] =
-                    block.get_by_position(arguments[i]).column->convert_to_full_column_if_const();
-            if (auto* nullable = check_and_get_column<ColumnNullable>(*argument_columns[i])) {
-                // Danger: Here must dispose the null map data first! Because
-                // argument_columns[i]=nullable->get_nested_column_ptr(); will release the mem
-                // of column nullable mem of null map
-                VectorizedUtils::update_null_map(null_map->get_data(),
-                                                 nullable->get_null_map_data());
-                argument_columns[i] = nullable->get_nested_column_ptr();
-            }
+            std::tie(argument_columns[i], col_const[i]) =
+                    unpack_if_const(block.get_by_position(arguments[i]).column);
+            check_set_nullable(argument_columns[i], null_map, col_const[i]);
         }
 
         auto res = Impl::ColumnType::create();
@@ -386,11 +411,27 @@ public:
         if constexpr (std::is_same_v<typename Impl::ReturnType, DataTypeString>) {
             auto& res_data = res->get_chars();
             auto& res_offsets = res->get_offsets();
-            Impl::vector_vector(context, ldata, loffsets, rdata, roffsets, res_data, res_offsets,
-                                null_map->get_data());
+            if (col_const[0]) {
+                Impl::scalar_vector(context, specific_str_column->get_data_at(0), rdata, roffsets,
+                                    res_data, res_offsets, null_map->get_data());
+            } else if (col_const[1]) {
+                Impl::vector_scalar(context, ldata, loffsets, specific_char_column->get_data_at(0),
+                                    res_data, res_offsets, null_map->get_data());
+            } else {
+                Impl::vector_vector(context, ldata, loffsets, rdata, roffsets, res_data,
+                                    res_offsets, null_map->get_data());
+            }
         } else {
-            Impl::vector_vector(context, ldata, loffsets, rdata, roffsets, res->get_data(),
-                                null_map->get_data());
+            if (col_const[0]) {
+                Impl::scalar_vector(context, specific_str_column->get_data_at(0), rdata, roffsets,
+                                    res->get_data(), null_map->get_data());
+            } else if (col_const[1]) {
+                Impl::vector_scalar(context, ldata, loffsets, specific_char_column->get_data_at(0),
+                                    res->get_data(), null_map->get_data());
+            } else {
+                Impl::vector_vector(context, ldata, loffsets, rdata, roffsets, res->get_data(),
+                                    null_map->get_data());
+            }
         }
 
         block.get_by_position(result).column =
@@ -415,16 +456,13 @@ public:
         return make_nullable(std::make_shared<typename Impl::ReturnType>());
     }
 
-    bool use_default_implementation_for_constants() const override { return true; }
-
     bool use_default_implementation_for_nulls() const override { return true; }
 
     Status execute_impl(FunctionContext* context, Block& block, const ColumnNumbers& arguments,
                         size_t result, size_t input_rows_count) override {
         auto null_map = ColumnUInt8::create(input_rows_count, 0);
 
-        auto col_ptr =
-                block.get_by_position(arguments[0]).column->convert_to_full_column_if_const();
+        auto& col_ptr = block.get_by_position(arguments[0]).column;
 
         auto res = Impl::ColumnType::create();
         if (const ColumnString* col = check_and_get_column<ColumnString>(col_ptr.get())) {
