@@ -23,7 +23,9 @@
 #include <mutex>
 #include <string>
 
-#include "exprs/table_function/table_function.h"
+#include "agent/be_exec_version_manager.h"
+#include "udf/udf.h"
+#include "vec/exprs/table_function/table_function.h"
 #include "vec/functions/function.h"
 
 namespace doris::vectorized {
@@ -49,8 +51,10 @@ void register_function_math(SimpleFunctionFactory& factory);
 void register_function_modulo(SimpleFunctionFactory& factory);
 void register_function_bitmap(SimpleFunctionFactory& factory);
 void register_function_bitmap_variadic(SimpleFunctionFactory& factory);
+void register_function_quantile_state(SimpleFunctionFactory& factory);
 void register_function_is_null(SimpleFunctionFactory& factory);
 void register_function_is_not_null(SimpleFunctionFactory& factory);
+void register_function_non_nullable(SimpleFunctionFactory& factory);
 void register_function_to_time_function(SimpleFunctionFactory& factory);
 void register_function_time_of_function(SimpleFunctionFactory& factory);
 void register_function_string(SimpleFunctionFactory& factory);
@@ -79,6 +83,9 @@ void register_function_convert_tz(SimpleFunctionFactory& factory);
 void register_function_least_greast(SimpleFunctionFactory& factory);
 void register_function_fake(SimpleFunctionFactory& factory);
 void register_function_array(SimpleFunctionFactory& factory);
+void register_function_map(SimpleFunctionFactory& factory);
+void register_function_struct(SimpleFunctionFactory& factory);
+void register_function_struct_element(SimpleFunctionFactory& factory);
 void register_function_geo(SimpleFunctionFactory& factory);
 void register_function_multi_string_position(SimpleFunctionFactory& factory);
 void register_function_multi_string_search(SimpleFunctionFactory& factory);
@@ -87,6 +94,8 @@ void register_function_width_bucket(SimpleFunctionFactory& factory);
 void register_function_encryption(SimpleFunctionFactory& factory);
 void register_function_regexp_extract(SimpleFunctionFactory& factory);
 void register_function_hex_variadic(SimpleFunctionFactory& factory);
+void register_function_match(SimpleFunctionFactory& factory);
+void register_function_tokenize(SimpleFunctionFactory& factory);
 
 void register_function_url(SimpleFunctionFactory& factory);
 
@@ -94,6 +103,8 @@ class SimpleFunctionFactory {
     using Creator = std::function<FunctionBuilderPtr()>;
     using FunctionCreators = phmap::flat_hash_map<std::string, Creator>;
     using FunctionIsVariadic = phmap::flat_hash_set<std::string>;
+    /// @TEMPORARY: for be_exec_version=2
+    constexpr static int DATETIME_FUNCTION_NEW = 2;
 
 public:
     void register_function(const std::string& name, const Creator& ptr) {
@@ -130,14 +141,25 @@ public:
         function_alias[alias] = name;
     }
 
+    /// @TEMPORARY: for be_exec_version=2
+    template <class Function>
+    void register_alternative_function() {
+        static std::string suffix {"_old_for_version_before_2_0"};
+        function_to_replace[Function::name] = Function::name + suffix;
+        register_function(Function::name + suffix, &createDefaultFunction<Function>);
+    }
+
     FunctionBasePtr get_function(const std::string& name, const ColumnsWithTypeAndName& arguments,
-                                 const DataTypePtr& return_type) {
+                                 const DataTypePtr& return_type,
+                                 int be_version = BeExecVersionManager::get_newest_version()) {
         std::string key_str = name;
 
         if (function_alias.count(name)) {
             key_str = function_alias[name];
         }
 
+        temporary_function_update(be_version, key_str);
+
         // if function is variadic, added types_str as key
         if (function_variadic_set.count(key_str)) {
             for (auto& arg : arguments) {
@@ -150,30 +172,42 @@ public:
         }
 
         auto iter = function_creators.find(key_str);
-        if (iter != function_creators.end()) {
-            return iter->second()->build(arguments, return_type);
+        if (iter == function_creators.end()) {
+            LOG(WARNING) << fmt::format("Function signature {} is not found", key_str);
+            return nullptr;
         }
 
-        LOG(WARNING) << fmt::format("Function signature {} is not found", key_str);
-        return nullptr;
+        return iter->second()->build(arguments, return_type);
     }
 
 private:
     FunctionCreators function_creators;
     FunctionIsVariadic function_variadic_set;
     std::unordered_map<std::string, std::string> function_alias;
+    /// @TEMPORARY: for be_exec_version=2. replace function to old version.
+    std::unordered_map<std::string, std::string> function_to_replace;
 
     template <typename Function>
     static FunctionBuilderPtr createDefaultFunction() {
         return std::make_shared<DefaultFunctionBuilder>(Function::create());
     }
 
+    /// @TEMPORARY: for be_exec_version=2
+    void temporary_function_update(int fe_version_now, std::string& name) {
+        // replace if fe is old version.
+        if (fe_version_now < DATETIME_FUNCTION_NEW &&
+            function_to_replace.find(name) != function_to_replace.end()) {
+            name = function_to_replace[name];
+        }
+    }
+
 public:
     static SimpleFunctionFactory& instance() {
         static std::once_flag oc;
         static SimpleFunctionFactory instance;
         std::call_once(oc, []() {
             register_function_bitmap(instance);
+            register_function_quantile_state(instance);
             register_function_bitmap_variadic(instance);
             register_function_hll_cardinality(instance);
             register_function_hll_empty(instance);
@@ -193,6 +227,7 @@ public:
             register_function_bit(instance);
             register_function_is_null(instance);
             register_function_is_not_null(instance);
+            register_function_non_nullable(instance);
             register_function_to_time_function(instance);
             register_function_time_of_function(instance);
             register_function_string(instance);
@@ -225,11 +260,16 @@ public:
             register_function_regexp_extract(instance);
             register_function_hex_variadic(instance);
             register_function_array(instance);
+            register_function_map(instance);
+            register_function_struct(instance);
+            register_function_struct_element(instance);
             register_function_geo(instance);
             register_function_url(instance);
             register_function_multi_string_position(instance);
             register_function_multi_string_search(instance);
             register_function_width_bucket(instance);
+            register_function_match(instance);
+            register_function_tokenize(instance);
         });
         return instance;
     }
