@@ -21,6 +21,7 @@
 #include <snappy/snappy.h>
 
 #include <iostream>
+#include <unordered_map>
 
 #include "common/exception.h"
 #include "util/binary_cast.hpp"
@@ -42,7 +43,7 @@ static constexpr size_t DEFAULT_MAX_STRING_SIZE = 1073741824; // 1GB
 static constexpr size_t DEFAULT_MAX_JSON_SIZE = 1073741824;   // 1GB
 static constexpr auto WRITE_HELPERS_MAX_INT_WIDTH = 40U;
 
-using ZoneList = std::map<std::string, cctz::time_zone>;
+using ZoneList = std::unordered_map<std::string, cctz::time_zone>;
 
 inline std::string int128_to_string(__int128_t value) {
     fmt::memory_buffer buffer;
@@ -269,6 +270,34 @@ bool read_int_text_impl(T& x, ReadBuffer& buf) {
     return true;
 }
 
+template <typename T>
+bool read_date_text_impl(T& x, ReadBuffer& buf) {
+    static_assert(std::is_same_v<Int64, T>);
+    auto dv = binary_cast<Int64, VecDateTimeValue>(x);
+    auto ans = dv.from_date_str(buf.position(), buf.count());
+    dv.cast_to_date();
+
+    // only to match the is_all_read() check to prevent return null
+    buf.position() = buf.end();
+    x = binary_cast<VecDateTimeValue, Int64>(dv);
+    return ans;
+}
+
+template <typename T>
+bool read_date_text_impl(T& x, ReadBuffer& buf, const cctz::time_zone& local_time_zone,
+                         ZoneList& time_zone_cache, std::shared_mutex& cache_lock) {
+    static_assert(std::is_same_v<Int64, T>);
+    auto dv = binary_cast<Int64, VecDateTimeValue>(x);
+    auto ans = dv.from_date_str(buf.position(), buf.count(), local_time_zone, time_zone_cache,
+                                &cache_lock);
+    dv.cast_to_date();
+
+    // only to match the is_all_read() check to prevent return null
+    buf.position() = buf.end();
+    x = binary_cast<VecDateTimeValue, Int64>(dv);
+    return ans;
+}
+
 template <typename T>
 bool read_datetime_text_impl(T& x, ReadBuffer& buf) {
     static_assert(std::is_same_v<Int64, T>);
@@ -283,11 +312,13 @@ bool read_datetime_text_impl(T& x, ReadBuffer& buf) {
 }
 
 template <typename T>
-bool read_date_text_impl(T& x, ReadBuffer& buf) {
+bool read_datetime_text_impl(T& x, ReadBuffer& buf, const cctz::time_zone& local_time_zone,
+                             ZoneList& time_zone_cache, std::shared_mutex& cache_lock) {
     static_assert(std::is_same_v<Int64, T>);
     auto dv = binary_cast<Int64, VecDateTimeValue>(x);
-    auto ans = dv.from_date_str(buf.position(), buf.count());
-    dv.cast_to_date();
+    auto ans = dv.from_date_str(buf.position(), buf.count(), local_time_zone, time_zone_cache,
+                                &cache_lock);
+    dv.to_datetime();
 
     // only to match the is_all_read() check to prevent return null
     buf.position() = buf.end();
@@ -309,10 +340,11 @@ bool read_date_v2_text_impl(T& x, ReadBuffer& buf) {
 
 template <typename T>
 bool read_date_v2_text_impl(T& x, ReadBuffer& buf, const cctz::time_zone& local_time_zone,
-                            ZoneList& time_zone_cache) {
+                            ZoneList& time_zone_cache, std::shared_mutex& cache_lock) {
     static_assert(std::is_same_v<UInt32, T>);
     auto dv = binary_cast<UInt32, DateV2Value<DateV2ValueType>>(x);
-    auto ans = dv.from_date_str(buf.position(), buf.count(), local_time_zone, time_zone_cache);
+    auto ans = dv.from_date_str(buf.position(), buf.count(), local_time_zone, time_zone_cache,
+                                &cache_lock);
 
     // only to match the is_all_read() check to prevent return null
     buf.position() = buf.end();
@@ -334,11 +366,12 @@ bool read_datetime_v2_text_impl(T& x, ReadBuffer& buf, UInt32 scale = -1) {
 
 template <typename T>
 bool read_datetime_v2_text_impl(T& x, ReadBuffer& buf, const cctz::time_zone& local_time_zone,
-                                ZoneList& time_zone_cache, UInt32 scale = -1) {
+                                ZoneList& time_zone_cache, std::shared_mutex& cache_lock,
+                                UInt32 scale = -1) {
     static_assert(std::is_same_v<UInt64, T>);
     auto dv = binary_cast<UInt64, DateV2Value<DateTimeV2ValueType>>(x);
-    auto ans =
-            dv.from_date_str(buf.position(), buf.count(), local_time_zone, time_zone_cache, scale);
+    auto ans = dv.from_date_str(buf.position(), buf.count(), local_time_zone, time_zone_cache,
+                                &cache_lock, scale);
 
     // only to match the is_all_read() check to prevent return null
     buf.position() = buf.end();
@@ -346,13 +379,13 @@ bool read_datetime_v2_text_impl(T& x, ReadBuffer& buf, const cctz::time_zone& lo
     return ans;
 }
 
-template <typename T>
+template <PrimitiveType P, typename T>
 bool read_decimal_text_impl(T& x, ReadBuffer& buf, UInt32 precision, UInt32 scale) {
     static_assert(IsDecimalNumber<T>);
     if constexpr (!std::is_same_v<Decimal128, T>) {
         StringParser::ParseResult result = StringParser::PARSE_SUCCESS;
 
-        x.value = StringParser::string_to_decimal<typename T::NativeType>(
+        x.value = StringParser::string_to_decimal<P, typename T::NativeType>(
                 (const char*)buf.position(), buf.count(), precision, scale, &result);
         // only to match the is_all_read() check to prevent return null
         buf.position() = buf.end();
@@ -360,9 +393,9 @@ bool read_decimal_text_impl(T& x, ReadBuffer& buf, UInt32 precision, UInt32 scal
     } else {
         StringParser::ParseResult result = StringParser::PARSE_SUCCESS;
 
-        x.value = StringParser::string_to_decimal<__int128>(buf.position(), buf.count(),
-                                                            DecimalV2Value::PRECISION,
-                                                            DecimalV2Value::SCALE, &result);
+        x.value = StringParser::string_to_decimal<TYPE_DECIMALV2, __int128>(
+                buf.position(), buf.count(), DecimalV2Value::PRECISION, DecimalV2Value::SCALE,
+                &result);
 
         // only to match the is_all_read() check to prevent return null
         buf.position() = buf.end();
@@ -416,30 +449,34 @@ bool try_read_float_text(T& x, ReadBuffer& in) {
     return read_float_text_fast_impl<T>(x, in);
 }
 
-template <typename T>
+template <PrimitiveType P, typename T>
 bool try_read_decimal_text(T& x, ReadBuffer& in, UInt32 precision, UInt32 scale) {
-    return read_decimal_text_impl<T>(x, in, precision, scale);
+    return read_decimal_text_impl<P, T>(x, in, precision, scale);
 }
 
 template <typename T>
-bool try_read_datetime_text(T& x, ReadBuffer& in) {
-    return read_datetime_text_impl<T>(x, in);
+bool try_read_datetime_text(T& x, ReadBuffer& in, const cctz::time_zone& local_time_zone,
+                            ZoneList& time_zone_cache, std::shared_mutex& cache_lock) {
+    return read_datetime_text_impl<T>(x, in, local_time_zone, time_zone_cache, cache_lock);
 }
 
 template <typename T>
-bool try_read_date_text(T& x, ReadBuffer& in) {
-    return read_date_text_impl<T>(x, in);
+bool try_read_date_text(T& x, ReadBuffer& in, const cctz::time_zone& local_time_zone,
+                        ZoneList& time_zone_cache, std::shared_mutex& cache_lock) {
+    return read_date_text_impl<T>(x, in, local_time_zone, time_zone_cache, cache_lock);
 }
 
 template <typename T>
 bool try_read_date_v2_text(T& x, ReadBuffer& in, const cctz::time_zone& local_time_zone,
-                           ZoneList& time_zone_cache) {
-    return read_date_v2_text_impl<T>(x, in, local_time_zone, time_zone_cache);
+                           ZoneList& time_zone_cache, std::shared_mutex& cache_lock) {
+    return read_date_v2_text_impl<T>(x, in, local_time_zone, time_zone_cache, cache_lock);
 }
 
 template <typename T>
 bool try_read_datetime_v2_text(T& x, ReadBuffer& in, const cctz::time_zone& local_time_zone,
-                               ZoneList& time_zone_cache, UInt32 scale) {
-    return read_datetime_v2_text_impl<T>(x, in, local_time_zone, time_zone_cache, scale);
+                               ZoneList& time_zone_cache, std::shared_mutex& cache_lock,
+                               UInt32 scale) {
+    return read_datetime_v2_text_impl<T>(x, in, local_time_zone, time_zone_cache, cache_lock,
+                                         scale);
 }
 } // namespace doris::vectorized
