@@ -17,11 +17,13 @@
 
 #include "runtime/decimalv2_value.h"
 
-#include <gtest/gtest.h>
+#include <gtest/gtest-message.h>
+#include <gtest/gtest-test-part.h>
 
-#include <iostream>
 #include <string>
 
+#include "gtest/gtest_pred_impl.h"
+
 namespace doris {
 
 class DecimalV2ValueTest : public testing::Test {
