@@ -15,15 +15,17 @@
 // specific language governing permissions and limitations
 // under the License.
 
-#include <gtest/gtest.h>
-#include <time.h>
-
 #include <string>
+#include <vector>
 
+#include "common/status.h"
 #include "function_test_util.h"
-#include "runtime/tuple_row.h"
-#include "util/url_coding.h"
+#include "gtest/gtest_pred_impl.h"
+#include "testutil/any_type.h"
 #include "vec/core/field.h"
+#include "vec/core/types.h"
+#include "vec/data_types/data_type_nullable.h"
+#include "vec/data_types/data_type_number.h"
 
 namespace doris::vectorized {
 
