@@ -15,29 +15,48 @@
 // specific language governing permissions and limitations
 // under the License.
 
-#include <gtest/gtest.h>
+#include <gtest/gtest-message.h>
+#include <gtest/gtest-test-part.h>
+#include <stdint.h>
 #include <time.h>
 
-#include <any>
-#include <iostream>
+#include <memory>
 #include <string>
+#include <utility>
+#include <vector>
 
-#include "exprs/table_function/table_function.h"
+#include "common/status.h"
+#include "gtest/gtest_pred_impl.h"
+#include "olap/olap_common.h"
+#include "runtime/define_primitive_type.h"
+#include "runtime/types.h"
 #include "testutil/any_type.h"
 #include "testutil/function_utils.h"
 #include "udf/udf.h"
-#include "udf/udf_internal.h"
+#include "util/jsonb_utils.h"
 #include "vec/columns/column.h"
 #include "vec/columns/column_const.h"
-#include "vec/core/columns_with_type_and_name.h"
-#include "vec/data_types/data_type_date_time.h"
-#include "vec/data_types/data_type_decimal.h"
-#include "vec/data_types/data_type_jsonb.h"
+#include "vec/common/string_ref.h"
+#include "vec/core/block.h"
+#include "vec/core/column_numbers.h"
+#include "vec/core/column_with_type_and_name.h"
+#include "vec/core/field.h"
+#include "vec/core/types.h"
+#include "vec/data_types/data_type.h"
+#include "vec/data_types/data_type_nullable.h"
 #include "vec/data_types/data_type_number.h"
-#include "vec/data_types/data_type_string.h"
-#include "vec/data_types/data_type_time.h"
 #include "vec/functions/simple_function_factory.h"
 
+namespace doris {
+namespace vectorized {
+class DataTypeJsonb;
+class DataTypeTime;
+class TableFunction;
+template <typename T>
+class DataTypeDecimal;
+} // namespace vectorized
+} // namespace doris
+
 namespace doris::vectorized {
 
 using InputDataSet = std::vector<std::vector<AnyType>>; // without result
@@ -150,7 +169,7 @@ constexpr TypeIndex get_type_index() {
 
 struct UTDataTypeDesc {
     DataTypePtr data_type;
-    doris_udf::FunctionContext::TypeDesc type_desc;
+    doris::TypeDescriptor type_desc;
     std::string col_name;
     bool is_const = false;
     bool is_nullable = true;
@@ -206,9 +225,9 @@ Status check_function(const std::string& func_name, const InputTypeSet& input_ty
 
     // 1.2 prepare args for function call
     ColumnNumbers arguments;
-    std::vector<doris_udf::FunctionContext::TypeDesc> arg_types;
+    std::vector<doris::TypeDescriptor> arg_types;
     std::vector<std::shared_ptr<ColumnPtrWrapper>> constant_col_ptrs;
-    std::vector<ColumnPtrWrapper*> constant_cols;
+    std::vector<std::shared_ptr<ColumnPtrWrapper>> constant_cols;
     for (size_t i = 0; i < descs.size(); ++i) {
         auto& desc = descs[i];
         arguments.push_back(i);
@@ -216,7 +235,7 @@ Status check_function(const std::string& func_name, const InputTypeSet& input_ty
         if (desc.is_const) {
             constant_col_ptrs.push_back(
                     std::make_shared<ColumnPtrWrapper>(block.get_by_position(i).column));
-            constant_cols.push_back(constant_col_ptrs.back().get());
+            constant_cols.push_back(constant_col_ptrs.back());
         } else {
             constant_cols.push_back(nullptr);
         }
@@ -229,29 +248,29 @@ Status check_function(const std::string& func_name, const InputTypeSet& input_ty
             func_name, block.get_columns_with_type_and_name(), return_type);
     EXPECT_TRUE(func != nullptr);
 
-    doris_udf::FunctionContext::TypeDesc fn_ctx_return;
+    doris::TypeDescriptor fn_ctx_return;
     if constexpr (std::is_same_v<ReturnType, DataTypeUInt8>) {
-        fn_ctx_return.type = doris_udf::FunctionContext::TYPE_BOOLEAN;
+        fn_ctx_return.type = doris::PrimitiveType::TYPE_BOOLEAN;
     } else if constexpr (std::is_same_v<ReturnType, DataTypeInt32>) {
-        fn_ctx_return.type = doris_udf::FunctionContext::TYPE_INT;
+        fn_ctx_return.type = doris::PrimitiveType::TYPE_INT;
     } else if constexpr (std::is_same_v<ReturnType, DataTypeFloat64> ||
                          std::is_same_v<ReturnType, DataTypeTime>) {
-        fn_ctx_return.type = doris_udf::FunctionContext::TYPE_DOUBLE;
+        fn_ctx_return.type = doris::PrimitiveType::TYPE_DOUBLE;
     } else if constexpr (std::is_same_v<ReturnType, DateTime>) {
-        fn_ctx_return.type = doris_udf::FunctionContext::TYPE_DATETIME;
+        fn_ctx_return.type = doris::PrimitiveType::TYPE_DATETIME;
     } else if (std::is_same_v<ReturnType, DateV2>) {
-        fn_ctx_return.type = doris_udf::FunctionContext::TYPE_DATEV2;
+        fn_ctx_return.type = doris::PrimitiveType::TYPE_DATEV2;
     } else if (std::is_same_v<ReturnType, DateTimeV2>) {
-        fn_ctx_return.type = doris_udf::FunctionContext::TYPE_DATETIMEV2;
+        fn_ctx_return.type = doris::PrimitiveType::TYPE_DATETIMEV2;
     } else {
-        fn_ctx_return.type = doris_udf::FunctionContext::INVALID_TYPE;
+        fn_ctx_return.type = doris::PrimitiveType::INVALID_TYPE;
     }
 
     FunctionUtils fn_utils(fn_ctx_return, arg_types, 0);
     auto* fn_ctx = fn_utils.get_fn_ctx();
-    fn_ctx->impl()->set_constant_cols(constant_cols);
-    func->prepare(fn_ctx, FunctionContext::FRAGMENT_LOCAL);
-    func->prepare(fn_ctx, FunctionContext::THREAD_LOCAL);
+    fn_ctx->set_constant_cols(constant_cols);
+    func->open(fn_ctx, FunctionContext::FRAGMENT_LOCAL);
+    func->open(fn_ctx, FunctionContext::THREAD_LOCAL);
 
     block.insert({nullptr, return_type, "result"});
 
