@@ -122,4 +122,12 @@ CREATE TABLE doris_test.json
     `o` JSON
 )
 ENGINE = MergeTree
-ORDER BY id;
\ No newline at end of file
+ORDER BY id;
+
+CREATE TABLE doris_test.final_test
+(
+    key Int64,
+    some String
+)
+    ENGINE = ReplacingMergeTree
+ORDER BY key;
