@@ -17,10 +17,20 @@
 # under the License.
 
 nohup /opt/hive/bin/hive --service metastore &
-sleep 10
+
+# wait metastore start
+sleep 10s
+
+# if you test in your local，better use # to annotation section about tpch1.db
 if [[ ! -d "/mnt/scripts/tpch1.db" ]]; then
     echo "/mnt/scripts/tpch1.db does not exist"
     exit 1
+else
+    wget -P /mnt/scripts https://doris-build-hk-1308700295.cos.ap-hongkong.myqcloud.com/regression/load/tpch1_parquet/tpch1.db.tar.gz
+    cd /mnt/scripts/
+    tar -zxf tpch1.db.tar.gz
+    rm -rf tpch1.db.tar.gz
+    cd -
 fi
 
 # put data file
