@@ -112,3 +112,15 @@ create table doris_test.test_clob (
   id number(11) not null primary key,
   num1 clob
 );
+
+create table doris_test."AA/D" (
+     id number(5),
+     name varchar2(20),
+     age number(2),
+     score number(3,1)
+);
+
+create table doris_test.aaad (
+     id number(5),
+     name varchar2(20)
+);
\ No newline at end of file
