@@ -77,4 +77,7 @@ insert into doris_test.test_number4 values (1, 12345678);
 insert into doris_test.test_number4 values (2, 123456789012);
 insert into doris_test.test_clob values (10086, 'yidong');
 insert into doris_test.test_clob values (10010, 'liantong');
+
+insert into doris_test."AA/D" values (1, 'alice', 20, 99.5);
+insert into doris_test.aaad values (1, 'alice');
 commit;
