@@ -114,6 +114,13 @@ CREATE TABLE doris_test.test8 (
   CONSTRAINT "f_a_w_r_p" PRIMARY KEY ("id")
 );
 
+CREATE TABLE doris_test.test9 (
+  id1 smallint,
+  id2 int,
+  id3 bool,
+  id4 varchar(10),
+  id5 bigint
+);
 
 CREATE TABLE catalog_pg_test.test10 (
    ID INT NOT NULL,
@@ -149,3 +156,25 @@ CREATE TABLE catalog_pg_test.test_insert (
    name varchar(128),
    age int
 );
+
+CREATE TABLE catalog_pg_test.wkb_test (
+   id SERIAL PRIMARY KEY,
+   location bytea
+);
+
+CREATE TABLE catalog_pg_test.dt_test (
+    ts_field TIMESTAMP(3),
+    tzt_field TIMESTAMPTZ(3)
+);
+
+CREATE TABLE catalog_pg_test.json_test (
+    id serial PRIMARY KEY,
+    type varchar(10),
+    value json
+);
+
+CREATE TABLE catalog_pg_test.jsonb_test (
+    id serial PRIMARY KEY,
+    type varchar(10),
+    value jsonb
+);
