@@ -30,6 +30,7 @@ import com.google.gson.annotations.SerializedName;
 import org.apache.logging.log4j.LogManager;
 import org.apache.logging.log4j.Logger;
 
+import java.math.BigDecimal;
 import java.util.Objects;
 
 /**
@@ -80,6 +81,20 @@ public class ScalarType extends Type {
     public static final int DEFAULT_MIN_AVG_DECIMAL128_SCALE = 4;
     public static final int MAX_DATETIMEV2_SCALE = 6;
 
+    private long byteSize = -1;
+
+
+    /**
+     * Set byte size of expression
+     */
+    public void setByteSize(long byteSize) {
+        this.byteSize = byteSize;
+    }
+
+    public long getByteSize() {
+        return byteSize;
+    }
+
     private static final Logger LOG = LogManager.getLogger(ScalarType.class);
     @SerializedName(value = "type")
     private final PrimitiveType type;
@@ -123,8 +138,13 @@ public class ScalarType extends Type {
             case DECIMAL32:
             case DECIMAL64:
             case DECIMAL128:
+                return createDecimalV3Type(precision, scale);
             case DECIMALV2:
                 return createDecimalType(precision, scale);
+            case DATETIMEV2:
+                return createDatetimeV2Type(scale);
+            case TIMEV2:
+                return createTimeV2Type(scale);
             default:
                 return createType(type);
         }
@@ -166,6 +186,10 @@ public class ScalarType extends Type {
                 return BITMAP;
             case QUANTILE_STATE:
                 return QUANTILE_STATE;
+            case AGG_STATE:
+                return AGG_STATE;
+            case LAMBDA_FUNCTION:
+                return LAMBDA_FUNCTION;
             case DATE:
                 return DATE;
             case DATETIME:
@@ -221,7 +245,7 @@ public class ScalarType extends Type {
                 return CHAR;
             case "VARCHAR":
                 return createVarcharType();
-            case "JSONB":
+            case "JSON":
                 return createJsonbType();
             case "STRING":
             case "TEXT":
@@ -232,6 +256,10 @@ public class ScalarType extends Type {
                 return BITMAP;
             case "QUANTILE_STATE":
                 return QUANTILE_STATE;
+            case "AGG_STATE":
+                return AGG_STATE;
+            case "LAMBDA_FUNCTION":
+                return LAMBDA_FUNCTION;
             case "DATE":
                 return DATE;
             case "DATETIME":
@@ -489,7 +517,9 @@ public class ScalarType extends Type {
     }
 
     public static ScalarType createVarcharType() {
-        return DEFAULT_VARCHAR;
+        // Because ScalarType is not an immutable class, it will call setLength() sometimes.
+        // So currently don't use DEFAULT_VARCHAR, will improve it in the future.
+        return new ScalarType(PrimitiveType.VARCHAR);
     }
 
     public static ScalarType createHllType() {
@@ -507,27 +537,27 @@ public class ScalarType extends Type {
             return "CHAR(" + len + ")";
         } else  if (type == PrimitiveType.DECIMALV2) {
             if (isWildcardDecimal()) {
-                return "DECIMAL(*,*)";
+                return "DECIMAL(*, *)";
             }
-            return "DECIMAL(" + precision + "," + scale + ")";
+            return "DECIMAL(" + precision + ", " + scale + ")";
         } else  if (type.isDecimalV3Type()) {
             if (isWildcardDecimal()) {
-                return "DECIMALV3(*,*)";
+                return "DECIMALV3(*, *)";
             }
-            return "DECIMALV3(" + precision + "," + scale + ")";
+            return "DECIMALV3(" + precision + ", " + scale + ")";
         } else  if (type == PrimitiveType.DATETIMEV2) {
             return "DATETIMEV2(" + scale + ")";
         } else  if (type == PrimitiveType.TIMEV2) {
             return "TIMEV2(" + scale + ")";
         } else if (type == PrimitiveType.VARCHAR) {
             if (isWildcardVarchar()) {
-                return "VARCHAR";
+                return "VARCHAR(*)";
             }
             return "VARCHAR(" + len + ")";
         } else if (type == PrimitiveType.STRING) {
             return "TEXT";
         } else if (type == PrimitiveType.JSONB) {
-            return "JSONB";
+            return "JSON";
         }
         return type.toString();
     }
@@ -544,7 +574,9 @@ public class ScalarType extends Type {
                 }
                 break;
             case VARCHAR:
-                if (Strings.isNullOrEmpty(lenStr)) {
+                if (isWildcardVarchar()) {
+                    stringBuilder.append("varchar");
+                } else if (Strings.isNullOrEmpty(lenStr)) {
                     stringBuilder.append("varchar").append("(").append(len).append(")");
                 } else {
                     stringBuilder.append("varchar").append("(`").append(lenStr).append("`)");
@@ -603,20 +635,21 @@ public class ScalarType extends Type {
             case DATEV2:
             case HLL:
             case BITMAP:
+            case VARIANT:
             case QUANTILE_STATE:
+            case LAMBDA_FUNCTION:
+            case ARRAY:
+            case NULL_TYPE:
                 stringBuilder.append(type.toString().toLowerCase());
                 break;
             case STRING:
                 stringBuilder.append("text");
                 break;
             case JSONB:
-                stringBuilder.append("jsonb");
+                stringBuilder.append("json");
                 break;
-            case ARRAY:
-                stringBuilder.append(type.toString().toLowerCase());
-                break;
-            case NULL_TYPE:
-                stringBuilder.append(type.toString().toLowerCase());
+            case AGG_STATE:
+                stringBuilder.append("agg_state(unknown)");
                 break;
             default:
                 stringBuilder.append("unknown type: " + type.toString());
@@ -637,6 +670,7 @@ public class ScalarType extends Type {
         node.setType(TTypeNodeType.SCALAR);
         TScalarType scalarType = new TScalarType();
         scalarType.setType(type.toThrift());
+        container.setByteSize(byteSize);
 
         switch (type) {
             case VARCHAR:
@@ -657,6 +691,12 @@ public class ScalarType extends Type {
                 scalarType.setPrecision(precision);
                 break;
             }
+            case TIMEV2: {
+                Preconditions.checkArgument(precision >= scale);
+                scalarType.setScale(scale);
+                scalarType.setPrecision(precision);
+                break;
+            }
             default:
                 break;
         }
@@ -695,6 +735,18 @@ public class ScalarType extends Type {
         this.len = len;
     }
 
+    public void setMaxLength() {
+        if (type == PrimitiveType.CHAR) {
+            this.len = MAX_CHAR_LENGTH;
+        }
+        if (type == PrimitiveType.VARCHAR) {
+            this.len = MAX_VARCHAR_LENGTH;
+        }
+        if (type == PrimitiveType.STRING) {
+            this.len = MAX_STRING_LENGTH;
+        }
+    }
+
     public boolean isLengthSet() {
         return getPrimitiveType() == PrimitiveType.HLL || len > 0 || !Strings.isNullOrEmpty(lenStr);
     }
@@ -781,6 +833,9 @@ public class ScalarType extends Type {
         if (equals(t)) {
             return true;
         }
+        if (t.isAnyType()) {
+            return t.matchesType(this);
+        }
         if (!t.isScalarType()) {
             return false;
         }
@@ -793,17 +848,14 @@ public class ScalarType extends Type {
             Preconditions.checkState(!isWildcardChar());
             return true;
         }
-        if (type == PrimitiveType.CHAR && scalarType.isStringType()) {
+        if (type.isStringType() && scalarType.isStringType()) {
             return true;
         }
-        if (type == PrimitiveType.VARCHAR && scalarType.isStringType()) {
-            return true;
-        }
-        if (isDecimalV2() && scalarType.isWildcardDecimal()) {
+        if (isDecimalV2() && scalarType.isWildcardDecimal() && scalarType.isDecimalV2()) {
             Preconditions.checkState(!isWildcardDecimal());
             return true;
         }
-        if (isDecimalV3() && scalarType.isWildcardDecimal()) {
+        if (isDecimalV3() && scalarType.isWildcardDecimal() && scalarType.isDecimalV3()) {
             Preconditions.checkState(!isWildcardDecimal());
             return true;
         }
@@ -825,7 +877,10 @@ public class ScalarType extends Type {
             return false;
         }
         ScalarType other = (ScalarType) o;
-        if ((this.isDatetimeV2() && other.isDatetimeV2()) || (this.isTimeV2() && other.isTimeV2())) {
+        if ((this.isDatetimeV2() && other.isDatetimeV2())) {
+            return this.decimalScale() == other.decimalScale();
+        }
+        if (this.isTimeV2() && other.isTimeV2()) {
             return this.decimalScale() == other.decimalScale();
         }
         if (type.isDecimalV3Type() && other.isDecimalV3()) {
@@ -1013,6 +1068,12 @@ public class ScalarType extends Type {
             return getAssignmentCompatibleDecimalV2Type(t1, t2);
         }
 
+        if ((t1.isDecimalV3() && t2.isDecimalV2()) || (t2.isDecimalV3() && t1.isDecimalV2())) {
+            int scale = Math.max(t1.scale, t2.scale);
+            int integerPart = Math.max(t1.precision - t1.scale, t2.precision - t2.scale);
+            return ScalarType.createDecimalV3Type(integerPart + scale, scale);
+        }
+
         if (t1.isDecimalV2() || t2.isDecimalV2()) {
             if (t1.isFloatingPointType() || t2.isFloatingPointType()) {
                 return Type.DOUBLE;
@@ -1028,6 +1089,36 @@ public class ScalarType extends Type {
             }
         }
 
+        if ((t1.isDecimalV3() && t2.isFixedPointType())
+                || (t2.isDecimalV3() && t1.isFixedPointType())) {
+            int precision;
+            int scale;
+            ScalarType intType;
+            if (t1.isDecimalV3()) {
+                precision = t1.precision;
+                scale = t1.scale;
+                intType = t2;
+            } else {
+                precision = t2.precision;
+                scale = t2.scale;
+                intType = t1;
+            }
+            int integerPart = precision - scale;
+            if (intType.isScalarType(PrimitiveType.TINYINT)
+                    || intType.isScalarType(PrimitiveType.SMALLINT)) {
+                integerPart = Math.max(integerPart, new BigDecimal(Short.MAX_VALUE).precision());
+            } else if (intType.isScalarType(PrimitiveType.INT)) {
+                integerPart = Math.max(integerPart, new BigDecimal(Integer.MAX_VALUE).precision());
+            } else {
+                integerPart = ScalarType.MAX_DECIMAL128_PRECISION - scale;
+            }
+            if (scale + integerPart <= ScalarType.MAX_DECIMAL128_PRECISION) {
+                return ScalarType.createDecimalV3Type(scale + integerPart, scale);
+            } else {
+                return Type.DOUBLE;
+            }
+        }
+
         if (t1.isDecimalV3() && t2.isDecimalV3()) {
             ScalarType finalType = ScalarType.createDecimalV3Type(Math.max(t1.decimalPrecision() - t1.decimalScale(),
                     t2.decimalPrecision() - t2.decimalScale()) + Math.max(t1.decimalScale(),
@@ -1090,51 +1181,6 @@ public class ScalarType extends Type {
         return PrimitiveType.isImplicitCast(type.getPrimitiveType(), targetType.getPrimitiveType());
     }
 
-    @Override
-    public int getStorageLayoutBytes() {
-        switch (type) {
-            case BOOLEAN:
-            case TINYINT:
-                return 1;
-            case SMALLINT:
-                return 2;
-            case INT:
-            case FLOAT:
-            case DECIMAL32:
-                return 4;
-            case BIGINT:
-            case TIME:
-            case DATETIME:
-            // TODO(Gabriel): unify execution engine and storage engine
-            case TIMEV2:
-            case DATETIMEV2:
-            case DECIMAL64:
-                return 8;
-            case LARGEINT:
-            case DECIMALV2:
-            case DECIMAL128:
-                return 16;
-            case DOUBLE:
-                return 12;
-            case DATEV2:
-            case DATE:
-                return 3;
-            case CHAR:
-            case VARCHAR:
-                return len;
-            case HLL:
-                return 16385;
-            case BITMAP:
-                return 1024; // this is a estimated value
-            case QUANTILE_STATE:
-                return 1024; // TODO(weixiang): no used in FE, figure out whether can delete this funcion?
-            case STRING:
-                return 1024;
-            default:
-                return 0;
-        }
-    }
-
     @Override
     public TColumnType toColumnTypeThrift() {
         TColumnType thrift = new TColumnType();
