@@ -491,8 +491,6 @@ public class CreateTableStmt extends DdlStmt {
                 columnDefs.add(ColumnDef.newVersionColumnDef(AggregateType.REPLACE));
             }
         }
-        boolean hasObjectStored = false;
-        String objectStoredColumn = "";
         Set<String> columnSet = Sets.newTreeSet(String.CASE_INSENSITIVE_ORDER);
         for (ColumnDef columnDef : columnDefs) {
             columnDef.analyze(engineName.equals("olap"));
@@ -519,8 +517,16 @@ public class CreateTableStmt extends DdlStmt {
             }
 
             if (columnDef.getType().isObjectStored()) {
-                hasObjectStored = true;
-                objectStoredColumn = columnDef.getName();
+                if (columnDef.getType().isBitmapType()) {
+                    if (keysDesc.getKeysType() == KeysType.DUP_KEYS) {
+                        throw new AnalysisException("column:" + columnDef.getName()
+                                + " must be used in AGG_KEYS or UNIQUE_KEYS.");
+                    }
+                } else {
+                    if (keysDesc.getKeysType() != KeysType.AGG_KEYS) {
+                        throw new AnalysisException("column:" + columnDef.getName() + " must be used in AGG_KEYS.");
+                    }
+                }
             }
 
             if (!columnSet.add(columnDef.getName())) {
@@ -528,10 +534,6 @@ public class CreateTableStmt extends DdlStmt {
             }
         }
 
-        if (hasObjectStored && keysDesc.getKeysType() != KeysType.AGG_KEYS) {
-            throw new AnalysisException("column:" + objectStoredColumn + " must be used in AGG_KEYS.");
-        }
-
         if (engineName.equals("olap")) {
             // before analyzing partition, handle the replication allocation info
             properties = rewriteReplicaAllocationProperties(properties);
@@ -605,7 +607,7 @@ public class CreateTableStmt extends DdlStmt {
                         }
                     }
                     if (!found) {
-                        throw new AnalysisException("BITMAP column does not exist in table. invalid column: "
+                        throw new AnalysisException("Column does not exist in table. invalid column: "
                                 + indexColName);
                     }
                 }
@@ -703,6 +705,9 @@ public class CreateTableStmt extends DdlStmt {
             sb.append("EXTERNAL ");
         }
         sb.append("TABLE ");
+        if (ifNotExists) {
+            sb.append("IF NOT EXISTS ");
+        }
         sb.append(tableName.toSql()).append(" (\n");
         int idx = 0;
         for (ColumnDef columnDef : columnDefs) {
