@@ -51,14 +51,20 @@ public class ShowCreateTableStmt extends ShowStmt {
 
     private TableName tbl;
     private boolean isView;
+    private boolean needBriefDdl;
 
     public ShowCreateTableStmt(TableName tbl) {
-        this(tbl, false);
+        this(tbl, false, false);
     }
 
-    public ShowCreateTableStmt(TableName tbl, boolean isView) {
+    public ShowCreateTableStmt(TableName tbl, boolean needBriefDdl) {
+        this(tbl, false, needBriefDdl);
+    }
+
+    public ShowCreateTableStmt(TableName tbl, boolean isView, boolean needBriefDdl) {
         this.tbl = tbl;
         this.isView = isView;
+        this.needBriefDdl = needBriefDdl;
     }
 
 
@@ -78,6 +84,10 @@ public class ShowCreateTableStmt extends ShowStmt {
         return isView;
     }
 
+    public boolean isNeedBriefDdl() {
+        return needBriefDdl;
+    }
+
     public static ShowResultSetMetaData getViewMetaData() {
         return VIEW_META_DATA;
     }
@@ -93,8 +103,8 @@ public class ShowCreateTableStmt extends ShowStmt {
         }
         tbl.analyze(analyzer);
 
-        if (!Env.getCurrentEnv().getAuth().checkTblPriv(ConnectContext.get(), tbl.getCtl(),
-                    tbl.getDb(), tbl.getTbl(), PrivPredicate.SHOW)) {
+        if (!Env.getCurrentEnv().getAccessManager().checkTblPriv(ConnectContext.get(), tbl.getCtl(), tbl.getDb(),
+                tbl.getTbl(), PrivPredicate.SHOW)) {
             ErrorReport.reportAnalysisException(ErrorCode.ERR_TABLEACCESS_DENIED_ERROR, "SHOW CREATE TABLE",
                                                 ConnectContext.get().getQualifiedUser(),
                                                 ConnectContext.get().getRemoteIP(),
