@@ -27,10 +27,12 @@ import org.apache.doris.common.ErrorReport;
 import org.apache.doris.common.UserException;
 import org.apache.doris.qe.OriginStatement;
 import org.apache.doris.rewrite.ExprRewriter;
+import org.apache.doris.thrift.TQueryOptions;
 
 import com.google.common.base.Preconditions;
 import com.google.common.base.Strings;
 
+import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
 
@@ -54,6 +56,12 @@ public abstract class StatementBase implements ParseNode {
 
     private UserIdentity userInfo;
 
+    private boolean isPrepared = false;
+
+    // select * from tbl where a = ? and b = ?
+    // `?` is the placeholder
+    private ArrayList<PlaceHolderExpr> placeholders = new ArrayList<>();
+
     protected StatementBase() { }
 
     /**
@@ -98,6 +106,14 @@ public abstract class StatementBase implements ParseNode {
         return this.explainOptions != null;
     }
 
+    public void setPlaceHolders(ArrayList<PlaceHolderExpr> placeholders) {
+        this.placeholders = new ArrayList<PlaceHolderExpr>(placeholders);
+    }
+
+    public ArrayList<PlaceHolderExpr> getPlaceHolders() {
+        return this.placeholders;
+    }
+
     public boolean isVerbose() {
         return explainOptions != null && explainOptions.isVerbose();
     }
@@ -106,6 +122,14 @@ public abstract class StatementBase implements ParseNode {
         return explainOptions;
     }
 
+    public void setIsPrepared() {
+        this.isPrepared = true;
+    }
+
+    public boolean isPrepared() {
+        return this.isPrepared;
+    }
+
     /*
      * Print SQL syntax corresponding to this node.
      *
@@ -187,7 +211,7 @@ public abstract class StatementBase implements ParseNode {
      * @throws AnalysisException
      * @param rewriter
      */
-    public void foldConstant(ExprRewriter rewriter) throws AnalysisException {
+    public void foldConstant(ExprRewriter rewriter, TQueryOptions tQueryOptions) throws AnalysisException {
         throw new IllegalStateException(
                 "foldConstant() not implemented for this stmt: " + getClass().getSimpleName());
     }
