@@ -33,10 +33,10 @@ import org.apache.doris.catalog.TableIf.TableType;
 import org.apache.doris.catalog.Tablet;
 import org.apache.doris.catalog.View;
 import org.apache.doris.common.FeConstants;
-import org.apache.doris.common.Version;
 import org.apache.doris.common.io.Text;
 import org.apache.doris.common.io.Writable;
 import org.apache.doris.persist.gson.GsonUtils;
+import org.apache.doris.thrift.TNetworkAddress;
 
 import com.google.common.base.Joiner;
 import com.google.common.collect.Lists;
@@ -92,17 +92,43 @@ public class BackupJobInfo implements Writable {
 
     @SerializedName("meta_version")
     public int metaVersion;
-    @SerializedName("major_version")
-    public int majorVersion;
-    @SerializedName("minor_version")
-    public int minorVersion;
-    @SerializedName("patch_version")
-    public int patchVersion;
+
+    @SerializedName("tablet_be_map")
+    public Map<Long, Long> tabletBeMap = Maps.newHashMap();
+
+    @SerializedName("tablet_snapshot_path_map")
+    public Map<Long, String> tabletSnapshotPathMap = Maps.newHashMap();
+
+    @SerializedName("table_commit_seq_map")
+    public Map<Long, Long> tableCommitSeqMap;
+
+    public static class ExtraInfo {
+        public static class NetworkAddrss {
+            @SerializedName("ip")
+            public String ip;
+            @SerializedName("port")
+            public int port;
+        }
+
+        @SerializedName("be_network_map")
+        public Map<Long, NetworkAddrss> beNetworkMap = Maps.newHashMap();
+
+        @SerializedName("token")
+        public String token;
+    }
+
+    @SerializedName("extra_info")
+    public ExtraInfo extraInfo;
+
 
     // This map is used to save the table alias mapping info when processing a restore job.
     // origin -> alias
     public Map<String, String> tblAlias = Maps.newHashMap();
 
+    public long getBackupTime() {
+        return backupTime;
+    }
+
     public void initBackupJobInfoAfterDeserialize() {
         // transform success
         if (successJson.equals("succeed")) {
@@ -494,9 +520,65 @@ public class BackupJobInfo implements Writable {
         return Joiner.on("/").join(pathSeg);
     }
 
+    // struct TRemoteTabletSnapshot {
+    //     1: optional i64 local_tablet_id
+    //     2: optional string local_snapshot_path
+    //     3: optional i64 remote_tablet_id
+    //     4: optional i64 remote_be_id
+    //     5: optional Types.TSchemaHash schema_hash
+    //     6: optional Types.TNetworkAddress remote_be_addr
+    //     7: optional string remote_snapshot_path
+    //     8: optional string token
+    // }
+
+    public String getTabletSnapshotPath(Long tabletId) {
+        return tabletSnapshotPathMap.get(tabletId);
+    }
+
+    public Long getBeId(Long tabletId) {
+        return tabletBeMap.get(tabletId);
+    }
+
+    public String getToken() {
+        return extraInfo.token;
+    }
+
+    public TNetworkAddress getBeAddr(Long beId) {
+        ExtraInfo.NetworkAddrss addr = extraInfo.beNetworkMap.get(beId);
+        if (addr == null) {
+            return null;
+        }
+
+        return new TNetworkAddress(addr.ip, addr.port);
+    }
+
+    // TODO(Drogon): improve this find perfermance
+    public Long getSchemaHash(long tableId, long partitionId, long indexId) {
+        for (BackupOlapTableInfo backupOlapTableInfo : backupOlapTableObjects.values()) {
+            if (backupOlapTableInfo.id != tableId) {
+                continue;
+            }
+
+            for (BackupPartitionInfo backupPartitionInfo : backupOlapTableInfo.partitions.values()) {
+                if (backupPartitionInfo.id != partitionId) {
+                    continue;
+                }
+
+                for (BackupIndexInfo backupIndexInfo : backupPartitionInfo.indexes.values()) {
+                    if (backupIndexInfo.id != indexId) {
+                        continue;
+                    }
+
+                    return Long.valueOf(backupIndexInfo.schemaHash);
+                }
+            }
+        }
+        return null;
+    }
+
     public static BackupJobInfo fromCatalog(long backupTime, String label, String dbName, long dbId,
                                             BackupContent content, BackupMeta backupMeta,
-                                            Map<Long, SnapshotInfo> snapshotInfos) {
+                                            Map<Long, SnapshotInfo> snapshotInfos, Map<Long, Long> tableCommitSeqMap) {
 
         BackupJobInfo jobInfo = new BackupJobInfo();
         jobInfo.backupTime = backupTime;
@@ -505,9 +587,7 @@ public class BackupJobInfo implements Writable {
         jobInfo.dbId = dbId;
         jobInfo.metaVersion = FeConstants.meta_version;
         jobInfo.content = content;
-        jobInfo.majorVersion = Version.DORIS_BUILD_VERSION_MAJOR;
-        jobInfo.minorVersion = Version.DORIS_BUILD_VERSION_MINOR;
-        jobInfo.patchVersion = Version.DORIS_BUILD_VERSION_PATCH;
+        jobInfo.tableCommitSeqMap = tableCommitSeqMap;
 
         Collection<Table> tbls = backupMeta.getTables().values();
         // tbls
@@ -536,8 +616,11 @@ public class BackupJobInfo implements Writable {
                             }
                         } else {
                             for (Tablet tablet : index.getTablets()) {
+                                SnapshotInfo snapshotInfo = snapshotInfos.get(tablet.getId());
                                 idxInfo.tablets.put(tablet.getId(),
-                                        Lists.newArrayList(snapshotInfos.get(tablet.getId()).getFiles()));
+                                        Lists.newArrayList(snapshotInfo.getFiles()));
+                                jobInfo.tabletBeMap.put(tablet.getId(), snapshotInfo.getBeId());
+                                jobInfo.tabletSnapshotPathMap.put(tablet.getId(), snapshotInfo.getPath());
                             }
                         }
                         idxInfo.tabletsOrder.addAll(index.getTabletIdsInOrder());
@@ -588,7 +671,7 @@ public class BackupJobInfo implements Writable {
         return genFromJson(json);
     }
 
-    private static BackupJobInfo genFromJson(String json) {
+    public static BackupJobInfo genFromJson(String json) {
         /* parse the json string:
          * {
          *   "backup_time": 1522231864000,
