@@ -17,7 +17,12 @@
 
 package org.apache.doris.catalog;
 
+import org.apache.doris.analysis.DateLiteral;
+import org.apache.doris.analysis.MaxLiteral;
+import org.apache.doris.analysis.PartitionDesc;
+import org.apache.doris.analysis.PartitionValue;
 import org.apache.doris.analysis.SinglePartitionDesc;
+import org.apache.doris.common.AnalysisException;
 import org.apache.doris.common.DdlException;
 import org.apache.doris.common.FeMetaVersion;
 import org.apache.doris.common.io.Text;
@@ -40,6 +45,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Objects;
 import java.util.Set;
+import java.util.stream.Collectors;
 
 /*
  * Repository of a partition's related infos
@@ -150,12 +156,14 @@ public class PartitionInfo implements Writable {
 
     public void unprotectHandleNewSinglePartitionDesc(long partitionId, boolean isTemp, PartitionItem partitionItem,
                                                       DataProperty dataProperty, ReplicaAllocation replicaAlloc,
-                                                      boolean isInMemory) {
+                                                      boolean isInMemory, boolean isMutable) {
         setItemInternal(partitionId, isTemp, partitionItem);
         idToDataProperty.put(partitionId, dataProperty);
         idToReplicaAllocation.put(partitionId, replicaAlloc);
         idToInMemory.put(partitionId, isInMemory);
         idToStoragePolicy.put(partitionId, "");
+        //TODO
+        //idToMutable.put(partitionId, isMutable);
     }
 
     public List<Map.Entry<Long, PartitionItem>> getPartitionItemEntryList(boolean isTemp, boolean isSorted) {
@@ -241,6 +249,14 @@ public class PartitionInfo implements Writable {
         return idToInMemory.get(partitionId);
     }
 
+    public boolean getIsMutable(long partitionId) {
+        return idToDataProperty.get(partitionId).isMutable();
+    }
+
+    public void setIsMutable(long partitionId, boolean isMutable) {
+        idToDataProperty.get(partitionId).setMutable(isMutable);
+    }
+
     public void setIsInMemory(long partitionId, boolean isInMemory) {
         idToInMemory.put(partitionId, isInMemory);
     }
@@ -265,14 +281,15 @@ public class PartitionInfo implements Writable {
     }
 
     public void addPartition(long partitionId, boolean isTemp, PartitionItem item, DataProperty dataProperty,
-                             ReplicaAllocation replicaAlloc, boolean isInMemory) {
-        addPartition(partitionId, dataProperty, replicaAlloc, isInMemory);
+                             ReplicaAllocation replicaAlloc, boolean isInMemory, boolean isMutable) {
+        addPartition(partitionId, dataProperty, replicaAlloc, isInMemory, isMutable);
         setItemInternal(partitionId, isTemp, item);
     }
 
     public void addPartition(long partitionId, DataProperty dataProperty,
                              ReplicaAllocation replicaAlloc,
-                             boolean isInMemory) {
+                             boolean isInMemory, boolean isMutable) {
+        dataProperty.setMutable(isMutable);
         idToDataProperty.put(partitionId, dataProperty);
         idToReplicaAllocation.put(partitionId, replicaAlloc);
         idToInMemory.put(partitionId, isInMemory);
@@ -292,6 +309,22 @@ public class PartitionInfo implements Writable {
         return "";
     }
 
+    public PartitionDesc toPartitionDesc(OlapTable olapTable) throws AnalysisException {
+        throw new RuntimeException("Should implement it in derived classes.");
+    }
+
+    static List<PartitionValue> toPartitionValue(PartitionKey partitionKey) {
+        return partitionKey.getKeys().stream().map(expr -> {
+            if (expr == MaxLiteral.MAX_VALUE) {
+                return PartitionValue.MAX_VALUE;
+            } else if (expr instanceof DateLiteral) {
+                return new PartitionValue(expr.getStringValue());
+            } else {
+                return new PartitionValue(expr.getRealValue().toString());
+            }
+        }).collect(Collectors.toList());
+    }
+
     public void moveFromTempToFormal(long tempPartitionId) {
         PartitionItem item = idToTempItem.remove(tempPartitionId);
         if (item != null) {
@@ -373,6 +406,7 @@ public class PartitionInfo implements Writable {
             buff.append("data_property: ").append(entry.getValue().toString()).append("; ");
             buff.append("replica number: ").append(idToReplicaAllocation.get(entry.getKey())).append("; ");
             buff.append("in memory: ").append(idToInMemory.get(entry.getKey()));
+            buff.append("is mutable: ").append(idToDataProperty.get(entry.getKey()).isMutable());
         }
 
         return buff.toString();
