@@ -34,7 +34,6 @@ import org.apache.doris.planner.PlanFragment;
 import org.apache.doris.planner.Planner;
 import org.apache.doris.planner.ScanNode;
 import org.apache.doris.qe.ConnectContext;
-import org.apache.doris.qe.GlobalVariable;
 import org.apache.doris.qe.OriginStatement;
 import org.apache.doris.qe.StmtExecutor;
 import org.apache.doris.thrift.TDataSink;
@@ -85,6 +84,10 @@ public class TableQueryPlanAction extends RestBaseController {
             @PathVariable(value = DB_KEY) final String dbName,
             @PathVariable(value = TABLE_KEY) final String tblName,
             HttpServletRequest request, HttpServletResponse response) {
+        if (needRedirect(request.getScheme())) {
+            return redirectToHttps(request);
+        }
+
         executeCheckPassword(request, response);
         // just allocate 2 slot for top holder map
         Map<String, Object> resultMap = new HashMap<>(4);
@@ -119,6 +122,12 @@ public class TableQueryPlanAction extends RestBaseController {
             }
             table.readLock();
             try {
+                if (ConnectContext.get() != null
+                        && ConnectContext.get().getSessionVariable() != null) {
+                    // Disable some optimizations, since it's not fully supported
+                    // TODO support it
+                    ConnectContext.get().getSessionVariable().setEnableTwoPhaseReadOpt(false);
+                }
                 // parse/analysis/plan the sql and acquire tablet distributions
                 handleQuery(ConnectContext.get(), fullDbName, tblName, sql, resultMap);
             } finally {
@@ -187,21 +196,10 @@ public class TableQueryPlanAction extends RestBaseController {
         // check consistent http requested resource with sql referenced
         // if consistent in this way, can avoid check privilege
         TableName tableAndDb = fromTables.get(0).getName();
-        int lower = GlobalVariable.lowerCaseTableNames;
-        //Determine whether table names are case-sensitive
-        if (lower == 0) {
-            if (!(tableAndDb.getDb().equals(requestDb) && tableAndDb.getTbl().equals(requestTable))) {
-                throw new DorisHttpException(HttpResponseStatus.BAD_REQUEST,
-                        "requested database and table must consistent with sql: request [ "
-                                + requestDb + "." + requestTable + "]" + "and sql [" + tableAndDb.toString() + "]");
-            }
-        } else {
-            if (!(tableAndDb.getDb().equalsIgnoreCase(requestDb)
-                    && tableAndDb.getTbl().equalsIgnoreCase(requestTable))) {
-                throw new DorisHttpException(HttpResponseStatus.BAD_REQUEST,
-                        "requested database and table must consistent with sql: request [ "
-                                + requestDb + "." + requestTable + "]" + "and sql [" + tableAndDb.toString() + "]");
-            }
+        if (!(tableAndDb.getDb().equals(requestDb) && tableAndDb.getTbl().equals(requestTable))) {
+            throw new DorisHttpException(HttpResponseStatus.BAD_REQUEST,
+                    "requested database and table must consistent with sql: request [ "
+                    + requestDb + "." + requestTable + "]" + "and sql [" + tableAndDb.toString() + "]");
         }
 
         // acquired Planner to get PlanNode and fragment templates
@@ -248,9 +246,10 @@ public class TableQueryPlanAction extends RestBaseController {
         tQueryPlanInfo.tablet_info = tabletInfo;
 
         // serialize TQueryPlanInfo and encode plan with Base64 to string in order to translate by json format
-        TSerializer serializer = new TSerializer();
+        TSerializer serializer;
         String opaquedQueryPlan;
         try {
+            serializer = new TSerializer();
             byte[] queryPlanStream = serializer.serialize(tQueryPlanInfo);
             opaquedQueryPlan = Base64.getEncoder().encodeToString(queryPlanStream);
         } catch (TException e) {
