@@ -831,7 +831,7 @@ public class JournalEntity implements Writable {
                 break;
             }
             case OperationType.OP_BARRIER: {
-                data = new BarrierLog();
+                data = BarrierLog.read(in);
                 isRead = true;
                 break;
             }
