@@ -19,10 +19,9 @@ package org.apache.doris.load.routineload;
 
 import org.apache.doris.analysis.AlterRoutineLoadStmt;
 import org.apache.doris.analysis.CreateRoutineLoadStmt;
-import org.apache.doris.analysis.RoutineLoadDataSourceProperties;
 import org.apache.doris.analysis.UserIdentity;
-import org.apache.doris.catalog.Catalog;
 import org.apache.doris.catalog.Database;
+import org.apache.doris.catalog.Env;
 import org.apache.doris.catalog.OlapTable;
 import org.apache.doris.common.Config;
 import org.apache.doris.common.DdlException;
@@ -38,21 +37,24 @@ import org.apache.doris.common.util.LogKey;
 import org.apache.doris.common.util.SmallFileMgr;
 import org.apache.doris.common.util.SmallFileMgr.SmallFile;
 import org.apache.doris.common.util.TimeUtils;
+import org.apache.doris.load.routineload.kafka.KafkaConfiguration;
+import org.apache.doris.load.routineload.kafka.KafkaDataSourceProperties;
 import org.apache.doris.persist.AlterRoutineLoadJobOperationLog;
-import org.apache.doris.system.SystemInfoService;
+import org.apache.doris.thrift.TFileCompressType;
 import org.apache.doris.transaction.TransactionState;
 import org.apache.doris.transaction.TransactionStatus;
 
 import com.google.common.base.Joiner;
 import com.google.common.base.Preconditions;
+import com.google.common.base.Strings;
 import com.google.common.collect.Lists;
 import com.google.common.collect.Maps;
 import com.google.gson.Gson;
 import com.google.gson.GsonBuilder;
-
+import org.apache.commons.collections.CollectionUtils;
+import org.apache.commons.collections.MapUtils;
 import org.apache.logging.log4j.LogManager;
 import org.apache.logging.log4j.Logger;
-import org.apache.parquet.Strings;
 
 import java.io.DataInput;
 import java.io.DataOutput;
@@ -60,6 +62,7 @@ import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.TimeZone;
@@ -79,7 +82,7 @@ public class KafkaRoutineLoadJob extends RoutineLoadJob {
     private String topic;
     // optional, user want to load partitions.
     private List<Integer> customKafkaPartitions = Lists.newArrayList();
-    // current kafka partitions is the actually partition which will be fetched
+    // current kafka partitions is the actual partition which will be fetched
     private List<Integer> currentKafkaPartitions = Lists.newArrayList();
     // optional, user want to set default offset when new partition add or offset not set.
     // kafkaDefaultOffSet has two formats, one is the time format, eg: "2021-10-10 11:00:00",
@@ -112,6 +115,16 @@ public class KafkaRoutineLoadJob extends RoutineLoadJob {
         this.progress = new KafkaProgress();
     }
 
+    public KafkaRoutineLoadJob(Long id, String name, String clusterName,
+                               long dbId, String brokerList, String topic,
+                               UserIdentity userIdentity, boolean isMultiTable) {
+        super(id, name, clusterName, dbId, LoadDataSourceType.KAFKA, userIdentity);
+        this.brokerList = brokerList;
+        this.topic = topic;
+        this.progress = new KafkaProgress();
+        setMultiTable(isMultiTable);
+    }
+
     public String getTopic() {
         return topic;
     }
@@ -171,7 +184,7 @@ public class KafkaRoutineLoadJob extends RoutineLoadJob {
             convertedCustomProperties.clear();
         }
 
-        SmallFileMgr smallFileMgr = Catalog.getCurrentCatalog().getSmallFileMgr();
+        SmallFileMgr smallFileMgr = Env.getCurrentEnv().getSmallFileMgr();
         for (Map.Entry<String, String> entry : customProperties.entrySet()) {
             if (entry.getValue().startsWith("FILE:")) {
                 // convert FILE:file_name -> FILE:file_id:md5
@@ -184,13 +197,17 @@ public class KafkaRoutineLoadJob extends RoutineLoadJob {
         }
 
         // This is mainly for compatibility. In the previous version, we directly obtained the value of the
-        // KAFKA_DEFAULT_OFFSETS attribute. In the new version, we support date time as the value of KAFKA_DEFAULT_OFFSETS,
-        // and this attribute will be converted into a timestamp during the analyzing phase, thus losing some information.
-        // So we use KAFKA_ORIGIN_DEFAULT_OFFSETS to store the original datetime formatted KAFKA_DEFAULT_OFFSETS value
-        if (convertedCustomProperties.containsKey(CreateRoutineLoadStmt.KAFKA_ORIGIN_DEFAULT_OFFSETS)) {
-            kafkaDefaultOffSet = convertedCustomProperties.remove(CreateRoutineLoadStmt.KAFKA_ORIGIN_DEFAULT_OFFSETS);
-        } else if (convertedCustomProperties.containsKey(CreateRoutineLoadStmt.KAFKA_DEFAULT_OFFSETS)) {
-            kafkaDefaultOffSet = convertedCustomProperties.remove(CreateRoutineLoadStmt.KAFKA_DEFAULT_OFFSETS);
+        // KAFKA_DEFAULT_OFFSETS attribute. In the new version, we support date time as the value of
+        // KAFKA_DEFAULT_OFFSETS, and this attribute will be converted into a timestamp during the analyzing phase,
+        // thus losing some information. So we use KAFKA_ORIGIN_DEFAULT_OFFSETS to store the original datetime
+        // formatted KAFKA_DEFAULT_OFFSETS value
+        if (convertedCustomProperties.containsKey(KafkaConfiguration.KAFKA_ORIGIN_DEFAULT_OFFSETS.getName())) {
+            kafkaDefaultOffSet = convertedCustomProperties
+                    .remove(KafkaConfiguration.KAFKA_ORIGIN_DEFAULT_OFFSETS.getName());
+            return;
+        }
+        if (convertedCustomProperties.containsKey(KafkaConfiguration.KAFKA_DEFAULT_OFFSETS.getName())) {
+            kafkaDefaultOffSet = convertedCustomProperties.remove(KafkaConfiguration.KAFKA_DEFAULT_OFFSETS.getName());
         }
     }
 
@@ -209,7 +226,7 @@ public class KafkaRoutineLoadJob extends RoutineLoadJob {
                                 ((KafkaProgress) progress).getOffsetByPartition(kafkaPartition));
                     }
                     KafkaTaskInfo kafkaTaskInfo = new KafkaTaskInfo(UUID.randomUUID(), id, clusterName,
-                            maxBatchIntervalS * 2 * 1000, taskKafkaProgress);
+                            maxBatchIntervalS * 2 * 1000, taskKafkaProgress, isMultiTable());
                     routineLoadTaskInfoList.add(kafkaTaskInfo);
                     result.add(kafkaTaskInfo);
                 }
@@ -221,7 +238,7 @@ public class KafkaRoutineLoadJob extends RoutineLoadJob {
                 LOG.debug("Ignore to divide routine load job while job state {}", state);
             }
             // save task into queue of needScheduleTasks
-            Catalog.getCurrentCatalog().getRoutineLoadTaskScheduler().addTasksInQueue(result);
+            Env.getCurrentEnv().getRoutineLoadTaskScheduler().addTasksInQueue(result);
         } finally {
             writeUnlock();
         }
@@ -229,7 +246,6 @@ public class KafkaRoutineLoadJob extends RoutineLoadJob {
 
     @Override
     public int calculateCurrentConcurrentTaskNum() {
-        SystemInfoService systemInfoService = Catalog.getCurrentSystemInfo();
         int partitionNum = currentKafkaPartitions.size();
         if (desireTaskConcurrentNum == 0) {
             desireTaskConcurrentNum = Config.max_routine_load_task_concurrent_num;
@@ -255,8 +271,8 @@ public class KafkaRoutineLoadJob extends RoutineLoadJob {
 
         // Running here, the status of the transaction should be ABORTED,
         // and it is caused by other errors. In this case, we should not update the offset.
-        LOG.debug("no need to update the progress of kafka routine load. txn status: {}, " +
-                        "txnStatusChangeReason: {}, task: {}, job: {}",
+        LOG.debug("no need to update the progress of kafka routine load. txn status: {}, "
+                        + "txnStatusChangeReason: {}, task: {}, job: {}",
                 txnState.getTransactionStatus(), txnStatusChangeReason,
                 DebugUtil.printId(rlTaskTxnCommitAttachment.getTaskId()), id);
         return false;
@@ -279,7 +295,7 @@ public class KafkaRoutineLoadJob extends RoutineLoadJob {
         KafkaTaskInfo oldKafkaTaskInfo = (KafkaTaskInfo) routineLoadTaskInfo;
         // add new task
         KafkaTaskInfo kafkaTaskInfo = new KafkaTaskInfo(oldKafkaTaskInfo,
-                ((KafkaProgress) progress).getPartitionIdToOffset(oldKafkaTaskInfo.getPartitions()));
+                ((KafkaProgress) progress).getPartitionIdToOffset(oldKafkaTaskInfo.getPartitions()), isMultiTable());
         // remove old task
         routineLoadTaskInfoList.remove(routineLoadTaskInfo);
         // add new task
@@ -324,38 +340,19 @@ public class KafkaRoutineLoadJob extends RoutineLoadJob {
     // else if kafka partitions of topic has been changed, return true.
     // else return false
     // update current kafka partition at the same time
-    // current kafka partitions = customKafkaPartitions == 0 ? all of partition of kafka topic : customKafkaPartitions
+    // current kafka partitions = customKafkaPartitions == 0 ? all partition of kafka topic : customKafkaPartitions
     @Override
     protected boolean unprotectNeedReschedule() throws UserException {
         // only running and need_schedule job need to be changed current kafka partitions
         if (this.state == JobState.RUNNING || this.state == JobState.NEED_SCHEDULE) {
-            if (customKafkaPartitions != null && customKafkaPartitions.size() != 0) {
+            if (CollectionUtils.isNotEmpty(customKafkaPartitions)) {
                 currentKafkaPartitions = customKafkaPartitions;
                 return false;
-            } else {
-                // the newCurrentKafkaPartition should be already updated in preCheckNeedScheduler()
-                Preconditions.checkNotNull(this.newCurrentKafkaPartition);
-                if (currentKafkaPartitions.containsAll(this.newCurrentKafkaPartition)) {
-                    if (currentKafkaPartitions.size() > this.newCurrentKafkaPartition.size()) {
-                        currentKafkaPartitions = this.newCurrentKafkaPartition;
-                        if (LOG.isDebugEnabled()) {
-                            LOG.debug(new LogBuilder(LogKey.ROUTINE_LOAD_JOB, id)
-                                    .add("current_kafka_partitions", Joiner.on(",").join(currentKafkaPartitions))
-                                    .add("msg", "current kafka partitions has been change")
-                                    .build());
-                        }
-                        return true;
-                    } else {
-                        // if the partitions of currentKafkaPartitions and progress are inconsistent,
-                        // We should also update the progress
-                        for (Integer kafkaPartition : currentKafkaPartitions) {
-                            if (!((KafkaProgress) progress).containsPartition(kafkaPartition)) {
-                                return true;
-                            }
-                        }
-                        return false;
-                    }
-                } else {
+            }
+            // the newCurrentKafkaPartition should be already updated in preCheckNeedScheduler()
+            Preconditions.checkNotNull(this.newCurrentKafkaPartition);
+            if (new HashSet<>(currentKafkaPartitions).containsAll(this.newCurrentKafkaPartition)) {
+                if (currentKafkaPartitions.size() > this.newCurrentKafkaPartition.size()) {
                     currentKafkaPartitions = this.newCurrentKafkaPartition;
                     if (LOG.isDebugEnabled()) {
                         LOG.debug(new LogBuilder(LogKey.ROUTINE_LOAD_JOB, id)
@@ -364,13 +361,33 @@ public class KafkaRoutineLoadJob extends RoutineLoadJob {
                                 .build());
                     }
                     return true;
+                } else {
+                    // if the partitions of currentKafkaPartitions and progress are inconsistent,
+                    // We should also update the progress
+                    for (Integer kafkaPartition : currentKafkaPartitions) {
+                        if (!((KafkaProgress) progress).containsPartition(kafkaPartition)) {
+                            return true;
+                        }
+                    }
+                    return false;
                 }
+            } else {
+                currentKafkaPartitions = this.newCurrentKafkaPartition;
+                if (LOG.isDebugEnabled()) {
+                    LOG.debug(new LogBuilder(LogKey.ROUTINE_LOAD_JOB, id)
+                            .add("current_kafka_partitions", Joiner.on(",").join(currentKafkaPartitions))
+                            .add("msg", "current kafka partitions has been change")
+                            .build());
+                }
+                return true;
             }
-        } else if (this.state == JobState.PAUSED) {
-            return ScheduleRule.isNeedAutoSchedule(this);
-        } else {
-            return false;
+
         }
+        if (this.state == JobState.PAUSED) {
+            return ScheduleRule.isNeedAutoSchedule(this);
+        }
+        return false;
+
     }
 
     @Override
@@ -387,16 +404,24 @@ public class KafkaRoutineLoadJob extends RoutineLoadJob {
 
     public static KafkaRoutineLoadJob fromCreateStmt(CreateRoutineLoadStmt stmt) throws UserException {
         // check db and table
-        Database db = Catalog.getCurrentCatalog().getDbOrDdlException(stmt.getDBName());
-        OlapTable olapTable = db.getOlapTableOrDdlException(stmt.getTableName());
-        checkMeta(olapTable, stmt.getRoutineLoadDesc());
-        long tableId = olapTable.getId();
+        Database db = Env.getCurrentInternalCatalog().getDbOrDdlException(stmt.getDBName());
 
-        // init kafka routine load job
-        long id = Catalog.getCurrentCatalog().getNextId();
-        KafkaRoutineLoadJob kafkaRoutineLoadJob = new KafkaRoutineLoadJob(id, stmt.getName(),
-                db.getClusterName(), db.getId(), tableId,
-                stmt.getKafkaBrokerList(), stmt.getKafkaTopic(), stmt.getUserInfo());
+        long id = Env.getCurrentEnv().getNextId();
+        KafkaDataSourceProperties kafkaProperties = (KafkaDataSourceProperties) stmt.getDataSourceProperties();
+        KafkaRoutineLoadJob kafkaRoutineLoadJob;
+        if (kafkaProperties.isMultiTable()) {
+            kafkaRoutineLoadJob = new KafkaRoutineLoadJob(id, stmt.getName(),
+                    db.getClusterName(), db.getId(),
+                    kafkaProperties.getBrokerList(), kafkaProperties.getTopic(), stmt.getUserInfo(), true);
+        } else {
+            OlapTable olapTable = db.getOlapTableOrDdlException(stmt.getTableName());
+            checkMeta(olapTable, stmt.getRoutineLoadDesc());
+            long tableId = olapTable.getId();
+            // init kafka routine load job
+            kafkaRoutineLoadJob = new KafkaRoutineLoadJob(id, stmt.getName(),
+                    db.getClusterName(), db.getId(), tableId,
+                    kafkaProperties.getBrokerList(), kafkaProperties.getTopic(), stmt.getUserInfo());
+        }
         kafkaRoutineLoadJob.setOptional(stmt);
         kafkaRoutineLoadJob.checkCustomProperties();
         kafkaRoutineLoadJob.checkCustomPartition();
@@ -418,7 +443,7 @@ public class KafkaRoutineLoadJob extends RoutineLoadJob {
     }
 
     private void checkCustomProperties() throws DdlException {
-        SmallFileMgr smallFileMgr = Catalog.getCurrentCatalog().getSmallFileMgr();
+        SmallFileMgr smallFileMgr = Env.getCurrentEnv().getSmallFileMgr();
         for (Map.Entry<String, String> entry : customProperties.entrySet()) {
             if (entry.getValue().startsWith("FILE:")) {
                 String file = entry.getValue().substring(entry.getValue().indexOf(":") + 1);
@@ -438,7 +463,8 @@ public class KafkaRoutineLoadJob extends RoutineLoadJob {
                 if (!((KafkaProgress) progress).containsPartition(kafkaPartition)) {
                     List<Integer> newPartitions = Lists.newArrayList();
                     newPartitions.add(kafkaPartition);
-                    List<Pair<Integer, Long>> newPartitionsOffsets = getNewPartitionOffsetsFromDefaultOffset(newPartitions);
+                    List<Pair<Integer, Long>> newPartitionsOffsets
+                            = getNewPartitionOffsetsFromDefaultOffset(newPartitions);
                     Preconditions.checkState(newPartitionsOffsets.size() == 1);
                     for (Pair<Integer, Long> partitionOffset : newPartitionsOffsets) {
                         ((KafkaProgress) progress).addPartitionOffset(partitionOffset);
@@ -458,16 +484,18 @@ public class KafkaRoutineLoadJob extends RoutineLoadJob {
         }
     }
 
-    private List<Pair<Integer, Long>> getNewPartitionOffsetsFromDefaultOffset(List<Integer> newPartitions) throws UserException {
+    private List<Pair<Integer, Long>> getNewPartitionOffsetsFromDefaultOffset(List<Integer> newPartitions)
+            throws UserException {
         List<Pair<Integer, Long>> partitionOffsets = Lists.newArrayList();
         // get default offset
         long beginOffset = convertedDefaultOffsetToLong();
         for (Integer kafkaPartition : newPartitions) {
-            partitionOffsets.add(Pair.create(kafkaPartition, beginOffset));
+            partitionOffsets.add(Pair.of(kafkaPartition, beginOffset));
         }
         if (isOffsetForTimes()) {
             try {
-                partitionOffsets = KafkaUtil.getOffsetsForTimes(this.brokerList, this.topic, convertedCustomProperties, partitionOffsets);
+                partitionOffsets = KafkaUtil.getOffsetsForTimes(this.brokerList,
+                        this.topic, convertedCustomProperties, partitionOffsets);
             } catch (LoadException e) {
                 LOG.warn(new LogBuilder(LogKey.ROUTINE_LOAD_JOB, id)
                         .add("partition:timestamp", Joiner.on(",").join(partitionOffsets))
@@ -482,27 +510,28 @@ public class KafkaRoutineLoadJob extends RoutineLoadJob {
     @Override
     protected void setOptional(CreateRoutineLoadStmt stmt) throws UserException {
         super.setOptional(stmt);
-
-        if (!stmt.getKafkaPartitionOffsets().isEmpty()) {
-            setCustomKafkaPartitions(stmt);
+        KafkaDataSourceProperties kafkaDataSourceProperties
+                = (KafkaDataSourceProperties) stmt.getDataSourceProperties();
+        if (CollectionUtils.isNotEmpty(kafkaDataSourceProperties.getKafkaPartitionOffsets())) {
+            setCustomKafkaPartitions(kafkaDataSourceProperties);
         }
-        if (!stmt.getCustomKafkaProperties().isEmpty()) {
-            setCustomKafkaProperties(stmt.getCustomKafkaProperties());
+        if (MapUtils.isNotEmpty(kafkaDataSourceProperties.getCustomKafkaProperties())) {
+            setCustomKafkaProperties(kafkaDataSourceProperties.getCustomKafkaProperties());
         }
         // set group id if not specified
-        if (!this.customProperties.containsKey(PROP_GROUP_ID)) {
-            this.customProperties.put(PROP_GROUP_ID, name + "_" + UUID.randomUUID().toString());
-        }
+        this.customProperties.putIfAbsent(PROP_GROUP_ID, name + "_" + UUID.randomUUID());
     }
 
-    // this is a unprotected method which is called in the initialization function
-    private void setCustomKafkaPartitions(CreateRoutineLoadStmt stmt) throws LoadException {
-        List<Pair<Integer, Long>> kafkaPartitionOffsets = stmt.getKafkaPartitionOffsets();
-        boolean isForTimes = stmt.isOffsetsForTimes();
+    // this is an unprotected method which is called in the initialization function
+    private void setCustomKafkaPartitions(KafkaDataSourceProperties kafkaDataSourceProperties) throws LoadException {
+
+        List<Pair<Integer, Long>> kafkaPartitionOffsets = kafkaDataSourceProperties.getKafkaPartitionOffsets();
+        boolean isForTimes = kafkaDataSourceProperties.isOffsetsForTimes();
         if (isForTimes) {
             // the offset is set by date time, we need to get the real offset by time
-            kafkaPartitionOffsets = KafkaUtil.getOffsetsForTimes(stmt.getKafkaBrokerList(), stmt.getKafkaTopic(),
-                    convertedCustomProperties, stmt.getKafkaPartitionOffsets());
+            kafkaPartitionOffsets = KafkaUtil.getOffsetsForTimes(kafkaDataSourceProperties.getBrokerList(),
+                    kafkaDataSourceProperties.getTopic(),
+                    convertedCustomProperties, kafkaDataSourceProperties.getKafkaPartitionOffsets());
         }
 
         for (Pair<Integer, Long> partitionOffset : kafkaPartitionOffsets) {
@@ -588,8 +617,8 @@ public class KafkaRoutineLoadJob extends RoutineLoadJob {
     @Override
     public void modifyProperties(AlterRoutineLoadStmt stmt) throws UserException {
         Map<String, String> jobProperties = stmt.getAnalyzedJobProperties();
-        RoutineLoadDataSourceProperties dataSourceProperties = stmt.getDataSourceProperties();
-        if (dataSourceProperties.isOffsetsForTimes()) {
+        KafkaDataSourceProperties dataSourceProperties = (KafkaDataSourceProperties) stmt.getDataSourceProperties();
+        if (null != dataSourceProperties && dataSourceProperties.isOffsetsForTimes()) {
             // if the partition offset is set by timestamp, convert it to real offset
             convertTimestampToOffset(dataSourceProperties);
         }
@@ -604,13 +633,13 @@ public class KafkaRoutineLoadJob extends RoutineLoadJob {
 
             AlterRoutineLoadJobOperationLog log = new AlterRoutineLoadJobOperationLog(this.id,
                     jobProperties, dataSourceProperties);
-            Catalog.getCurrentCatalog().getEditLog().logAlterRoutineLoadJob(log);
+            Env.getCurrentEnv().getEditLog().logAlterRoutineLoadJob(log);
         } finally {
             writeUnlock();
         }
     }
 
-    private void convertTimestampToOffset(RoutineLoadDataSourceProperties dataSourceProperties) throws UserException {
+    private void convertTimestampToOffset(KafkaDataSourceProperties dataSourceProperties) throws UserException {
         List<Pair<Integer, Long>> partitionOffsets = dataSourceProperties.getKafkaPartitionOffsets();
         if (partitionOffsets.isEmpty()) {
             return;
@@ -621,42 +650,40 @@ public class KafkaRoutineLoadJob extends RoutineLoadJob {
     }
 
     private void modifyPropertiesInternal(Map<String, String> jobProperties,
-                                          RoutineLoadDataSourceProperties dataSourceProperties)
+                                          KafkaDataSourceProperties dataSourceProperties)
             throws DdlException {
+        if (null != dataSourceProperties) {
+            List<Pair<Integer, Long>> kafkaPartitionOffsets = Lists.newArrayList();
+            Map<String, String> customKafkaProperties = Maps.newHashMap();
 
-        List<Pair<Integer, Long>> kafkaPartitionOffsets = Lists.newArrayList();
-        Map<String, String> customKafkaProperties = Maps.newHashMap();
+            if (MapUtils.isNotEmpty(dataSourceProperties.getOriginalDataSourceProperties())) {
+                kafkaPartitionOffsets = dataSourceProperties.getKafkaPartitionOffsets();
+                customKafkaProperties = dataSourceProperties.getCustomKafkaProperties();
+            }
 
-        if (dataSourceProperties.hasAnalyzedProperties()) {
-            kafkaPartitionOffsets = dataSourceProperties.getKafkaPartitionOffsets();
-            customKafkaProperties = dataSourceProperties.getCustomKafkaProperties();
+            // modify partition offset first
+            if (!kafkaPartitionOffsets.isEmpty()) {
+                // we can only modify the partition that is being consumed
+                ((KafkaProgress) progress).modifyOffset(kafkaPartitionOffsets);
+            }
+
+            if (!customKafkaProperties.isEmpty()) {
+                this.customProperties.putAll(customKafkaProperties);
+                convertCustomProperties(true);
+            }
+            // modify broker list and topic
+            if (!Strings.isNullOrEmpty(dataSourceProperties.getBrokerList())) {
+                this.brokerList = dataSourceProperties.getBrokerList();
+            }
+            if (!Strings.isNullOrEmpty(dataSourceProperties.getTopic())) {
+                this.topic = dataSourceProperties.getTopic();
+            }
         }
-
-        // modify partition offset first
-        if (!kafkaPartitionOffsets.isEmpty()) {
-            // we can only modify the partition that is being consumed
-            ((KafkaProgress) progress).modifyOffset(kafkaPartitionOffsets);
-        }
-
-        if (!customKafkaProperties.isEmpty()) {
-            this.customProperties.putAll(customKafkaProperties);
-            convertCustomProperties(true);
-        }
-
         if (!jobProperties.isEmpty()) {
             Map<String, String> copiedJobProperties = Maps.newHashMap(jobProperties);
             modifyCommonJobProperties(copiedJobProperties);
             this.jobProperties.putAll(copiedJobProperties);
         }
-
-        // modify broker list and topic
-        if (!Strings.isNullOrEmpty(dataSourceProperties.getKafkaBrokerList())) {
-            this.brokerList = dataSourceProperties.getKafkaBrokerList();
-        }
-        if (!Strings.isNullOrEmpty(dataSourceProperties.getKafkaTopic())) {
-            this.topic = dataSourceProperties.getKafkaTopic();
-        }
-
         LOG.info("modify the properties of kafka routine load job: {}, jobProperties: {}, datasource properties: {}",
                 this.id, jobProperties, dataSourceProperties);
     }
@@ -664,7 +691,7 @@ public class KafkaRoutineLoadJob extends RoutineLoadJob {
     @Override
     public void replayModifyProperties(AlterRoutineLoadJobOperationLog log) {
         try {
-            modifyPropertiesInternal(log.getJobProperties(), log.getDataSourceProperties());
+            modifyPropertiesInternal(log.getJobProperties(), (KafkaDataSourceProperties) log.getDataSourceProperties());
         } catch (DdlException e) {
             // should not happen
             LOG.error("failed to replay modify kafka routine load job: {}", id, e);
@@ -723,6 +750,11 @@ public class KafkaRoutineLoadJob extends RoutineLoadJob {
         return gson.toJson(partitionIdToOffsetLag);
     }
 
+    @Override
+    public TFileCompressType getCompressType() {
+        return TFileCompressType.PLAIN;
+    }
+
     @Override
     public double getMaxFilterRatio() {
         // for kafka routine load, the max filter ratio is always 1, because it use max error num instead of this.
