@@ -75,10 +75,21 @@ public class MysqlChannel {
 
     protected volatile MysqlSerializer serializer;
 
+    // mysql flag CLIENT_DEPRECATE_EOF
+    private boolean clientDeprecatedEOF;
+
     protected MysqlChannel() {
         // For DummyMysqlChannel
     }
 
+    public void setClientDeprecatedEOF() {
+        clientDeprecatedEOF = true;
+    }
+
+    public boolean clientDeprecatedEOF() {
+        return clientDeprecatedEOF;
+    }
+
     public MysqlChannel(StreamConnection connection) {
         Preconditions.checkNotNull(connection);
         this.sequenceId = 0;
