@@ -19,6 +19,8 @@ package org.apache.doris.mysql.privilege;
 
 import org.apache.doris.analysis.CompoundPredicate.Operator;
 
+import java.util.Optional;
+
 public class PrivPredicate {
 
     // user can 'see' this meta
@@ -34,7 +36,7 @@ public class PrivPredicate {
             Privilege.USAGE_PRIV),
             Operator.OR);
     public static final PrivPredicate SHOW_WORKLOAD_GROUP = PrivPredicate.of(PrivBitSet.of(Privilege.ADMIN_PRIV,
-                    Privilege.USAGE_PRIV),
+            Privilege.USAGE_PRIV),
             Operator.OR);
     // create/drop/alter/show user
     public static final PrivPredicate GRANT = PrivPredicate.of(PrivBitSet.of(Privilege.ADMIN_PRIV,
@@ -110,6 +112,18 @@ public class PrivPredicate {
         return op;
     }
 
+    // Determine which column Privilege correspond to PrivPredicate
+    //The current logic is to include a SELECT_ PRIV returns SELECT_ PRIV, if load is included_ PRIV returns LOAD_ PRIV,
+    // the order cannot be reversed
+    public Optional<Privilege> getColPrivilege() {
+        if (privs.get(Privilege.SELECT_PRIV.getIdx())) {
+            return Optional.of(Privilege.SELECT_PRIV);
+        } else if (privs.get(Privilege.LOAD_PRIV.getIdx())) {
+            return Optional.of(Privilege.LOAD_PRIV);
+        }
+        return Optional.empty();
+    }
+
     @Override
     public String toString() {
         StringBuilder sb = new StringBuilder();
