@@ -27,10 +27,7 @@ import org.apache.doris.common.UserException;
 import org.apache.doris.common.io.Writable;
 import org.apache.doris.load.DppConfig;
 import org.apache.doris.resource.Tag;
-import org.apache.doris.thrift.TAgentServiceVersion;
-import org.apache.doris.thrift.TFetchResourceResult;
 
-import com.google.common.base.Preconditions;
 import com.google.common.collect.Maps;
 import org.apache.logging.log4j.LogManager;
 import org.apache.logging.log4j.Logger;
@@ -40,6 +37,7 @@ import java.io.DataOutput;
 import java.io.IOException;
 import java.util.List;
 import java.util.Map;
+import java.util.Map.Entry;
 import java.util.Set;
 import java.util.concurrent.atomic.AtomicLong;
 
@@ -52,69 +50,22 @@ public class UserPropertyMgr implements Writable {
     public static final String LDAP_RESOURCE_USER = "ldap";
 
     private static final UserProperty LDAP_PROPERTY = new UserProperty(LDAP_RESOURCE_USER);
-
-    static {
-        try {
-            setNormalUserDefaultResource(LDAP_PROPERTY);
-        } catch (DdlException e) {
-            LOG.error("init DEFAULT_PROPERTY error.", e);
-            throw new RuntimeException(e);
-        }
-    }
-
     private AtomicLong resourceVersion = new AtomicLong(0);
 
     public UserPropertyMgr() {
     }
 
-    public void addUserResource(String qualifiedUser, boolean isSystemUser) {
+    public void addUserResource(String qualifiedUser) {
         UserProperty property = propertyMap.get(qualifiedUser);
         if (property != null) {
             return;
         }
 
         property = new UserProperty(qualifiedUser);
-
-        // set user properties
-        try {
-            if (isSystemUser) {
-                setSystemUserDefaultResource(property);
-            } else {
-                setNormalUserDefaultResource(property);
-            }
-        } catch (DdlException e) {
-            // this should not happen, because the value is set by us!!
-        }
-
         propertyMap.put(qualifiedUser, property);
         resourceVersion.incrementAndGet();
     }
 
-    public void setPasswordForDomain(UserIdentity userIdentity, byte[] password, boolean errOnExist,
-            boolean errOnNonExist) throws DdlException {
-        Preconditions.checkArgument(userIdentity.isDomain());
-        UserProperty property = propertyMap.get(userIdentity.getQualifiedUser());
-        if (property == null) {
-            if (errOnNonExist) {
-                throw new DdlException("user " + userIdentity + " does not exist");
-            }
-            property = new UserProperty(userIdentity.getQualifiedUser());
-        }
-        property.setPasswordForDomain(userIdentity.getHost(), password, errOnExist);
-        // update propertyMap after setPasswordForDomain, cause setPasswordForDomain may throw exception
-        propertyMap.put(userIdentity.getQualifiedUser(), property);
-    }
-
-    public void removeDomainFromUser(UserIdentity userIdentity) {
-        Preconditions.checkArgument(userIdentity.isDomain());
-        UserProperty userProperty = propertyMap.get(userIdentity.getQualifiedUser());
-        if (userProperty == null) {
-            return;
-        }
-        userProperty.removeDomain(userIdentity.getHost());
-        resourceVersion.incrementAndGet();
-    }
-
     public void dropUser(UserIdentity userIdent) {
         if (propertyMap.remove(userIdent.getQualifiedUser()) != null) {
             LOG.info("drop user {} from user property manager", userIdent.getQualifiedUser());
@@ -130,7 +81,7 @@ public class UserPropertyMgr implements Writable {
         property.update(properties);
     }
 
-    public long getQueryTimeout(String qualifiedUser) {
+    public int getQueryTimeout(String qualifiedUser) {
         UserProperty existProperty = propertyMap.get(qualifiedUser);
         existProperty = getLdapPropertyIfNull(qualifiedUser, existProperty);
         if (existProperty == null) {
@@ -139,6 +90,15 @@ public class UserPropertyMgr implements Writable {
         return existProperty.getQueryTimeout();
     }
 
+    public int getInsertTimeout(String qualifiedUser) {
+        UserProperty existProperty = propertyMap.get(qualifiedUser);
+        existProperty = getLdapPropertyIfNull(qualifiedUser, existProperty);
+        if (existProperty == null) {
+            return 0;
+        }
+        return existProperty.getInsertTimeout();
+    }
+
     public long getMaxConn(String qualifiedUser) {
         UserProperty existProperty = propertyMap.get(qualifiedUser);
         existProperty = getLdapPropertyIfNull(qualifiedUser, existProperty);
@@ -166,42 +126,6 @@ public class UserPropertyMgr implements Writable {
         return existProperty.getCopiedResourceTags();
     }
 
-    public int getPropertyMapSize() {
-        return propertyMap.size();
-    }
-
-    private void setSystemUserDefaultResource(UserProperty user) throws DdlException {
-        UserResource userResource = user.getResource();
-        userResource.updateResource("CPU_SHARE", 100);
-        userResource.updateResource("IO_SHARE", 100);
-        userResource.updateResource("SSD_READ_MBPS", 30);
-        userResource.updateResource("SSD_WRITE_MBPS", 30);
-        userResource.updateResource("HDD_READ_MBPS", 30);
-        userResource.updateResource("HDD_WRITE_MBPS", 30);
-    }
-
-    private static void setNormalUserDefaultResource(UserProperty user) throws DdlException {
-        UserResource userResource = user.getResource();
-        userResource.updateResource("CPU_SHARE", 1000);
-        userResource.updateResource("IO_SHARE", 1000);
-        userResource.updateResource("SSD_READ_IOPS", 1000);
-        userResource.updateResource("HDD_READ_IOPS", 80);
-        userResource.updateResource("SSD_READ_MBPS", 30);
-        userResource.updateResource("HDD_READ_MBPS", 30);
-    }
-
-    public TFetchResourceResult toResourceThrift() {
-        TFetchResourceResult tResult = new TFetchResourceResult();
-        tResult.setProtocolVersion(TAgentServiceVersion.V1);
-        tResult.setResourceVersion(resourceVersion.get());
-
-        for (Map.Entry<String, UserProperty> entry : propertyMap.entrySet()) {
-            tResult.putToResourceByUser(entry.getKey(), entry.getValue().getResource().toThrift());
-        }
-
-        return tResult;
-    }
-
     public Pair<String, DppConfig> getLoadClusterInfo(String qualifiedUser, String cluster) throws DdlException {
         Pair<String, DppConfig> loadClusterInfo = null;
 
@@ -223,44 +147,11 @@ public class UserPropertyMgr implements Writable {
         return property.fetchProperty();
     }
 
-    // return a map from domain name -> set of user names
-    public void getAllDomains(Set<String> allDomains) {
-        LOG.debug("get property map: {}", propertyMap);
-        for (Map.Entry<String, UserProperty> entry : propertyMap.entrySet()) {
-            Set<String> domains = entry.getValue().getWhiteList().getAllDomains();
-            allDomains.addAll(domains);
-        }
-    }
-
-    // check if specified user identity has password
-    public boolean doesUserHasPassword(UserIdentity userIdent) {
-        Preconditions.checkState(userIdent.isDomain());
-        if (!propertyMap.containsKey(userIdent.getQualifiedUser())) {
-            return false;
-        }
-        return propertyMap.get(userIdent.getQualifiedUser()).getWhiteList().hasPassword(userIdent.getHost());
-    }
-
-    public boolean doesUserExist(UserIdentity userIdent) {
-        Preconditions.checkState(userIdent.isDomain());
-        if (!propertyMap.containsKey(userIdent.getQualifiedUser())) {
-            return false;
-        }
-        return propertyMap.get(userIdent.getQualifiedUser()).getWhiteList().containsDomain(userIdent.getHost());
-    }
-
-    public void addUserPrivEntriesByResolvedIPs(Map<String, Set<String>> resolvedIPsMap) {
-        for (UserProperty userProperty : propertyMap.values()) {
-            userProperty.getWhiteList()
-                    .addUserPrivEntriesByResolvedIPs(userProperty.getQualifiedUser(), resolvedIPsMap);
-        }
-    }
-
     public String[] getSqlBlockRules(String qualifiedUser) {
         UserProperty existProperty = propertyMap.get(qualifiedUser);
         existProperty = getLdapPropertyIfNull(qualifiedUser, existProperty);
         if (existProperty == null) {
-            return new String[]{};
+            return new String[] {};
         }
         return existProperty.getSqlBlockRules();
     }
@@ -283,6 +174,24 @@ public class UserPropertyMgr implements Writable {
         return existProperty.getExecMemLimit();
     }
 
+    public String getWorkloadGroup(String qualifiedUser) {
+        UserProperty existProperty = propertyMap.get(qualifiedUser);
+        existProperty = getLdapPropertyIfNull(qualifiedUser, existProperty);
+        if (existProperty == null) {
+            return null;
+        }
+        return existProperty.getWorkloadGroup();
+    }
+
+    public Pair<Boolean, String> isWorkloadGroupInUse(String groupName) {
+        for (Entry<String, UserProperty> entry : propertyMap.entrySet()) {
+            if (entry.getValue().getWorkloadGroup().equals(groupName)) {
+                return Pair.of(true, entry.getKey());
+            }
+        }
+        return Pair.of(false, "");
+    }
+
     private UserProperty getLdapPropertyIfNull(String qualifiedUser, UserProperty existProperty) {
         if (existProperty == null && Env.getCurrentEnv().getAuth().getLdapManager().doesUserExist(qualifiedUser)) {
             return LDAP_PROPERTY;
