@@ -17,6 +17,8 @@
 
 package org.apache.doris.nereids.trees.expressions.functions;
 
+import org.apache.doris.qe.ConnectContext;
+
 /**
  * Nondeterministic functions.
  *
@@ -24,5 +26,11 @@ package org.apache.doris.nereids.trees.expressions.functions;
  *
  * note: no 'uuid' function currently.
  */
-public interface Nondeterministic {
+public interface Nondeterministic extends ExpressionTrait {
+    @Override
+    default boolean foldable() {
+        return ConnectContext.get() == null
+                || ConnectContext.get().getSessionVariable() == null
+                || ConnectContext.get().getSessionVariable().isEnableFoldNondeterministicFn();
+    }
 }
