@@ -55,9 +55,10 @@ public class LogicalApply<LEFT_CHILD_TYPE extends Plan, RIGHT_CHILD_TYPE extends
     // The slot replaced by the subquery in MarkJoin
     private final Optional<MarkJoinSlotReference> markJoinSlotReference;
 
-    private final Optional<Expression> subCorrespondingConjunct;
-
     // Whether the subquery is in logicalProject
+    private final boolean inProject;
+
+    // Whether adding the subquery's output to projects
     private final boolean needAddSubOutputToProjects;
 
     /**
@@ -68,7 +69,7 @@ public class LogicalApply<LEFT_CHILD_TYPE extends Plan, RIGHT_CHILD_TYPE extends
             List<Expression> correlationSlot,
             SubqueryExpr subqueryExpr, Optional<Expression> correlationFilter,
             Optional<MarkJoinSlotReference> markJoinSlotReference,
-            Optional<Expression> subCorrespondingConjunct,
+            boolean needAddSubOutputToProjects,
             boolean inProject,
             LEFT_CHILD_TYPE leftChild, RIGHT_CHILD_TYPE rightChild) {
         super(PlanType.LOGICAL_APPLY, groupExpression, logicalProperties, leftChild, rightChild);
@@ -76,16 +77,17 @@ public class LogicalApply<LEFT_CHILD_TYPE extends Plan, RIGHT_CHILD_TYPE extends
         this.subqueryExpr = Objects.requireNonNull(subqueryExpr, "subquery can not be null");
         this.correlationFilter = correlationFilter;
         this.markJoinSlotReference = markJoinSlotReference;
-        this.subCorrespondingConjunct = subCorrespondingConjunct;
-        this.needAddSubOutputToProjects = inProject;
+        this.needAddSubOutputToProjects = needAddSubOutputToProjects;
+        this.inProject = inProject;
     }
 
     public LogicalApply(List<Expression> correlationSlot, SubqueryExpr subqueryExpr,
             Optional<Expression> correlationFilter, Optional<MarkJoinSlotReference> markJoinSlotReference,
-            Optional<Expression> subCorrespondingConjunct, boolean inProject,
+            boolean needAddSubOutputToProjects, boolean inProject,
             LEFT_CHILD_TYPE input, RIGHT_CHILD_TYPE subquery) {
-        this(Optional.empty(), Optional.empty(), correlationSlot, subqueryExpr,
-                correlationFilter, markJoinSlotReference, subCorrespondingConjunct, inProject, input, subquery);
+        this(Optional.empty(), Optional.empty(), correlationSlot, subqueryExpr, correlationFilter,
+                markJoinSlotReference, needAddSubOutputToProjects, inProject, input,
+                subquery);
     }
 
     public List<Expression> getCorrelationSlot() {
@@ -128,14 +130,14 @@ public class LogicalApply<LEFT_CHILD_TYPE extends Plan, RIGHT_CHILD_TYPE extends
         return markJoinSlotReference;
     }
 
-    public Optional<Expression> getSubCorrespondingConjunct() {
-        return subCorrespondingConjunct;
-    }
-
     public boolean isNeedAddSubOutputToProjects() {
         return needAddSubOutputToProjects;
     }
 
+    public boolean isInProject() {
+        return inProject;
+    }
+
     @Override
     public List<Slot> computeOutput() {
         return ImmutableList.<Slot>builder()
@@ -153,9 +155,7 @@ public class LogicalApply<LEFT_CHILD_TYPE extends Plan, RIGHT_CHILD_TYPE extends
                 "correlationSlot", correlationSlot,
                 "correlationFilter", correlationFilter,
                 "isMarkJoin", markJoinSlotReference.isPresent(),
-                "MarkJoinSlotReference", markJoinSlotReference.isPresent() ? markJoinSlotReference.get() : "empty",
-                "scalarSubCorrespondingSlot",
-                subCorrespondingConjunct.isPresent() ? subCorrespondingConjunct.get() : "empty");
+                "MarkJoinSlotReference", markJoinSlotReference.isPresent() ? markJoinSlotReference.get() : "empty");
     }
 
     @Override
@@ -171,15 +171,15 @@ public class LogicalApply<LEFT_CHILD_TYPE extends Plan, RIGHT_CHILD_TYPE extends
                 && Objects.equals(subqueryExpr, that.getSubqueryExpr())
                 && Objects.equals(correlationFilter, that.getCorrelationFilter())
                 && Objects.equals(markJoinSlotReference, that.getMarkJoinSlotReference())
-                && Objects.equals(subCorrespondingConjunct, that.getSubCorrespondingConjunct())
-                && needAddSubOutputToProjects == that.needAddSubOutputToProjects;
+                && needAddSubOutputToProjects == that.needAddSubOutputToProjects
+                && inProject == that.inProject;
     }
 
     @Override
     public int hashCode() {
         return Objects.hash(
                 correlationSlot, subqueryExpr, correlationFilter,
-                markJoinSlotReference, subCorrespondingConjunct, needAddSubOutputToProjects);
+                markJoinSlotReference, needAddSubOutputToProjects, inProject);
     }
 
     @Override
@@ -204,23 +204,23 @@ public class LogicalApply<LEFT_CHILD_TYPE extends Plan, RIGHT_CHILD_TYPE extends
     public LogicalBinary<Plan, Plan> withChildren(List<Plan> children) {
         Preconditions.checkArgument(children.size() == 2);
         return new LogicalApply<>(correlationSlot, subqueryExpr, correlationFilter,
-                markJoinSlotReference, subCorrespondingConjunct, needAddSubOutputToProjects,
+                markJoinSlotReference, needAddSubOutputToProjects, inProject,
                 children.get(0), children.get(1));
     }
 
     @Override
     public Plan withGroupExpression(Optional<GroupExpression> groupExpression) {
         return new LogicalApply<>(groupExpression, Optional.of(getLogicalProperties()),
-                correlationSlot, subqueryExpr, correlationFilter,
-                markJoinSlotReference, subCorrespondingConjunct, needAddSubOutputToProjects, left(), right());
+                correlationSlot, subqueryExpr, correlationFilter, markJoinSlotReference,
+                needAddSubOutputToProjects, inProject, left(), right());
     }
 
     @Override
     public Plan withGroupExprLogicalPropChildren(Optional<GroupExpression> groupExpression,
             Optional<LogicalProperties> logicalProperties, List<Plan> children) {
         Preconditions.checkArgument(children.size() == 2);
-        return new LogicalApply<>(groupExpression, logicalProperties, correlationSlot, subqueryExpr, correlationFilter,
-                markJoinSlotReference, subCorrespondingConjunct, needAddSubOutputToProjects, children.get(0),
-                children.get(1));
+        return new LogicalApply<>(groupExpression, logicalProperties, correlationSlot, subqueryExpr,
+                correlationFilter, markJoinSlotReference,
+                needAddSubOutputToProjects, inProject, children.get(0), children.get(1));
     }
 }
