@@ -22,7 +22,6 @@ import org.apache.doris.catalog.Type;
 import org.apache.doris.nereids.annotation.Developing;
 import org.apache.doris.nereids.types.coercion.AbstractDataType;
 import org.apache.doris.nereids.types.coercion.FractionalType;
-import org.apache.doris.nereids.types.coercion.IntegralType;
 
 import com.google.common.base.Preconditions;
 import com.google.common.collect.ImmutableMap;
@@ -36,77 +35,99 @@ import java.util.Objects;
  */
 @Developing
 public class DecimalV3Type extends FractionalType {
-    public static final int MAX_DECIMALV2_SCALE = 9;
     public static final int MAX_DECIMAL32_PRECISION = 9;
     public static final int MAX_DECIMAL64_PRECISION = 18;
     public static final int MAX_DECIMAL128_PRECISION = 38;
 
-    public static final DecimalV3Type DEFAULT_DECIMAL32 = new DecimalV3Type(DEFAULT_PRECISION, DEFAULT_SCALE);
-    public static final DecimalV3Type DEFAULT_DECIMAL64 = new DecimalV3Type(DEFAULT_PRECISION, DEFAULT_SCALE);
-    public static final DecimalV3Type DEFAULT_DECIMAL128 = new DecimalV3Type(MAX_DECIMAL128_PRECISION, DEFAULT_SCALE);
-    public static final DecimalV3Type SYSTEM_DEFAULT = DEFAULT_DECIMAL32;
+    public static final DecimalV3Type WILDCARD = new DecimalV3Type(-1, -1);
+    public static final DecimalV3Type SYSTEM_DEFAULT = new DecimalV3Type(MAX_DECIMAL128_PRECISION, DEFAULT_SCALE);
 
-    private static final DecimalV3Type BOOLEAN_DECIMAL = DEFAULT_DECIMAL32;
-    private static final DecimalV3Type TINYINT_DECIMAL = DEFAULT_DECIMAL32;
-    private static final DecimalV3Type SMALLINT_DECIMAL = DEFAULT_DECIMAL32;
-    private static final DecimalV3Type INTEGER_DECIMAL = DEFAULT_DECIMAL32;
-    private static final DecimalV3Type BIGINT_DECIMAL = DEFAULT_DECIMAL64;
-    private static final DecimalV3Type FLOAT_DECIMAL = DEFAULT_DECIMAL64;
-    private static final DecimalV3Type DOUBLE_DECIMAL = DEFAULT_DECIMAL128;
+    private static final DecimalV3Type BOOLEAN_DECIMAL = new DecimalV3Type(1, 0);
+    private static final DecimalV3Type TINYINT_DECIMAL = new DecimalV3Type(3, 0);
+    private static final DecimalV3Type SMALLINT_DECIMAL = new DecimalV3Type(5, 0);
+    private static final DecimalV3Type INTEGER_DECIMAL = new DecimalV3Type(10, 0);
+    private static final DecimalV3Type BIGINT_DECIMAL = new DecimalV3Type(20, 0);
+    private static final DecimalV3Type LARGEINT_DECIMAL = new DecimalV3Type(38, 0);
+    private static final DecimalV3Type FLOAT_DECIMAL = new DecimalV3Type(14, 7);
+    private static final DecimalV3Type DOUBLE_DECIMAL = new DecimalV3Type(30, 15);
 
     private static final Map<DataType, DecimalV3Type> FOR_TYPE_MAP = ImmutableMap.<DataType, DecimalV3Type>builder()
+            .put(BooleanType.INSTANCE, BOOLEAN_DECIMAL)
             .put(TinyIntType.INSTANCE, TINYINT_DECIMAL)
             .put(SmallIntType.INSTANCE, SMALLINT_DECIMAL)
             .put(IntegerType.INSTANCE, INTEGER_DECIMAL)
             .put(BigIntType.INSTANCE, BIGINT_DECIMAL)
-            .put(LargeIntType.INSTANCE, DEFAULT_DECIMAL128)
+            .put(LargeIntType.INSTANCE, LARGEINT_DECIMAL)
             .put(FloatType.INSTANCE, FLOAT_DECIMAL)
             .put(DoubleType.INSTANCE, DOUBLE_DECIMAL)
+            .put(NullType.INSTANCE, BOOLEAN_DECIMAL)
             .build();
 
-    private final int precision;
-    private final int scale;
+    protected final int precision;
+    protected final int scale;
 
     private DecimalV3Type(int precision, int scale) {
-        Preconditions.checkArgument(precision > 0 && precision <= MAX_DECIMAL128_PRECISION);
         this.precision = precision;
         this.scale = scale;
     }
 
+    /**
+     * create DecimalV3Type with appropriate scale and precision.
+     */
     public static DecimalV3Type forType(DataType dataType) {
+        if (dataType instanceof DecimalV3Type) {
+            return (DecimalV3Type) dataType;
+        }
+        if (dataType instanceof DecimalV2Type) {
+            return createDecimalV3Type(
+                    ((DecimalV2Type) dataType).getPrecision(), ((DecimalV2Type) dataType).getScale());
+        }
         if (FOR_TYPE_MAP.containsKey(dataType)) {
             return FOR_TYPE_MAP.get(dataType);
         }
-        throw new RuntimeException("Could not create decimal for type " + dataType);
+        if (dataType.isDateTimeV2Type()) {
+            return createDecimalV3Type(14 + ((DateTimeV2Type) dataType).getScale(),
+                    ((DateTimeV2Type) dataType).getScale());
+        }
+        return SYSTEM_DEFAULT;
     }
 
     /** createDecimalV3Type. */
     public static DecimalV3Type createDecimalV3Type(int precision) {
-        if (precision <= MAX_DECIMAL32_PRECISION) {
-            return DEFAULT_DECIMAL32;
-        }
-        if (precision <= MAX_DECIMAL64_PRECISION) {
-            return DEFAULT_DECIMAL64;
-        }
-        if (precision <= MAX_DECIMAL128_PRECISION) {
-            return DEFAULT_DECIMAL128;
-        }
+        return createDecimalV3Type(precision, DEFAULT_SCALE);
+    }
 
-        return new DecimalV3Type(Math.min(precision, MAX_DECIMAL128_PRECISION), DEFAULT_SCALE);
+    /** createDecimalV3Type. */
+    public static DecimalV3Type createDecimalV3Type(int precision, int scale) {
+        Preconditions.checkArgument(precision > 0 && precision <= MAX_DECIMAL128_PRECISION,
+                "precision should in (0, " + MAX_DECIMAL128_PRECISION + "], but real precision is " + precision);
+        Preconditions.checkArgument(scale >= 0, "scale should not smaller than 0, but real scale is " + scale);
+        Preconditions.checkArgument(precision >= scale, "precision should not smaller than scale,"
+                + " but precision is " + precision, ", scale is " + scale);
+        return new DecimalV3Type(precision, scale);
     }
 
     public static DecimalV3Type createDecimalV3Type(BigDecimal bigDecimal) {
         int precision = org.apache.doris.analysis.DecimalLiteral.getBigDecimalPrecision(bigDecimal);
-        return createDecimalV3Type(precision);
+        int scale = org.apache.doris.analysis.DecimalLiteral.getBigDecimalScale(bigDecimal);
+        return createDecimalV3Type(precision, scale);
     }
 
-    public static DecimalV3Type widerDecimalV3Type(DecimalV3Type left, DecimalV3Type right) {
-        return widerDecimalV3Type(left.getPrecision(), right.getPrecision());
+    public static DataType widerDecimalV3Type(DecimalV3Type left, DecimalV3Type right, boolean overflowToDouble) {
+        return widerDecimalV3Type(left.getPrecision(), right.getPrecision(),
+                left.getScale(), right.getScale(), overflowToDouble);
     }
 
-    private static DecimalV3Type widerDecimalV3Type(int leftPrecision, int rightPrecision) {
-        int maxPrecision = Math.max(leftPrecision, rightPrecision);
-        return DecimalV3Type.createDecimalV3Type(maxPrecision);
+    private static DataType widerDecimalV3Type(
+            int leftPrecision, int rightPrecision,
+            int leftScale, int rightScale,
+            boolean overflowToDouble) {
+        int scale = Math.max(leftScale, rightScale);
+        int range = Math.max(leftPrecision - leftScale, rightPrecision - rightScale);
+        if (range + scale > MAX_DECIMAL128_PRECISION && overflowToDouble) {
+            return DoubleType.INSTANCE;
+        }
+        return DecimalV3Type.createDecimalV3Type(range + scale, scale);
     }
 
     @Override
@@ -122,38 +143,28 @@ public class DecimalV3Type extends FractionalType {
         return scale;
     }
 
-    public boolean isWiderThan(DataType other) {
-        return isWiderThanInternal(other);
-    }
-
-    private boolean isWiderThanInternal(DataType other) {
-        if (other instanceof DecimalV3Type) {
-            DecimalV3Type dt = (DecimalV3Type) other;
-            return this.precision - this.scale >= dt.precision - dt.scale && this.scale >= dt.scale;
-        } else if (other instanceof IntegralType) {
-            return isWiderThanInternal(forType(other));
-        }
-        return false;
+    public int getRange() {
+        return precision - scale;
     }
 
     @Override
     public DataType defaultConcreteType() {
-        return SYSTEM_DEFAULT;
+        return this;
     }
 
     @Override
     public boolean acceptsType(AbstractDataType other) {
-        return other instanceof DecimalV3Type;
+        return other.equals(this);
     }
 
     @Override
     public String simpleString() {
-        return "decimal";
+        return "decimalv3";
     }
 
     @Override
     public String toSql() {
-        return "DECIMAL(" + precision + ", " + scale + ")";
+        return "DECIMALV3(" + precision + ", " + scale + ")";
     }
 
     @Override
@@ -186,6 +197,4 @@ public class DecimalV3Type extends FractionalType {
             return 16;
         }
     }
-
 }
-
