@@ -17,6 +17,7 @@
 
 package org.apache.doris.nereids.types;
 
+import org.apache.doris.catalog.ScalarType;
 import org.apache.doris.catalog.Type;
 import org.apache.doris.nereids.types.coercion.PrimitiveType;
 
@@ -28,13 +29,26 @@ public class TimeV2Type extends PrimitiveType {
     public static final TimeV2Type INSTANCE = new TimeV2Type();
 
     private static final int WIDTH = 8;
+    private final int scale;
+
+    private TimeV2Type(int scale) {
+        this.scale = scale;
+    }
 
     private TimeV2Type() {
+        scale = 0;
     }
 
     @Override
     public Type toCatalogDataType() {
-        return Type.TIMEV2;
+        return ScalarType.createTimeV2Type(scale);
+    }
+
+    /**
+     * create TimeV2Type from scale
+     */
+    public static TimeV2Type of(int scale) {
+        return new TimeV2Type(scale);
     }
 
     @Override
@@ -46,4 +60,8 @@ public class TimeV2Type extends PrimitiveType {
     public int width() {
         return WIDTH;
     }
+
+    public int getScale() {
+        return scale;
+    }
 }
