@@ -48,6 +48,7 @@ public class QueryState {
     private int warningRows = 0;
     // make it public for easy to use
     public int serverStatus = 0;
+    public boolean isNereids = false;
 
     public QueryState() {
     }
@@ -61,12 +62,17 @@ public class QueryState {
         isQuery = false;
         affectedRows = 0;
         warningRows = 0;
+        isNereids = false;
     }
 
     public MysqlStateType getStateType() {
         return stateType;
     }
 
+    public void setNoop() {
+        stateType = MysqlStateType.NOOP;
+    }
+
     public void setEof() {
         stateType = MysqlStateType.EOF;
     }
@@ -136,6 +142,14 @@ public class QueryState {
         return warningRows;
     }
 
+    public void setNereids(boolean nereids) {
+        isNereids = nereids;
+    }
+
+    public boolean isNereids() {
+        return isNereids;
+    }
+
     public MysqlPacket toResponsePacket() {
         MysqlPacket packet = null;
         switch (stateType) {
