@@ -19,20 +19,31 @@ package org.apache.doris.system;
 
 import org.apache.doris.catalog.Env;
 import org.apache.doris.common.Config;
+import org.apache.doris.common.FeMetaVersion;
 import org.apache.doris.common.io.Text;
 import org.apache.doris.common.io.Writable;
 import org.apache.doris.ha.BDBHA;
 import org.apache.doris.ha.FrontendNodeType;
+import org.apache.doris.persist.gson.GsonUtils;
 import org.apache.doris.system.HeartbeatResponse.HbStatus;
+import org.apache.doris.system.SystemInfoService.HostInfo;
+
+import com.google.gson.annotations.SerializedName;
 
 import java.io.DataInput;
 import java.io.DataOutput;
 import java.io.IOException;
 
 public class Frontend implements Writable {
+    @SerializedName("role")
     private FrontendNodeType role;
+    // nodeName = ip:port_timestamp
+    @SerializedName("nodeName")
     private String nodeName;
-    private String host;
+    @SerializedName(value = "host", alternate = {"ip"})
+    private volatile String host;
+    // used for getIpByHostname
+    @SerializedName("editLogPort")
     private int editLogPort;
     private String version;
 
@@ -45,9 +56,14 @@ public class Frontend implements Writable {
 
     private boolean isAlive = false;
 
-    public Frontend() {}
+    public Frontend() {
+    }
 
     public Frontend(FrontendNodeType role, String nodeName, String host, int editLogPort) {
+        this(role, nodeName, host, "", editLogPort);
+    }
+
+    public Frontend(FrontendNodeType role, String nodeName, String host, String hostName, int editLogPort) {
         this.role = role;
         this.nodeName = nodeName;
         this.host = host;
@@ -82,6 +98,10 @@ public class Frontend implements Writable {
         return isAlive;
     }
 
+    public void setIsAlive(boolean isAlive) {
+        this.isAlive = isAlive;
+    }
+
     public int getEditLogPort() {
         return this.editLogPort;
     }
@@ -131,13 +151,12 @@ public class Frontend implements Writable {
 
     @Override
     public void write(DataOutput out) throws IOException {
-        Text.writeString(out, role.name());
-        Text.writeString(out, host);
-        out.writeInt(editLogPort);
-        Text.writeString(out, nodeName);
+        String json = GsonUtils.GSON.toJson(this);
+        Text.writeString(out, json);
     }
 
-    public void readFields(DataInput in) throws IOException {
+    @Deprecated
+    private void readFields(DataInput in) throws IOException {
         role = FrontendNodeType.valueOf(Text.readString(in));
         if (role == FrontendNodeType.REPLICA) {
             // this is for compatibility.
@@ -150,9 +169,13 @@ public class Frontend implements Writable {
     }
 
     public static Frontend read(DataInput in) throws IOException {
-        Frontend frontend = new Frontend();
-        frontend.readFields(in);
-        return frontend;
+        if (Env.getCurrentEnvJournalVersion() < FeMetaVersion.VERSION_118) {
+            Frontend frontend = new Frontend();
+            frontend.readFields(in);
+            return frontend;
+        }
+        String json = Text.readString(in);
+        return GsonUtils.GSON.fromJson(json, Frontend.class);
     }
 
     @Override
@@ -160,6 +183,15 @@ public class Frontend implements Writable {
         StringBuilder sb = new StringBuilder();
         sb.append("name: ").append(nodeName).append(", role: ").append(role.name());
         sb.append(", ").append(host).append(":").append(editLogPort);
+        sb.append(", is alive: ").append(isAlive);
         return sb.toString();
     }
+
+    public void setHost(String host) {
+        this.host = host;
+    }
+
+    public HostInfo toHostInfo() {
+        return new HostInfo(host, editLogPort);
+    }
 }
