@@ -17,7 +17,11 @@
 
 package org.apache.doris.tablefunction;
 
+import org.apache.doris.analysis.TupleDescriptor;
 import org.apache.doris.common.AnalysisException;
+import org.apache.doris.planner.DataGenScanNode;
+import org.apache.doris.planner.PlanNodeId;
+import org.apache.doris.planner.ScanNode;
 import org.apache.doris.thrift.TDataGenFunctionName;
 
 import java.util.List;
@@ -27,4 +31,8 @@ public abstract class DataGenTableValuedFunction extends TableValuedFunctionIf {
 
     public abstract TDataGenFunctionName getDataGenFunctionName();
 
+    @Override
+    public ScanNode getScanNode(PlanNodeId id, TupleDescriptor desc) {
+        return new DataGenScanNode(id, desc, this);
+    }
 }
