@@ -67,7 +67,6 @@ public class S3TableValuedFunction extends ExternalFileTableValuedFunction {
     private final S3URI s3uri;
     private final boolean forceVirtualHosted;
     private String virtualBucket = "";
-    private String virtualKey;
 
     public S3TableValuedFunction(Map<String, String> params) throws AnalysisException {
         Map<String, String> tvfParams = getValidParams(params);
@@ -93,8 +92,6 @@ public class S3TableValuedFunction extends ExternalFileTableValuedFunction {
         locationProperties = S3Properties.credentialToMap(credential);
         String usePathStyle = tvfParams.getOrDefault(PropertyConverter.USE_PATH_STYLE, "false");
         locationProperties.put(PropertyConverter.USE_PATH_STYLE, usePathStyle);
-        locationProperties.put(S3Properties.VIRTUAL_BUCKET, virtualBucket);
-        locationProperties.put(S3Properties.VIRTUAL_KEY, getVirtualKey());
 
         parseProperties(tvfParams);
         if (FeConstants.runningUnitTest) {
@@ -124,11 +121,6 @@ public class S3TableValuedFunction extends ExternalFileTableValuedFunction {
         return S3Properties.requiredS3TVFProperties(validParams);
     }
 
-    private String getVirtualKey() {
-        virtualKey = s3uri.getBucket() + S3URI.PATH_DELIM + s3uri.getKey();
-        return virtualKey;
-    }
-
     private String getEndpointAndSetVirtualBucket(Map<String, String> params) throws AnalysisException {
         Preconditions.checkState(forceVirtualHosted, "only invoked when force virtual hosted.");
         String[] fileds = s3uri.getVirtualBucket().split("\\.", 2);
@@ -175,7 +167,8 @@ public class S3TableValuedFunction extends ExternalFileTableValuedFunction {
     public String getFilePath() {
         // must be "s3://..."
         if (forceVirtualHosted) {
-            return NAME + S3URI.SCHEME_DELIM + virtualBucket + S3URI.PATH_DELIM + virtualKey;
+            return NAME + S3URI.SCHEME_DELIM + virtualBucket + S3URI.PATH_DELIM
+                    + s3uri.getBucket() + S3URI.PATH_DELIM + s3uri.getKey();
         }
         return NAME + S3URI.SCHEME_DELIM + s3uri.getKey();
     }
