@@ -81,6 +81,7 @@ import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.locks.ReentrantReadWriteLock;
+import java.util.function.Function;
 import java.util.stream.Collectors;
 
 /**
@@ -434,6 +435,7 @@ public class DatabaseTransactionMgr {
                                    Set<Long> errorReplicaIds, Map<Long, Set<Long>> tableToPartition,
                                    Set<Long> totalInvolvedBackends) throws UserException {
 
+        long transactionId = transactionState.getTransactionId();
         Database db = env.getInternalCatalog().getDbOrMetaException(dbId);
 
         // update transaction state extra if exists
@@ -490,6 +492,33 @@ public class DatabaseTransactionMgr {
             }
             tabletToBackends.get(tabletId).add(tabletCommitInfos.get(i).getBackendId());
         }
+        List<String> tabletSuccReplicas = Lists.newArrayList();
+        List<String> tabletWriteFailedReplicas = Lists.newArrayList();
+        List<String> tabletVersionFailedReplicas = Lists.newArrayList();
+        Function<Replica, String> getReplicaInfo = replica -> {
+            StringBuilder strBuffer = new StringBuilder("[replicaId=");
+            strBuffer.append(replica.getId());
+            strBuffer.append(", backendId=");
+            strBuffer.append(replica.getBackendId());
+            strBuffer.append(", backendAlive=");
+            strBuffer.append(Env.getCurrentSystemInfo().checkBackendAlive(replica.getBackendId()));
+            strBuffer.append(", version=");
+            strBuffer.append(replica.getVersion());
+            if (replica.getLastFailedVersion() >= 0) {
+                strBuffer.append(", lastFailedVersion=");
+                strBuffer.append(replica.getLastFailedVersion());
+                strBuffer.append(", lastSuccessVersion=");
+                strBuffer.append(replica.getLastSuccessVersion());
+                strBuffer.append(", lastFailedTimestamp=");
+                strBuffer.append(replica.getLastFailedTimestamp());
+            }
+            strBuffer.append(", state=");
+            strBuffer.append(replica.getState().name());
+            strBuffer.append("]");
+
+            return strBuffer.toString();
+        };
+
         for (long tableId : tableToPartition.keySet()) {
             OlapTable table = (OlapTable) db.getTableOrMetaException(tableId);
             for (Partition partition : table.getAllPartitions()) {
@@ -533,6 +562,9 @@ public class DatabaseTransactionMgr {
                         .getReplicaAllocation(partition.getId()).getTotalReplicaNum() / 2 + 1;
                 for (MaterializedIndex index : allIndices) {
                     for (Tablet tablet : index.getTablets()) {
+                        tabletSuccReplicas.clear();
+                        tabletWriteFailedReplicas.clear();
+                        tabletVersionFailedReplicas.clear();
                         int successReplicaNum = 0;
                         long tabletId = tablet.getId();
                         Set<Long> tabletBackends = tablet.getBackendIds();
@@ -558,11 +590,14 @@ public class DatabaseTransactionMgr {
                                 // for example, a replica is in clone state
                                 if (replica.getLastFailedVersion() < 0) {
                                     ++successReplicaNum;
+                                    tabletSuccReplicas.add(getReplicaInfo.apply(replica));
                                 } else {
                                     errorReplicaInfo += " replica [" + replica.getId() + "], lastFailedVersion ["
                                                         + replica.getLastFailedVersion() + "]";
+                                    tabletVersionFailedReplicas.add(getReplicaInfo.apply(replica));
                                 }
                             } else {
+                                tabletWriteFailedReplicas.add(getReplicaInfo.apply(replica));
                                 errorBackendIdsForTablet.add(tabletBackend);
                                 errorReplicaIds.add(replica.getId());
                                 // not remove rollup task here, because the commit maybe failed
@@ -580,9 +615,29 @@ public class DatabaseTransactionMgr {
                                     transactionState.getTransactionId(), tablet.getId(), successReplicaNum,
                                     quorumReplicaNum, Joiner.on(",").join(errorBackendIdsForTablet),
                                     errorReplicaInfo, commitBackends);
-                            throw new TabletQuorumFailedException(transactionState.getTransactionId(), tablet.getId(),
-                                    successReplicaNum, quorumReplicaNum,
-                                    errorBackendIdsForTablet);
+
+                            String replicasDetailMsg = "";
+                            if (!tabletSuccReplicas.isEmpty()) {
+                                replicasDetailMsg += String.format("%s replicas final succ: { %s }; ",
+                                        tabletSuccReplicas.size(), Joiner.on(", ").join(tabletSuccReplicas));
+                            }
+                            if (!tabletWriteFailedReplicas.isEmpty()) {
+                                replicasDetailMsg += String.format("%s replicas write data failed: { %s }; ",
+                                        tabletWriteFailedReplicas.size(),
+                                        Joiner.on(", ").join(tabletWriteFailedReplicas));
+                            }
+                            if (!tabletVersionFailedReplicas.isEmpty()) {
+                                replicasDetailMsg += String.format("%s replicas write data succ but miss previous "
+                                                + "version: { %s }.",
+                                        tabletVersionFailedReplicas.size(),
+                                        Joiner.on(", ").join(tabletVersionFailedReplicas));
+                            }
+
+                            throw new TabletQuorumFailedException(transactionId, String.format(
+                                        "Failed to commit txn %s, cause tablet %s succ replica num %s < quorum "
+                                                + " replica num %s. table %s, partition %s, this tablet detail: %s",
+                                        transactionId, tablet.getId(), successReplicaNum, quorumReplicaNum, tableId,
+                                        partition.getId(), replicasDetailMsg));
                         }
                     }
                 }
@@ -1709,6 +1764,35 @@ public class DatabaseTransactionMgr {
         return true;
     }
 
+    public boolean isPreviousTransactionsFinished(long endTransactionId, long tableId, long partitionId) {
+        readLock();
+        try {
+            for (Map.Entry<Long, TransactionState> entry : idToRunningTransactionState.entrySet()) {
+                TransactionState transactionState = entry.getValue();
+                if (entry.getKey() > endTransactionId
+                        || transactionState.getTransactionStatus().isFinalStatus()
+                        || transactionState.getDbId() != dbId
+                        || !transactionState.getTableIdList().contains(tableId)) {
+                    continue;
+                }
+
+                if (transactionState.getTransactionStatus() == TransactionStatus.COMMITTED) {
+                    TableCommitInfo tableCommitInfo = transactionState.getTableCommitInfo(tableId);
+                    // txn not contains this partition
+                    if (tableCommitInfo != null
+                            && tableCommitInfo.getIdToPartitionCommitInfo().get(partitionId) == null) {
+                        continue;
+                    }
+                }
+
+                return false;
+            }
+        } finally {
+            readUnlock();
+        }
+        return true;
+    }
+
     /**
      * check if there exists a intersection between the source tableId list and target tableId list
      * if one of them is null or empty, that means that we don't know related tables in tableList,
