@@ -315,7 +315,7 @@ public class RollupJobV2Test {
 
     @Test
     public void testSerializeOfRollupJob(@Mocked CreateMaterializedViewStmt stmt)
-            throws IOException {
+            throws IOException, AnalysisException {
         // prepare file
         File file = new File(fileName);
         file.createNewFile();
@@ -327,7 +327,7 @@ public class RollupJobV2Test {
         Column column = new Column(mvColumnName, Type.BITMAP, false, AggregateType.BITMAP_UNION, false, "1", "");
         columns.add(column);
 
-        RollupJobV2 rollupJobV2 = new RollupJobV2(1, 1, 1, "test", 1, 1, 1, "test", "rollup", columns, 1, 1,
+        RollupJobV2 rollupJobV2 = new RollupJobV2("", 1, 1, 1, "test", 1, 1, 1, "test", "rollup", columns, null, 1, 1,
                 KeysType.AGG_KEYS, keysCount,
                 new OriginStatement("create materialized view rollup as select bitmap_union(to_bitmap(c1)) from test",
                         0));
