@@ -17,10 +17,15 @@
 
 package org.apache.doris.analysis;
 
+import org.apache.doris.catalog.Env;
 import org.apache.doris.common.AnalysisException;
 import org.apache.doris.common.FeConstants;
+import org.apache.doris.common.MetaNotFoundException;
 import org.apache.doris.common.UserException;
-import org.apache.doris.mysql.privilege.PaloAuth;
+import org.apache.doris.load.routineload.KafkaRoutineLoadJob;
+import org.apache.doris.load.routineload.kafka.KafkaConfiguration;
+import org.apache.doris.load.routineload.kafka.KafkaDataSourceProperties;
+import org.apache.doris.mysql.privilege.AccessControllerManager;
 import org.apache.doris.mysql.privilege.PrivPredicate;
 import org.apache.doris.qe.ConnectContext;
 
@@ -31,35 +36,31 @@ import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;
 
+import java.util.HashMap;
 import java.util.Map;
 
-/*
- * Author: Chenmingyu
- * Date: Jul 20, 2020
- */
-
 public class AlterRoutineLoadStmtTest {
 
     private Analyzer analyzer;
 
     @Mocked
-    private PaloAuth auth;
+    private AccessControllerManager accessManager;
 
     @Before
-    public void setUp() {
+    public void setUp() throws MetaNotFoundException {
         analyzer = AccessTestUtil.fetchAdminAnalyzer(false);
         FeConstants.runningUnitTest = true;
         new Expectations() {
             {
-                auth.checkGlobalPriv((ConnectContext) any, (PrivPredicate) any);
+                accessManager.checkGlobalPriv((ConnectContext) any, (PrivPredicate) any);
                 minTimes = 0;
                 result = true;
 
-                auth.checkDbPriv((ConnectContext) any, anyString, (PrivPredicate) any);
+                accessManager.checkDbPriv((ConnectContext) any, anyString, (PrivPredicate) any);
                 minTimes = 0;
                 result = true;
 
-                auth.checkTblPriv((ConnectContext) any, anyString, anyString, (PrivPredicate) any);
+                accessManager.checkTblPriv((ConnectContext) any, anyString, anyString, (PrivPredicate) any);
                 minTimes = 0;
                 result = true;
             }
@@ -67,52 +68,61 @@ public class AlterRoutineLoadStmtTest {
     }
 
     @Test
-    public void testNormal() {
+    public void testNormal() throws UserException {
+        new Expectations() {
+            {
+                Env.getCurrentEnv().getRoutineLoadManager()
+                        .getJob(anyString, anyString);
+                minTimes = 0;
+                result = new KafkaRoutineLoadJob();
+            }
+        };
         { // CHECKSTYLE IGNORE THIS LINE
             Map<String, String> jobProperties = Maps.newHashMap();
             jobProperties.put(CreateRoutineLoadStmt.MAX_ERROR_NUMBER_PROPERTY, "100");
             jobProperties.put(CreateRoutineLoadStmt.MAX_BATCH_ROWS_PROPERTY, "200000");
-            String typeName = "kafka";
             Map<String, String> dataSourceProperties = Maps.newHashMap();
             dataSourceProperties.put("property.client.id", "101");
             dataSourceProperties.put("property.group.id", "mygroup");
-            dataSourceProperties.put(CreateRoutineLoadStmt.KAFKA_PARTITIONS_PROPERTY, "1,2,3");
-            dataSourceProperties.put(CreateRoutineLoadStmt.KAFKA_OFFSETS_PROPERTY, "10000, 20000, 30000");
-            RoutineLoadDataSourceProperties routineLoadDataSourceProperties = new RoutineLoadDataSourceProperties(
-                    typeName, dataSourceProperties, true);
+            dataSourceProperties.put(KafkaConfiguration.KAFKA_PARTITIONS.getName(), "1,2,3");
+            dataSourceProperties.put(KafkaConfiguration.KAFKA_OFFSETS.getName(), "10000, 20000, 30000");
             AlterRoutineLoadStmt stmt = new AlterRoutineLoadStmt(new LabelName("db1", "label1"),
-                    jobProperties, routineLoadDataSourceProperties);
-            try {
-                stmt.analyze(analyzer);
-            } catch (UserException e) {
-                Assert.fail();
-            }
-
+                    jobProperties, dataSourceProperties);
+            stmt.analyze(analyzer);
             Assert.assertEquals(2, stmt.getAnalyzedJobProperties().size());
             Assert.assertTrue(stmt.getAnalyzedJobProperties().containsKey(CreateRoutineLoadStmt.MAX_ERROR_NUMBER_PROPERTY));
             Assert.assertTrue(stmt.getAnalyzedJobProperties().containsKey(CreateRoutineLoadStmt.MAX_BATCH_ROWS_PROPERTY));
             Assert.assertTrue(stmt.hasDataSourceProperty());
-            Assert.assertEquals(2, stmt.getDataSourceProperties().getCustomKafkaProperties().size());
-            Assert.assertTrue(stmt.getDataSourceProperties().getCustomKafkaProperties().containsKey("group.id"));
-            Assert.assertTrue(stmt.getDataSourceProperties().getCustomKafkaProperties().containsKey("client.id"));
-            Assert.assertEquals(3, stmt.getDataSourceProperties().getKafkaPartitionOffsets().size());
+            KafkaDataSourceProperties kafkaDataSourceProperties = (KafkaDataSourceProperties) stmt.getDataSourceProperties();
+            Assert.assertEquals(2, kafkaDataSourceProperties.getCustomKafkaProperties().size());
+            Assert.assertTrue(kafkaDataSourceProperties.getCustomKafkaProperties().containsKey("group.id"));
+            Assert.assertTrue(kafkaDataSourceProperties.getCustomKafkaProperties().containsKey("client.id"));
+            Assert.assertEquals(3, kafkaDataSourceProperties.getKafkaPartitionOffsets().size());
         } // CHECKSTYLE IGNORE THIS LINE
     }
 
     @Test(expected = AnalysisException.class)
-    public void testNoProperties() throws AnalysisException, UserException {
+    public void testNoProperties() throws UserException {
         AlterRoutineLoadStmt stmt = new AlterRoutineLoadStmt(new LabelName("db1", "label1"),
-                Maps.newHashMap(), new RoutineLoadDataSourceProperties());
+                Maps.newHashMap(), new HashMap<>());
         stmt.analyze(analyzer);
     }
 
     @Test
-    public void testUnsupportedProperties() {
+    public void testUnsupportedProperties() throws MetaNotFoundException {
+        new Expectations() {
+            {
+                Env.getCurrentEnv().getRoutineLoadManager()
+                        .getJob(anyString, anyString);
+                minTimes = 0;
+                result = new KafkaRoutineLoadJob();
+            }
+        };
         { // CHECKSTYLE IGNORE THIS LINE
             Map<String, String> jobProperties = Maps.newHashMap();
             jobProperties.put(CreateRoutineLoadStmt.FORMAT, "csv");
             AlterRoutineLoadStmt stmt = new AlterRoutineLoadStmt(new LabelName("db1", "label1"),
-                    jobProperties, new RoutineLoadDataSourceProperties());
+                    jobProperties, new HashMap<>());
             try {
                 stmt.analyze(analyzer);
                 Assert.fail();
@@ -127,13 +137,11 @@ public class AlterRoutineLoadStmtTest {
         { // CHECKSTYLE IGNORE THIS LINE
             Map<String, String> jobProperties = Maps.newHashMap();
             jobProperties.put(CreateRoutineLoadStmt.MAX_ERROR_NUMBER_PROPERTY, "100");
-            String typeName = "kafka";
             Map<String, String> dataSourceProperties = Maps.newHashMap();
-            dataSourceProperties.put(CreateRoutineLoadStmt.KAFKA_TOPIC_PROPERTY, "new_topic");
-            RoutineLoadDataSourceProperties routineLoadDataSourceProperties = new RoutineLoadDataSourceProperties(
-                    typeName, dataSourceProperties, true);
+            dataSourceProperties.put(KafkaConfiguration.KAFKA_TOPIC.getName(), "new_topic");
+            //fixme: should be failed
             AlterRoutineLoadStmt stmt = new AlterRoutineLoadStmt(new LabelName("db1", "label1"),
-                    jobProperties, routineLoadDataSourceProperties);
+                    jobProperties, dataSourceProperties);
 
             try {
                 stmt.analyze(analyzer);
@@ -148,13 +156,10 @@ public class AlterRoutineLoadStmtTest {
         { // CHECKSTYLE IGNORE THIS LINE
             Map<String, String> jobProperties = Maps.newHashMap();
             jobProperties.put(CreateRoutineLoadStmt.MAX_ERROR_NUMBER_PROPERTY, "100");
-            String typeName = "kafka";
             Map<String, String> dataSourceProperties = Maps.newHashMap();
-            dataSourceProperties.put(CreateRoutineLoadStmt.KAFKA_PARTITIONS_PROPERTY, "1,2,3");
-            RoutineLoadDataSourceProperties routineLoadDataSourceProperties = new RoutineLoadDataSourceProperties(
-                    typeName, dataSourceProperties, true);
+            dataSourceProperties.put(KafkaConfiguration.KAFKA_PARTITIONS.getName(), "1,2,3");
             AlterRoutineLoadStmt stmt = new AlterRoutineLoadStmt(new LabelName("db1", "label1"),
-                    jobProperties, routineLoadDataSourceProperties);
+                    jobProperties, dataSourceProperties);
             try {
                 stmt.analyze(analyzer);
                 Assert.fail();
@@ -168,14 +173,11 @@ public class AlterRoutineLoadStmtTest {
         { // CHECKSTYLE IGNORE THIS LINE
             Map<String, String> jobProperties = Maps.newHashMap();
             jobProperties.put(CreateRoutineLoadStmt.MAX_ERROR_NUMBER_PROPERTY, "100");
-            String typeName = "kafka";
             Map<String, String> dataSourceProperties = Maps.newHashMap();
-            dataSourceProperties.put(CreateRoutineLoadStmt.KAFKA_PARTITIONS_PROPERTY, "1,2,3");
-            dataSourceProperties.put(CreateRoutineLoadStmt.KAFKA_OFFSETS_PROPERTY, "1000, 2000");
-            RoutineLoadDataSourceProperties routineLoadDataSourceProperties = new RoutineLoadDataSourceProperties(
-                    typeName, dataSourceProperties, true);
+            dataSourceProperties.put(KafkaConfiguration.KAFKA_PARTITIONS.getName(), "1,2,3");
+            dataSourceProperties.put(KafkaConfiguration.KAFKA_OFFSETS.getName(), "1000, 2000");
             AlterRoutineLoadStmt stmt = new AlterRoutineLoadStmt(new LabelName("db1", "label1"),
-                    jobProperties, routineLoadDataSourceProperties);
+                    jobProperties, dataSourceProperties);
             try {
                 stmt.analyze(analyzer);
                 Assert.fail();
@@ -189,13 +191,10 @@ public class AlterRoutineLoadStmtTest {
         { // CHECKSTYLE IGNORE THIS LINE
             Map<String, String> jobProperties = Maps.newHashMap();
             jobProperties.put(CreateRoutineLoadStmt.MAX_ERROR_NUMBER_PROPERTY, "100");
-            String typeName = "kafka";
             Map<String, String> dataSourceProperties = Maps.newHashMap();
-            dataSourceProperties.put(CreateRoutineLoadStmt.KAFKA_OFFSETS_PROPERTY, "1000, 2000, 3000");
-            RoutineLoadDataSourceProperties routineLoadDataSourceProperties = new RoutineLoadDataSourceProperties(
-                    typeName, dataSourceProperties, true);
+            dataSourceProperties.put(KafkaConfiguration.KAFKA_OFFSETS.getName(), "1000, 2000, 3000");
             AlterRoutineLoadStmt stmt = new AlterRoutineLoadStmt(new LabelName("db1", "label1"),
-                    jobProperties, routineLoadDataSourceProperties);
+                    jobProperties, dataSourceProperties);
             try {
                 stmt.analyze(analyzer);
                 Assert.fail();
@@ -210,16 +209,13 @@ public class AlterRoutineLoadStmtTest {
             Map<String, String> jobProperties = Maps.newHashMap();
             jobProperties.put(CreateRoutineLoadStmt.MAX_ERROR_NUMBER_PROPERTY, "100");
             jobProperties.put(CreateRoutineLoadStmt.MAX_BATCH_SIZE_PROPERTY, "200000");
-            String typeName = "kafka";
             Map<String, String> dataSourceProperties = Maps.newHashMap();
             dataSourceProperties.put("property.client.id", "101");
             dataSourceProperties.put("property.group.id", "mygroup");
-            dataSourceProperties.put(CreateRoutineLoadStmt.KAFKA_PARTITIONS_PROPERTY, "1,2,3");
-            dataSourceProperties.put(CreateRoutineLoadStmt.KAFKA_OFFSETS_PROPERTY, "10000, 20000, 30000");
-            RoutineLoadDataSourceProperties routineLoadDataSourceProperties = new RoutineLoadDataSourceProperties(
-                    typeName, dataSourceProperties, true);
+            dataSourceProperties.put(KafkaConfiguration.KAFKA_PARTITIONS.getName(), "1,2,3");
+            dataSourceProperties.put(KafkaConfiguration.KAFKA_OFFSETS.getName(), "10000, 20000, 30000");
             AlterRoutineLoadStmt stmt = new AlterRoutineLoadStmt(new LabelName("db1", "label1"),
-                    jobProperties, routineLoadDataSourceProperties);
+                    jobProperties, dataSourceProperties);
             try {
                 stmt.analyze(analyzer);
                 Assert.fail();
