@@ -61,6 +61,7 @@ public class CreateFunctionTest {
         FeConstants.runningUnitTest = true;
         // create connect context
         connectContext = UtFrameUtils.createDefaultCtx();
+        connectContext.getSessionVariable().setEnableNereidsPlanner(false);
     }
 
     @AfterClass
@@ -72,17 +73,13 @@ public class CreateFunctionTest {
     @Test
     public void test() throws Exception {
         ConnectContext ctx = UtFrameUtils.createDefaultCtx();
+        ctx.getSessionVariable().setEnableNereidsPlanner(false);
 
         // create database db1
-        String createDbStmtStr = "create database db1;";
-        CreateDbStmt createDbStmt = (CreateDbStmt) UtFrameUtils.parseAndAnalyzeStmt(createDbStmtStr, ctx);
-        Env.getCurrentEnv().createDb(createDbStmt);
-        System.out.println(Env.getCurrentInternalCatalog().getDbNames());
+        createDatabase(ctx, "create database db1;");
 
-        String createTblStmtStr = "create table db1.tbl1(k1 int, k2 bigint, k3 varchar(10), k4 char(5)) duplicate key(k1) "
-                + "distributed by hash(k2) buckets 1 properties('replication_num' = '1');";
-        CreateTableStmt createTableStmt = (CreateTableStmt) UtFrameUtils.parseAndAnalyzeStmt(createTblStmtStr, connectContext);
-        Env.getCurrentEnv().createTable(createTableStmt);
+        createTable("create table db1.tbl1(k1 int, k2 bigint, k3 varchar(10), k4 char(5)) duplicate key(k1) "
+                + "distributed by hash(k2) buckets 1 properties('replication_num' = '1');");
 
         dorisAssert = new DorisAssert();
         dorisAssert.useDatabase("db1");
@@ -91,8 +88,10 @@ public class CreateFunctionTest {
         Assert.assertNotNull(db);
 
         // create alias function
-        String createFuncStr = "create alias function db1.id_masking(bigint) with parameter(id) as concat(left(id,3),'****',right(id,4));";
-        CreateFunctionStmt createFunctionStmt = (CreateFunctionStmt) UtFrameUtils.parseAndAnalyzeStmt(createFuncStr, ctx);
+        String createFuncStr
+                = "create alias function db1.id_masking(bigint) with parameter(id) as concat(left(id,3),'****',right(id,4));";
+        CreateFunctionStmt createFunctionStmt = (CreateFunctionStmt) UtFrameUtils.parseAndAnalyzeStmt(createFuncStr,
+                ctx);
         Env.getCurrentEnv().createFunction(createFunctionStmt);
 
         List<Function> functions = db.getFunctions();
@@ -107,14 +106,15 @@ public class CreateFunctionTest {
         Assert.assertEquals(1, planner.getFragments().size());
         PlanFragment fragment = planner.getFragments().get(0);
         Assert.assertTrue(fragment.getPlanRoot() instanceof UnionNode);
-        UnionNode unionNode =  (UnionNode) fragment.getPlanRoot();
+        UnionNode unionNode = (UnionNode) fragment.getPlanRoot();
         List<List<Expr>> constExprLists = Deencapsulation.getField(unionNode, "constExprLists");
         Assert.assertEquals(1, constExprLists.size());
         Assert.assertEquals(1, constExprLists.get(0).size());
         Assert.assertTrue(constExprLists.get(0).get(0) instanceof FunctionCallExpr);
 
         queryStr = "select db1.id_masking(k1) from db1.tbl1";
-        Assert.assertTrue(dorisAssert.query(queryStr).explainQuery().contains("concat(left(`k1`, 3), '****', right(`k1`, 4))"));
+        Assert.assertTrue(
+                dorisAssert.query(queryStr).explainQuery().contains("concat(left(k1, 3), '****', right(k1, 4))"));
 
         // create alias function with cast
         // cast any type to decimal with specific precision and scale
@@ -135,16 +135,16 @@ public class CreateFunctionTest {
         Assert.assertEquals(1, planner.getFragments().size());
         fragment = planner.getFragments().get(0);
         Assert.assertTrue(fragment.getPlanRoot() instanceof UnionNode);
-        unionNode =  (UnionNode) fragment.getPlanRoot();
+        unionNode = (UnionNode) fragment.getPlanRoot();
         constExprLists = Deencapsulation.getField(unionNode, "constExprLists");
         System.out.println(constExprLists.get(0).get(0));
         Assert.assertTrue(constExprLists.get(0).get(0) instanceof StringLiteral);
 
         queryStr = "select db1.decimal(k3, 4, 1) from db1.tbl1;";
         if (Config.enable_decimal_conversion) {
-            Assert.assertTrue(dorisAssert.query(queryStr).explainQuery().contains("CAST(`k3` AS DECIMALV3(4,1))"));
+            Assert.assertTrue(dorisAssert.query(queryStr).explainQuery().contains("CAST(`k3` AS DECIMALV3(4, 1))"));
         } else {
-            Assert.assertTrue(dorisAssert.query(queryStr).explainQuery().contains("CAST(`k3` AS DECIMAL(4,1))"));
+            Assert.assertTrue(dorisAssert.query(queryStr).explainQuery().contains("CAST(`k3` AS DECIMAL(4, 1))"));
         }
 
         // cast any type to varchar with fixed length
@@ -165,7 +165,7 @@ public class CreateFunctionTest {
         Assert.assertEquals(1, planner.getFragments().size());
         fragment = planner.getFragments().get(0);
         Assert.assertTrue(fragment.getPlanRoot() instanceof UnionNode);
-        unionNode =  (UnionNode) fragment.getPlanRoot();
+        unionNode = (UnionNode) fragment.getPlanRoot();
         constExprLists = Deencapsulation.getField(unionNode, "constExprLists");
         Assert.assertEquals(1, constExprLists.size());
         Assert.assertEquals(1, constExprLists.get(0).size());
@@ -175,7 +175,7 @@ public class CreateFunctionTest {
         Assert.assertTrue(dorisAssert.query(queryStr).explainQuery().contains("CAST(`k1` AS CHARACTER)"));
 
         // cast any type to char with fixed length
-        createFuncStr = "create alias function db1.char(all, int) with parameter(text, length) as "
+        createFuncStr = "create alias function db1.to_char(all, int) with parameter(text, length) as "
                 + "cast(text as char(length));";
         createFunctionStmt = (CreateFunctionStmt) UtFrameUtils.parseAndAnalyzeStmt(createFuncStr, ctx);
         Env.getCurrentEnv().createFunction(createFunctionStmt);
@@ -183,7 +183,7 @@ public class CreateFunctionTest {
         functions = db.getFunctions();
         Assert.assertEquals(4, functions.size());
 
-        queryStr = "select db1.char(333, 4);";
+        queryStr = "select db1.to_char(333, 4);";
         ctx.getState().reset();
         stmtExecutor = new StmtExecutor(ctx, queryStr);
         stmtExecutor.execute();
@@ -192,13 +192,131 @@ public class CreateFunctionTest {
         Assert.assertEquals(1, planner.getFragments().size());
         fragment = planner.getFragments().get(0);
         Assert.assertTrue(fragment.getPlanRoot() instanceof UnionNode);
-        unionNode =  (UnionNode) fragment.getPlanRoot();
+        unionNode = (UnionNode) fragment.getPlanRoot();
         constExprLists = Deencapsulation.getField(unionNode, "constExprLists");
         Assert.assertEquals(1, constExprLists.size());
         Assert.assertEquals(1, constExprLists.get(0).size());
         Assert.assertTrue(constExprLists.get(0).get(0) instanceof StringLiteral);
 
-        queryStr = "select db1.char(k1, 4) from db1.tbl1;";
+        queryStr = "select db1.to_char(k1, 4) from db1.tbl1;";
         Assert.assertTrue(dorisAssert.query(queryStr).explainQuery().contains("CAST(`k1` AS CHARACTER)"));
     }
+
+    @Test
+    public void testCreateGlobalFunction() throws Exception {
+        ConnectContext ctx = UtFrameUtils.createDefaultCtx();
+        ctx.getSessionVariable().setEnableNereidsPlanner(false);
+
+        // 1. create database db2
+        createDatabase(ctx, "create database db2;");
+
+        createTable("create table db2.tbl1(k1 int, k2 bigint, k3 varchar(10), k4 char(5)) duplicate key(k1) "
+                + "distributed by hash(k2) buckets 1 properties('replication_num' = '1');");
+
+        dorisAssert = new DorisAssert();
+        dorisAssert.useDatabase("db2");
+
+        Database db = Env.getCurrentInternalCatalog().getDbNullable("default_cluster:db2");
+        Assert.assertNotNull(db);
+
+        // 2. create global function
+
+        String createFuncStr
+                = "create global alias function id_masking(bigint) with parameter(id) as concat(left(id,3),'****',right(id,4));";
+        CreateFunctionStmt createFunctionStmt = (CreateFunctionStmt) UtFrameUtils.parseAndAnalyzeStmt(createFuncStr,
+                ctx);
+        Env.getCurrentEnv().createFunction(createFunctionStmt);
+
+        List<Function> functions = Env.getCurrentEnv().getGlobalFunctionMgr().getFunctions();
+        Assert.assertEquals(1, functions.size());
+
+        String queryStr = "select id_masking(13888888888);";
+        testFunctionQuery(ctx, queryStr, false);
+
+        queryStr = "select id_masking(k1) from db2.tbl1";
+        Assert.assertTrue(
+                dorisAssert.query(queryStr).explainQuery().contains("concat(left(k1, 3), '****', right(k1, 4))"));
+
+        // 4. create alias function with cast
+        // cast any type to decimal with specific precision and scale
+        createFuncStr = "create global alias function decimal(all, int, int) with parameter(col, precision, scale)"
+                + " as cast(col as decimal(precision, scale));";
+        createFunctionStmt = (CreateFunctionStmt) UtFrameUtils.parseAndAnalyzeStmt(createFuncStr, ctx);
+        Env.getCurrentEnv().createFunction(createFunctionStmt);
+
+        functions = Env.getCurrentEnv().getGlobalFunctionMgr().getFunctions();
+        Assert.assertEquals(2, functions.size());
+
+        queryStr = "select decimal(333, 4, 1);";
+        testFunctionQuery(ctx, queryStr, true);
+
+        queryStr = "select decimal(k3, 4, 1) from db2.tbl1;";
+        if (Config.enable_decimal_conversion) {
+            Assert.assertTrue(dorisAssert.query(queryStr).explainQuery().contains("CAST(`k3` AS DECIMALV3(4, 1))"));
+        } else {
+            Assert.assertTrue(dorisAssert.query(queryStr).explainQuery().contains("CAST(`k3` AS DECIMAL(4, 1))"));
+        }
+
+        // 5. cast any type to varchar with fixed length
+        createFuncStr = "create global alias function db2.varchar(all, int) with parameter(text, length) as "
+                + "cast(text as varchar(length));";
+        createFunctionStmt = (CreateFunctionStmt) UtFrameUtils.parseAndAnalyzeStmt(createFuncStr, ctx);
+        Env.getCurrentEnv().createFunction(createFunctionStmt);
+
+        functions = Env.getCurrentEnv().getGlobalFunctionMgr().getFunctions();
+        Assert.assertEquals(3, functions.size());
+
+        queryStr = "select varchar(333, 4);";
+        testFunctionQuery(ctx, queryStr, true);
+
+        queryStr = "select varchar(k1, 4) from db2.tbl1;";
+        Assert.assertTrue(dorisAssert.query(queryStr).explainQuery().contains("CAST(`k1` AS CHARACTER)"));
+
+        // 6. cast any type to char with fixed length
+        createFuncStr = "create global alias function db2.to_char(all, int) with parameter(text, length) as "
+                + "cast(text as char(length));";
+        createFunctionStmt = (CreateFunctionStmt) UtFrameUtils.parseAndAnalyzeStmt(createFuncStr, ctx);
+        Env.getCurrentEnv().createFunction(createFunctionStmt);
+
+        functions = Env.getCurrentEnv().getGlobalFunctionMgr().getFunctions();
+        Assert.assertEquals(4, functions.size());
+
+        queryStr = "select to_char(333, 4);";
+        testFunctionQuery(ctx, queryStr, true);
+
+        queryStr = "select to_char(k1, 4) from db2.tbl1;";
+        Assert.assertTrue(dorisAssert.query(queryStr).explainQuery().contains("CAST(`k1` AS CHARACTER)"));
+    }
+
+    private void testFunctionQuery(ConnectContext ctx, String queryStr, Boolean isStringLiteral) throws Exception {
+        ctx.getState().reset();
+        StmtExecutor stmtExecutor = new StmtExecutor(ctx, queryStr);
+        stmtExecutor.execute();
+        Assert.assertNotEquals(QueryState.MysqlStateType.ERR, ctx.getState().getStateType());
+        Planner planner = stmtExecutor.planner();
+        Assert.assertEquals(1, planner.getFragments().size());
+        PlanFragment fragment = planner.getFragments().get(0);
+        Assert.assertTrue(fragment.getPlanRoot() instanceof UnionNode);
+        UnionNode unionNode = (UnionNode) fragment.getPlanRoot();
+        List<List<Expr>> constExprLists = Deencapsulation.getField(unionNode, "constExprLists");
+        Assert.assertEquals(1, constExprLists.size());
+        Assert.assertEquals(1, constExprLists.get(0).size());
+        if (isStringLiteral) {
+            Assert.assertTrue(constExprLists.get(0).get(0) instanceof StringLiteral);
+        } else {
+            Assert.assertTrue(constExprLists.get(0).get(0) instanceof FunctionCallExpr);
+        }
+    }
+
+    private void createTable(String createTblStmtStr) throws Exception {
+        CreateTableStmt createTableStmt = (CreateTableStmt) UtFrameUtils.parseAndAnalyzeStmt(createTblStmtStr,
+                connectContext);
+        Env.getCurrentEnv().createTable(createTableStmt);
+    }
+
+    private void createDatabase(ConnectContext ctx, String createDbStmtStr) throws Exception {
+        CreateDbStmt createDbStmt = (CreateDbStmt) UtFrameUtils.parseAndAnalyzeStmt(createDbStmtStr, ctx);
+        Env.getCurrentEnv().createDb(createDbStmt);
+        System.out.println(Env.getCurrentInternalCatalog().getDbNames());
+    }
 }
