@@ -21,10 +21,12 @@ import org.apache.doris.analysis.UserIdentity;
 import org.apache.doris.catalog.Env;
 import org.apache.doris.cluster.ClusterNamespace;
 import org.apache.doris.common.DdlException;
-import org.apache.doris.mysql.privilege.PaloAuth;
-import org.apache.doris.mysql.privilege.PaloRole;
+import org.apache.doris.mysql.privilege.AccessControllerManager;
+import org.apache.doris.mysql.privilege.Auth;
+import org.apache.doris.mysql.privilege.Role;
 import org.apache.doris.qe.ConnectContext;
 
+import com.google.common.collect.Sets;
 import mockit.Delegate;
 import mockit.Expectations;
 import mockit.Mocked;
@@ -40,16 +42,16 @@ public class LdapAuthenticateTest {
     private static final String IP = "192.168.1.1";
     private static final String TABLE_RD = "palo_rd";
 
-    private PaloRole ldapGroupsPrivs;
+    private Role ldapGroupsPrivs;
 
     @Mocked
     private LdapManager ldapManager;
     @Mocked
-    private LdapPrivsChecker ldapPrivsChecker;
-    @Mocked
     private Env env;
     @Mocked
-    private PaloAuth auth;
+    private Auth auth;
+    @Mocked
+    private AccessControllerManager accessManager;
 
     @Before
     public void setUp() throws DdlException {
@@ -59,14 +61,18 @@ public class LdapAuthenticateTest {
                 minTimes = 0;
                 result = true;
 
-                auth.mergeRolesNoCheckName((List<String>) any, (PaloRole) any);
+                auth.mergeRolesNoCheckName((List<String>) any, (Role) any);
                 minTimes = 0;
                 result = new Delegate() {
-                    void fakeMergeRolesNoCheckName(List<String> roles, PaloRole savedRole) {
+                    void fakeMergeRolesNoCheckName(List<String> roles, Role savedRole) {
                         ldapGroupsPrivs = savedRole;
                     }
                 };
 
+                env.getAccessManager();
+                minTimes = 0;
+                result = accessManager;
+
                 env.getAuth();
                 minTimes = 0;
                 result = auth;
@@ -106,7 +112,7 @@ public class LdapAuthenticateTest {
                     minTimes = 0;
                     result = new Delegate() {
                         LdapUserInfo fakeGetGroups(String user) {
-                            return new LdapUserInfo(anyString, false, "", new PaloRole(anyString));
+                            return new LdapUserInfo(anyString, false, "", Sets.newHashSet(new Role(anyString)));
                         }
                     };
                 } else {
@@ -150,7 +156,7 @@ public class LdapAuthenticateTest {
         setGetCurrentUserIdentity(true);
         String qualifiedUser = ClusterNamespace.getFullName(DEFAULT_CLUSTER, USER_NAME);
         Assert.assertTrue(LdapAuthenticate.authenticate(context, "123", qualifiedUser));
-        Assert.assertFalse(context.getIsTempUser());
+        Assert.assertTrue(context.getIsTempUser());
     }
 
     @Test
@@ -183,7 +189,7 @@ public class LdapAuthenticateTest {
         setGetCurrentUserIdentity(true);
         String qualifiedUser = ClusterNamespace.getFullName(DEFAULT_CLUSTER, USER_NAME);
         Assert.assertTrue(LdapAuthenticate.authenticate(context, "123", qualifiedUser));
-        Assert.assertFalse(context.getIsTempUser());
+        Assert.assertTrue(context.getIsTempUser());
     }
 
     @Test
