@@ -36,6 +36,9 @@ public class PlannerTest extends TestWithFeService {
 
     @Override
     protected void runBeforeAll() throws Exception {
+
+        connectContext.getSessionVariable().setEnableNereidsPlanner(false);
+
         // Create database `db1`.
         createDatabase("db1");
 
@@ -80,7 +83,7 @@ public class PlannerTest extends TestWithFeService {
         Planner planner1 = stmtExecutor1.planner();
         String plan1 = planner1.getExplainString(new ExplainOptions(false, false));
         Assertions.assertEquals(1, StringUtils.countMatches(plan1, "UNION"));
-        String sql2 = "explain select * from db1.tbl1 where k1='a' and k4=1\n"
+        String sql2 = "explain select /*+ SET_VAR(enable_nereids_planner=false) */ * from db1.tbl1 where k1='a' and k4=1\n"
                 + "union distinct\n"
                 + "  (select * from db1.tbl1 where k1='b' and k4=2\n"
                 + "   union all\n"
@@ -106,7 +109,7 @@ public class PlannerTest extends TestWithFeService {
         Assertions.assertEquals(4, StringUtils.countMatches(plan2, "UNION"));
 
         // intersect
-        String sql3 = "explain select * from\n"
+        String sql3 = "explain select /*+ SET_VAR(enable_nereids_planner=false) */ * from\n"
                 + "  (select k1, k2 from db1.tbl1\n"
                 + "   intersect\n"
                 + "   select k1, k2 from db1.tbl1) a\n"
@@ -119,7 +122,7 @@ public class PlannerTest extends TestWithFeService {
         Planner planner3 = stmtExecutor3.planner();
         String plan3 = planner3.getExplainString(new ExplainOptions(false, false));
         Assertions.assertEquals(1, StringUtils.countMatches(plan3, "INTERSECT"));
-        String sql4 = "explain select * from db1.tbl1 where k1='a' and k4=1\n"
+        String sql4 = "explain select /*+ SET_VAR(enable_nereids_planner=false) */ * from db1.tbl1 where k1='a' and k4=1\n"
                 + "intersect distinct\n"
                 + "  (select * from db1.tbl1 where k1='b' and k4=2\n"
                 + "   intersect\n"
@@ -146,7 +149,7 @@ public class PlannerTest extends TestWithFeService {
         Assertions.assertEquals(3, StringUtils.countMatches(plan4, "INTERSECT"));
 
         // except
-        String sql5 = "explain select * from\n"
+        String sql5 = "explain select /*+ SET_VAR(enable_nereids_planner=false) */ * from\n"
                 + "  (select k1, k2 from db1.tbl1\n"
                 + "   except\n"
                 + "   select k1, k2 from db1.tbl1) a\n"
@@ -160,7 +163,7 @@ public class PlannerTest extends TestWithFeService {
         String plan5 = planner5.getExplainString(new ExplainOptions(false, false));
         Assertions.assertEquals(1, StringUtils.countMatches(plan5, "EXCEPT"));
 
-        String sql6 = "select * from db1.tbl1 where k1='a' and k4=1\n"
+        String sql6 = "select /*+ SET_VAR(enable_nereids_planner=false) */ * from db1.tbl1 where k1='a' and k4=1\n"
                 + "except\n"
                 + "select * from db1.tbl1 where k1='a' and k4=1\n"
                 + "except\n"
@@ -174,7 +177,7 @@ public class PlannerTest extends TestWithFeService {
         String plan6 = planner6.getExplainString(new ExplainOptions(false, false));
         Assertions.assertEquals(1, StringUtils.countMatches(plan6, "EXCEPT"));
 
-        String sql7 = "select * from db1.tbl1 where k1='a' and k4=1\n"
+        String sql7 = "select /*+ SET_VAR(enable_nereids_planner=false) */ * from db1.tbl1 where k1='a' and k4=1\n"
                 + "except distinct\n"
                 + "select * from db1.tbl1 where k1='a' and k4=1\n"
                 + "except\n"
@@ -189,7 +192,7 @@ public class PlannerTest extends TestWithFeService {
         Assertions.assertEquals(1, StringUtils.countMatches(plan7, "EXCEPT"));
 
         // mixed
-        String sql8 = "select * from db1.tbl1 where k1='a' and k4=1\n"
+        String sql8 = "select /*+ SET_VAR(enable_nereids_planner=false) */ * from db1.tbl1 where k1='a' and k4=1\n"
                 + "union\n"
                 + "select * from db1.tbl1 where k1='a' and k4=1\n"
                 + "except\n"
@@ -205,7 +208,7 @@ public class PlannerTest extends TestWithFeService {
         Assertions.assertEquals(1, StringUtils.countMatches(plan8, "INTERSECT"));
         Assertions.assertEquals(1, StringUtils.countMatches(plan8, "EXCEPT"));
 
-        String sql9 = "explain select * from db1.tbl1 where k1='a' and k4=1\n"
+        String sql9 = "explain select /*+ SET_VAR(enable_nereids_planner=false) */ * from db1.tbl1 where k1='a' and k4=1\n"
                 + "intersect distinct\n"
                 + "  (select * from db1.tbl1 where k1='b' and k4=2\n"
                 + "   union all\n"
@@ -233,7 +236,7 @@ public class PlannerTest extends TestWithFeService {
         Assertions.assertEquals(3, StringUtils.countMatches(plan9, "INTERSECT"));
         Assertions.assertEquals(2, StringUtils.countMatches(plan9, "EXCEPT"));
 
-        String sql10 = "select 499 union select 670 except select 499";
+        String sql10 = "select /*+ SET_VAR(enable_nereids_planner=false) */ 499 union select 670 except select 499";
         StmtExecutor stmtExecutor10 = new StmtExecutor(connectContext, sql10);
         stmtExecutor10.execute();
         Planner planner10 = stmtExecutor10.planner();
@@ -243,7 +246,7 @@ public class PlannerTest extends TestWithFeService {
         Assertions.assertTrue(fragments10.get(0).getPlanRoot()
                 .getFragment().getPlanRoot().getChild(1) instanceof UnionNode);
 
-        String sql11 = "SELECT a.x FROM\n"
+        String sql11 = "SELECT /*+ SET_VAR(enable_nereids_planner=false) */ a.x FROM\n"
                 + "(SELECT '01' x) a \n"
                 + "INNER JOIN\n"
                 + "(SELECT '01' x UNION all SELECT '02') b";
@@ -253,7 +256,7 @@ public class PlannerTest extends TestWithFeService {
         SetOperationNode setNode11 = (SetOperationNode) (planner11.getFragments().get(1).getPlanRoot());
         Assertions.assertEquals(2, setNode11.getMaterializedConstExprLists().size());
 
-        String sql12 = "SELECT a.x \n"
+        String sql12 = "SELECT /*+ SET_VAR(enable_nereids_planner=false) */ a.x \n"
                 + "FROM (SELECT '01' x) a \n"
                 + "INNER JOIN \n"
                 + "(SELECT k1 from db1.tbl1 \n"
@@ -269,7 +272,7 @@ public class PlannerTest extends TestWithFeService {
     @Test
     public void testPushDown() throws Exception {
         String sql1 =
-                "SELECT\n"
+                "SELECT /*+ SET_VAR(enable_nereids_planner=false) */ \n"
                 + "    IF(k2 IS NULL, 'ALL', k2) AS k2,\n"
                 + "    IF(k3 IS NULL, 'ALL', k3) AS k3,\n"
                 + "    k4\n"
@@ -302,7 +305,7 @@ public class PlannerTest extends TestWithFeService {
         Assertions.assertEquals(3, fragments1.get(0).getPlanRoot().getChild(0).getChild(0).conjuncts.size());
 
         String sql2 =
-                "SELECT\n"
+                "SELECT /*+ SET_VAR(enable_nereids_planner=false) */ \n"
                         + "    IF(k2 IS NULL, 'ALL', k2) AS k2,\n"
                         + "    IF(k3 IS NULL, 'ALL', k3) AS k3,\n"
                         + "    k4\n"
@@ -333,7 +336,7 @@ public class PlannerTest extends TestWithFeService {
         // union
         String sql1 = "with a as (select NULL as user_id ), "
                 + "b as ( select '543' as user_id) "
-                + "select user_id from a union all select user_id from b";
+                + "select /*+ SET_VAR(enable_nereids_planner=false) */ user_id from a union all select user_id from b";
 
         StmtExecutor stmtExecutor1 = new StmtExecutor(connectContext, sql1);
         stmtExecutor1.execute();
@@ -352,7 +355,7 @@ public class PlannerTest extends TestWithFeService {
 
     @Test
     public void testAnalyticSortNodeLeftJoin() throws Exception {
-        String sql = "SELECT a.k1, a.k3, SUM(COUNT(t.k2)) OVER (PARTITION BY a.k3 ORDER BY a.k1) AS c\n"
+        String sql = "SELECT /*+ SET_VAR(enable_nereids_planner=false) */ a.k1, a.k3, SUM(COUNT(t.k2)) OVER (PARTITION BY a.k3 ORDER BY a.k1) AS c\n"
                 + "FROM ( SELECT k1, k3 FROM db1.tbl3) a\n"
                 + "LEFT JOIN (SELECT 1 AS line, k1, k2, k3 FROM db1.tbl3) t\n"
                 + "ON t.k1 = a.k1 AND t.k3 = a.k3\n"
@@ -402,18 +405,18 @@ public class PlannerTest extends TestWithFeService {
             Assertions.assertEquals(plan1, plan2);
         };
 
-        compare.accept("select * from db1.tbl2 where k1 = 2.0", "select * from db1.tbl2 where k1 = 2");
-        compare.accept("select * from db1.tbl2 where k1 = 2.1", "select * from db1.tbl2 where 2 = 2.1");
-        compare.accept("select * from db1.tbl2 where k1 != 2.0", "select * from db1.tbl2 where k1 != 2");
-        compare.accept("select * from db1.tbl2 where k1 != 2.1", "select * from db1.tbl2 where TRUE");
-        compare.accept("select * from db1.tbl2 where k1 <= 2.0", "select * from db1.tbl2 where k1 <= 2");
-        compare.accept("select * from db1.tbl2 where k1 <= 2.1", "select * from db1.tbl2 where k1 <= 2");
-        compare.accept("select * from db1.tbl2 where k1 >= 2.0", "select * from db1.tbl2 where k1 >= 2");
-        compare.accept("select * from db1.tbl2 where k1 >= 2.1", "select * from db1.tbl2 where k1 > 2");
-        compare.accept("select * from db1.tbl2 where k1 < 2.0", "select * from db1.tbl2 where k1 < 2");
-        compare.accept("select * from db1.tbl2 where k1 < 2.1", "select * from db1.tbl2 where k1 <= 2");
-        compare.accept("select * from db1.tbl2 where k1 > 2.0", "select * from db1.tbl2 where k1 > 2");
-        compare.accept("select * from db1.tbl2 where k1 > 2.1", "select * from db1.tbl2 where k1 > 2");
+        compare.accept("select /*+ SET_VAR(enable_nereids_planner=false) */ * from db1.tbl2 where k1 = 2.0", "select /*+ SET_VAR(enable_nereids_planner=false) */ * from db1.tbl2 where k1 = 2");
+        compare.accept("select /*+ SET_VAR(enable_nereids_planner=false) */ * from db1.tbl2 where k1 = 2.1", "select /*+ SET_VAR(enable_nereids_planner=false) */ * from db1.tbl2 where 2 = 2.1");
+        compare.accept("select /*+ SET_VAR(enable_nereids_planner=false) */* from db1.tbl2 where k1 != 2.0", "select /*+ SET_VAR(enable_nereids_planner=false) */* from db1.tbl2 where k1 != 2");
+        compare.accept("select /*+ SET_VAR(enable_nereids_planner=false) */* from db1.tbl2 where k1 != 2.1", "select /*+ SET_VAR(enable_nereids_planner=false) */* from db1.tbl2 where TRUE");
+        compare.accept("select /*+ SET_VAR(enable_nereids_planner=false) */* from db1.tbl2 where k1 <= 2.0", "select /*+ SET_VAR(enable_nereids_planner=false) */* from db1.tbl2 where k1 <= 2");
+        compare.accept("select /*+ SET_VAR(enable_nereids_planner=false) */* from db1.tbl2 where k1 <= 2.1", "select /*+ SET_VAR(enable_nereids_planner=false) */* from db1.tbl2 where k1 <= 2");
+        compare.accept("select /*+ SET_VAR(enable_nereids_planner=false) */* from db1.tbl2 where k1 >= 2.0", "select /*+ SET_VAR(enable_nereids_planner=false) */* from db1.tbl2 where k1 >= 2");
+        compare.accept("select /*+ SET_VAR(enable_nereids_planner=false) */* from db1.tbl2 where k1 >= 2.1", "select /*+ SET_VAR(enable_nereids_planner=false) */* from db1.tbl2 where k1 > 2");
+        compare.accept("select /*+ SET_VAR(enable_nereids_planner=false) */* from db1.tbl2 where k1 < 2.0", "select /*+ SET_VAR(enable_nereids_planner=false) */* from db1.tbl2 where k1 < 2");
+        compare.accept("select /*+ SET_VAR(enable_nereids_planner=false) */* from db1.tbl2 where k1 < 2.1", "select /*+ SET_VAR(enable_nereids_planner=false) */* from db1.tbl2 where k1 <= 2");
+        compare.accept("select /*+ SET_VAR(enable_nereids_planner=false) */* from db1.tbl2 where k1 > 2.0", "select /*+ SET_VAR(enable_nereids_planner=false) */* from db1.tbl2 where k1 > 2");
+        compare.accept("select /*+ SET_VAR(enable_nereids_planner=false) */* from db1.tbl2 where k1 > 2.1", "select /*+ SET_VAR(enable_nereids_planner=false) */* from db1.tbl2 where k1 > 2");
     }
 
     @Test
@@ -427,7 +430,7 @@ public class PlannerTest extends TestWithFeService {
 
     @Test
     public void testPushDownPredicateOnGroupingSetAggregate() throws Exception {
-        String sql = "explain select k1, k2, count(distinct v1) from db1.tbl4"
+        String sql = "explain select /*+ SET_VAR(enable_nereids_planner=false) */ k1, k2, count(distinct v1) from db1.tbl4"
                 + " group by grouping sets((k1), (k1, k2)) having k1 = 1 and k2 = 1";
         StmtExecutor stmtExecutor = new StmtExecutor(connectContext, sql);
         stmtExecutor.execute();
@@ -449,18 +452,18 @@ public class PlannerTest extends TestWithFeService {
 
     @Test
     public void testPushDownPredicateOnNormalAggregate() throws Exception {
-        String sql = "explain select k1, k2, count(distinct v1) from db1.tbl4"
+        String sql = "explain select /*+ SET_VAR(enable_nereids_planner=false) */ k1, k2, count(distinct v1) from db1.tbl4"
                 + " group by k1, k2 having k1 = 1 and k2 = 1";
         StmtExecutor stmtExecutor = new StmtExecutor(connectContext, sql);
         stmtExecutor.execute();
         Planner planner = stmtExecutor.planner();
         String plan = planner.getExplainString(new ExplainOptions(false, false));
-        Assertions.assertTrue(plan.contains("PREDICATES: `k1` = 1, `k2` = 1\n"));
+        Assertions.assertTrue(plan.contains("PREDICATES: `k1` = 1 AND `k2` = 1\n"));
     }
 
     @Test
     public void testPushDownPredicateOnWindowFunction() throws Exception {
-        String sql = "explain select v1, k1,"
+        String sql = "explain select /*+ SET_VAR(enable_nereids_planner=false) */ v1, k1,"
                 + " sum(v1) over (partition by k1 order by v1 rows between 1 preceding and 1 following)"
                 + " as 'moving total' from db1.tbl4 where k1 = 1";
         StmtExecutor stmtExecutor = new StmtExecutor(connectContext, sql);
@@ -494,16 +497,8 @@ public class PlannerTest extends TestWithFeService {
         Assertions.assertEquals(MysqlStateType.ERR, state.getStateType());
         Assertions.assertTrue(state.getErrorMessage()
                 .contains("you need (at least one of) the LOAD privilege(s) for this operation"));
-
         // set to admin user
         connectContext.setCurrentUserIdentity(UserIdentity.ADMIN);
-        stmtExecutor = new StmtExecutor(connectContext, qSQL);
-        stmtExecutor.execute();
-        state = connectContext.getState();
-        // still error because we can not do real update in unit test.
-        // just check if it pass the priv check.
-        Assertions.assertEquals(MysqlStateType.ERR, state.getStateType());
-        Assertions.assertTrue(state.getErrorMessage().contains("failed to execute update stmt"));
     }
 
     @Test
@@ -516,6 +511,7 @@ public class PlannerTest extends TestWithFeService {
         String plan1 = planner1.getExplainString(new ExplainOptions(false, false));
         Assertions.assertFalse(plan1.contains("SORT INFO:\n          `k1`\n          `k2`"));
         Assertions.assertFalse(plan1.contains("SORT LIMIT:"));
+        Assertions.assertFalse(plan1.contains("TOPN OPT"));
 
         // Push sort fail limit > topnOptLimitThreshold
         sql1 = "explain select k1 from db1.tbl3 order by k1, k2 limit "
@@ -526,9 +522,10 @@ public class PlannerTest extends TestWithFeService {
         plan1 = planner1.getExplainString(new ExplainOptions(false, false));
         Assertions.assertFalse(plan1.contains("SORT INFO:\n          `k1`\n          `k2`"));
         Assertions.assertFalse(plan1.contains("SORT LIMIT:"));
+        Assertions.assertFalse(plan1.contains("TOPN OPT"));
 
         // Push sort success limit = topnOptLimitThreshold
-        sql1 = "explain select k1 from db1.tbl3 order by k1, k2 limit "
+        sql1 = "explain select /*+ SET_VAR(enable_nereids_planner=false) */ k1 from db1.tbl3 order by k1, k2 limit "
             + (connectContext.getSessionVariable().topnOptLimitThreshold);
         stmtExecutor1 = new StmtExecutor(connectContext, sql1);
         stmtExecutor1.execute();
@@ -536,10 +533,11 @@ public class PlannerTest extends TestWithFeService {
         plan1 = planner1.getExplainString(new ExplainOptions(false, false));
         Assertions.assertTrue(plan1.contains("SORT INFO:\n          `k1`\n          `k2`"));
         Assertions.assertTrue(plan1.contains("SORT LIMIT:"));
+        Assertions.assertTrue(plan1.contains("TOPN OPT"));
 
         // Push sort success limit < topnOptLimitThreshold
         if (connectContext.getSessionVariable().topnOptLimitThreshold > 1) {
-            sql1 = "explain select k1 from db1.tbl3 order by k1, k2 limit "
+            sql1 = "explain select /*+ SET_VAR(enable_nereids_planner=false) */ k1 from db1.tbl3 order by k1, k2 limit "
                 + (connectContext.getSessionVariable().topnOptLimitThreshold - 1);
             stmtExecutor1 = new StmtExecutor(connectContext, sql1);
             stmtExecutor1.execute();
@@ -547,6 +545,7 @@ public class PlannerTest extends TestWithFeService {
             plan1 = planner1.getExplainString(new ExplainOptions(false, false));
             Assertions.assertTrue(plan1.contains("SORT INFO:\n          `k1`\n          `k2`"));
             Assertions.assertTrue(plan1.contains("SORT LIMIT:"));
+            Assertions.assertTrue(plan1.contains("TOPN OPT"));
         }
 
         // Push sort failed
@@ -561,9 +560,9 @@ public class PlannerTest extends TestWithFeService {
 
     @Test
     public void testEliminatingSortNode() throws Exception {
-            // success case 1
+            // fail case 1
             {
-            String sql1 = "explain select k1 from db1.tbl1 where k1 = 1 order by k1, k2";
+            String sql1 = "explain select /*+ SET_VAR(enable_nereids_planner=false) */ k1 from db1.tbl1 where k1 = 1 order by k1, k2";
             StmtExecutor stmtExecutor1 = new StmtExecutor(connectContext, sql1);
             stmtExecutor1.execute();
             Planner planner1 = stmtExecutor1.planner();
@@ -573,7 +572,7 @@ public class PlannerTest extends TestWithFeService {
 
             // fail case 2
             {
-            String sql1 = "explain select k1 from db1.tbl1 where k1 = 1 and k3 = 2 order by k1, k2";
+            String sql1 = "explain select /*+ SET_VAR(enable_nereids_planner=false) */ k1 from db1.tbl1 where k1 = 1 and k3 = 2 order by k1, k2";
             StmtExecutor stmtExecutor1 = new StmtExecutor(connectContext, sql1);
             stmtExecutor1.execute();
             Planner planner1 = stmtExecutor1.planner();
@@ -583,7 +582,7 @@ public class PlannerTest extends TestWithFeService {
 
             // fail case 3
             {
-            String sql1 = "explain select k1 from db1.tbl1 where k1 = 1 and k2 != 2 order by k1, k2";
+            String sql1 = "explain select /*+ SET_VAR(enable_nereids_planner=false) */ k1 from db1.tbl1 where k1 = 1 and k2 != 2 order by k1, k2";
             StmtExecutor stmtExecutor1 = new StmtExecutor(connectContext, sql1);
             stmtExecutor1.execute();
             Planner planner1 = stmtExecutor1.planner();
@@ -593,7 +592,7 @@ public class PlannerTest extends TestWithFeService {
 
             // fail case 4
             {
-            String sql1 = "explain select k1 from db1.tbl1 where k1 = 1 or k2 = 2 order by k1, k2";
+            String sql1 = "explain select /*+ SET_VAR(enable_nereids_planner=false) */ k1 from db1.tbl1 where k1 = 1 or k2 = 2 order by k1, k2";
             StmtExecutor stmtExecutor1 = new StmtExecutor(connectContext, sql1);
             stmtExecutor1.execute();
             Planner planner1 = stmtExecutor1.planner();
@@ -603,7 +602,7 @@ public class PlannerTest extends TestWithFeService {
 
             // fail case 5
             {
-            String sql1 = "explain select k1 from db1.tbl1 where k1 = 1 and k2 = 2 or k3 = 3 order by k1, k2";
+            String sql1 = "explain select /*+ SET_VAR(enable_nereids_planner=false) */ k1 from db1.tbl1 where k1 = 1 and k2 = 2 or k3 = 3 order by k1, k2";
             StmtExecutor stmtExecutor1 = new StmtExecutor(connectContext, sql1);
             stmtExecutor1.execute();
             Planner planner1 = stmtExecutor1.planner();
@@ -634,7 +633,7 @@ public class PlannerTest extends TestWithFeService {
 
             // success case 1
             {
-            String sql1 = "explain select k1 from db1.tbl1 where k1 = 1 and k2 = 2 order by k1, k2";
+            String sql1 = "explain select /*+ SET_VAR(enable_nereids_planner=false) */ k1 from db1.tbl1 where k1 = 1 and k2 = 2 order by k1, k2";
             StmtExecutor stmtExecutor1 = new StmtExecutor(connectContext, sql1);
             stmtExecutor1.execute();
             Planner planner1 = stmtExecutor1.planner();
@@ -644,7 +643,7 @@ public class PlannerTest extends TestWithFeService {
 
             // success case 2
             {
-            String sql1 = "explain select k1 from db1.tbl1 where k3 = 3 and k2 = 2 and k1 = 1 order by k1, k2";
+            String sql1 = "explain select /*+ SET_VAR(enable_nereids_planner=false) */ k1 from db1.tbl1 where k3 = 3 and k2 = 2 and k1 = 1 order by k1, k2";
             StmtExecutor stmtExecutor1 = new StmtExecutor(connectContext, sql1);
             stmtExecutor1.execute();
             Planner planner1 = stmtExecutor1.planner();
@@ -654,7 +653,7 @@ public class PlannerTest extends TestWithFeService {
 
             // success case 3
             {
-            String sql1 = "explain select k1 from db1.tbl1 where k1 in (1) and k2 in (2) and k2 !=2 order by k1, k2";
+            String sql1 = "explain select /*+ SET_VAR(enable_nereids_planner=false) */ k1 from db1.tbl1 where k1 in (1) and k2 in (2) and k2 !=2 order by k1, k2";
             StmtExecutor stmtExecutor1 = new StmtExecutor(connectContext, sql1);
             stmtExecutor1.execute();
             Planner planner1 = stmtExecutor1.planner();
@@ -664,7 +663,7 @@ public class PlannerTest extends TestWithFeService {
 
             // success case 4
             {
-            String sql1 = "explain select k1 from db1.tbl1 where k1 in (concat('1','2')) and k2 = 2 order by k1, k2";
+            String sql1 = "explain select /*+ SET_VAR(enable_nereids_planner=false) */ k1 from db1.tbl1 where k1 in (concat('1','2')) and k2 = 2 order by k1, k2";
             StmtExecutor stmtExecutor1 = new StmtExecutor(connectContext, sql1);
             stmtExecutor1.execute();
             Planner planner1 = stmtExecutor1.planner();
@@ -682,7 +681,5 @@ public class PlannerTest extends TestWithFeService {
             String plan1 = planner1.getExplainString(new ExplainOptions(false, false));
             Assertions.assertFalse(plan1.contains("order by:"));
             }
-
-
     }
 }
