@@ -27,13 +27,15 @@ import org.apache.hadoop.hive.ql.udf.generic.GenericUDF;
 import org.apache.hadoop.hive.serde2.objectinspector.ObjectInspector;
 import org.apache.hadoop.hive.serde2.objectinspector.primitive.BinaryObjectInspector;
 import org.apache.hadoop.hive.serde2.objectinspector.primitive.PrimitiveObjectInspectorFactory;
+import org.apache.logging.log4j.LogManager;
+import org.apache.logging.log4j.Logger;
 
 import java.io.IOException;
 
 @Description(name = "bitmap_xor", value = "a _FUNC_ b - Compute the symmetric"
         + " union of two or more input bitmaps, return the new bitmap")
 public class BitmapXorUDF extends GenericUDF {
-
+    private static final Logger LOG = LogManager.getLogger(BitmapXorUDF.class);
     private transient BinaryObjectInspector inputOI0;
     private transient BinaryObjectInspector inputOI1;
 
@@ -66,7 +68,7 @@ public class BitmapXorUDF extends GenericUDF {
             bitmapValue0.xor(bitmapValue1);
             return BitmapValueUtil.serializeToBytes(bitmapValue1);
         } catch (IOException ioException) {
-            ioException.printStackTrace();
+            LOG.warn("", ioException);
             throw new RuntimeException(ioException);
         }
     }
