@@ -14,22 +14,13 @@
 -- KIND, either express or implied.  See the License for the
 -- specific language governing permissions and limitations
 -- under the License.
-SELECT /*+SET_VAR(parallel_fragment_exec_instance_num=2, enable_vectorized_engine=true, batch_size=4096, enable_cost_based_join_reorder=true, enable_projection=true) */
-    d_year,
-    s_city,
-    p_brand,
-    SUM(lo_revenue - lo_supplycost) AS PROFIT
-FROM dates, customer, supplier, part, lineorder
+SELECT SUM(lo_revenue), d_year, p_brand
+FROM lineorder, dates, part, supplier
 WHERE
-    lo_custkey = c_custkey
-    AND lo_suppkey = s_suppkey
+    lo_orderdate = d_datekey
     AND lo_partkey = p_partkey
-    AND lo_orderdate = d_datekey
-    AND s_nation = 'UNITED STATES'
-    AND (
-        d_year = 1997
-        OR d_year = 1998
-    )
-    AND p_category = 'MFGR#14'
-GROUP BY d_year, s_city, p_brand
-ORDER BY d_year, s_city, p_brand;
+    AND lo_suppkey = s_suppkey
+    AND p_brand BETWEEN 'MFGR#2221' AND 'MFGR#2228'
+    AND s_region = 'ASIA'
+GROUP BY d_year, p_brand
+ORDER BY d_year, p_brand;
\ No newline at end of file
